@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,26 +21,22 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <webserver/request.h>
 #include <access/bible.h>
 #include <filter/roles.h>
-using namespace std;
 
 
 // This function returns users assigned to the logged-in user.
-vector <string> access_user::assignees (void * webserver_request)
+std::vector <std::string> access_user::assignees (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-
-  string myuser = request->session_logic ()->currentUser ();
-  int mylevel = request->session_logic ()->currentLevel ();
+  const int mylevel = webserver_request.session_logic ()->get_level ();
 
   // This holds the assignees.
-  vector <string> assignees {};
+  std::vector <std::string> assignees {};
 
   // Process all users.
-  vector <string> users = request->database_users ()->get_users ();
+  std::vector <std::string> users = webserver_request.database_users ()->get_users ();
   sort (users.begin(), users.end());
-  for (const auto & user : users) {
+  for (const auto& user : users) {
     // Assignees should have a level less than or equal to mylevel.
-    if (request->database_users ()->get_level (user) <= mylevel) {
+    if (webserver_request.database_users ()->get_level (user) <= mylevel) {
       assignees.push_back (user);
     }
   }
