@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2024 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 
 void changes_logic_start ()
 {
-  tasks_logic_queue (GENERATECHANGES);
+  tasks_logic_queue (task::generate_changes);
 }
 
 
