@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2018 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,12 @@
  */
 
 
-#ifndef INCLUDED_CHECKS_SETTINGS_PAIRS_H
-#define INCLUDED_CHECKS_SETTINGS_PAIRS_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+class Webserver_Request;
 
-string checks_settingspairs_url ();
-bool checks_settingspairs_acl (void * webserver_request);
-string checks_settingspairs (void * webserver_request);
-
-
-#endif
+std::string checks_settingspairs_url ();
+bool checks_settingspairs_acl (Webserver_Request& webserver_request);
+std::string checks_settingspairs (Webserver_Request& webserver_request);
