@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -27,13 +27,12 @@
 #include <database/bibleimages.h>
 #include <styles/logic.h>
 #include <locale/translate.h>
-using namespace std;
 
 
-Checks_Usfm::Checks_Usfm (const string & bible)
+Checks_Usfm::Checks_Usfm (const std::string& bible)
 {
   Database_Styles database_styles {};
-  string stylesheet = Database_Config_Bible::getExportStylesheet (bible);
+  const std::string stylesheet = database::config::bible::get_export_stylesheet (bible);
   markers_stylesheet = database_styles.getMarkers (stylesheet);
   for (const auto & marker : markers_stylesheet) {
     Database_Styles_Item style = database_styles.getMarkerData (stylesheet, marker);
@@ -102,12 +101,12 @@ void Checks_Usfm::finalize ()
 {
   // Check on unclosed markers.
   if (open_matching_markers.size () > 0) {
-    add_result (translate ("Unclosed markers:") + " " + filter_string_implode (open_matching_markers, " "), display_nothing);
+    add_result (translate ("Unclosed markers:") + " " + filter::strings::implode (open_matching_markers, " "), display_nothing);
   }
 }
 
 
-void Checks_Usfm::check (const string & usfm)
+void Checks_Usfm::check (const std::string& usfm)
 {
   new_line_in_usfm (usfm);
   
@@ -122,8 +121,8 @@ void Checks_Usfm::check (const string & usfm)
       
       // Get the current verse number.
       if (usfm_item == R"(\v )") {
-        string verseCode = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
-        verse_number = convert_to_int (filter::usfm::peek_verse_number (verseCode));
+        std::string verseCode = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
+        verse_number = filter::strings::convert_to_int (filter::usfm::peek_verse_number (verseCode));
       }
       
       malformed_verse_number ();
@@ -153,10 +152,10 @@ void Checks_Usfm::check (const string & usfm)
 void Checks_Usfm::malformed_verse_number ()
 {
   if (usfm_item == "\\v ") {
-    string code = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
-    string cleanVerseNumber = filter::usfm::peek_verse_number (code);
-    vector <string> v_dirtyVerseNumber = filter_string_explode (code, ' ');
-    string dirtyVerseNumber;
+    const std::string code = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
+    const std::string cleanVerseNumber = filter::usfm::peek_verse_number (code);
+    std::vector <std::string> v_dirtyVerseNumber = filter::strings::explode (code, ' ');
+    std::string dirtyVerseNumber {};
     if (!v_dirtyVerseNumber.empty ()) dirtyVerseNumber = v_dirtyVerseNumber [0];
     if (cleanVerseNumber != dirtyVerseNumber) {
       add_result (translate ("Malformed verse number"), display_full);
@@ -165,21 +164,21 @@ void Checks_Usfm::malformed_verse_number ()
 }
 
 
-void Checks_Usfm::new_line_in_usfm (const string & usfm)
+void Checks_Usfm::new_line_in_usfm (const std::string& usfm)
 {
-  size_t position {string::npos};
+  size_t position {std::string::npos};
   size_t pos = usfm.find ("\\\n");
-  if (pos != string::npos) {
+  if (pos != std::string::npos) {
     position = pos;
   }
   pos = usfm.find ("\\ \n");
-  if (pos != string::npos) {
+  if (pos != std::string::npos) {
     position = pos;
   }
-  if (position != string::npos) {
+  if (position != std::string::npos) {
     if (position == 0) position = 1;
-    string bit = usfm.substr (position - 1, 10);
-    bit = filter_string_str_replace ("\n", " ", bit);
+    std::string bit = usfm.substr (position - 1, 10);
+    bit = filter::strings::replace ("\n", " ", bit);
     add_result (translate ("New line within USFM:") + " " + bit, display_nothing);
   }
 }
@@ -187,8 +186,8 @@ void Checks_Usfm::new_line_in_usfm (const string & usfm)
 
 void Checks_Usfm::marker_in_stylesheet ()
 {
-  string marker = usfm_item.substr (1);
-  marker = filter_string_trim (marker);
+  std::string marker = usfm_item.substr (1);
+  marker = filter::strings::trim (marker);
   if (!filter::usfm::is_opening_marker (marker)) {
     if (!marker.empty ()) marker = marker.substr (0, marker.length () - 1);
   }
@@ -203,20 +202,20 @@ void Checks_Usfm::marker_in_stylesheet ()
 
 void Checks_Usfm::malformed_id ()
 {
-  string item = usfm_item.substr (0, 3);
-  string ide = usfm_item.substr (0, 4);
+  const std::string item = usfm_item.substr (0, 3);
+  const std::string ide = usfm_item.substr (0, 4);
   if (ide == R"(\ide)") return;
   if (item == R"(\id)") {
-    string code = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
-    string sid = code.substr (0, 3);
-    vector <string> vid = filter_string_explode (code, ' ');
-    string id {};
+    const std::string code = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
+    const std::string sid = code.substr (0, 3);
+    const std::vector <std::string> vid = filter::strings::explode (code, ' ');
+    std::string id {};
     if (!vid.empty ()) id = vid [0];
     book_id book = database::books::get_id_from_usfm (id);
     if (book == book_id::_unknown) {
       add_result (translate ("Unknown ID"), display_full);
     } else {
-      if (unicode_string_uppercase (id) != id) {
+      if (filter::strings::unicode_string_uppercase (id) != id) {
         add_result (translate ("ID is not in uppercase"), display_full);
       }
     }
@@ -224,23 +223,23 @@ void Checks_Usfm::malformed_id ()
 }
 
 
-void Checks_Usfm::forward_slash (const string & usfm)
+void Checks_Usfm::forward_slash (const std::string& usfm)
 {
-  string code = filter_string_str_replace ("\n", " ", usfm);
+  const std::string code = filter::strings::replace ("\n", " ", usfm);
   size_t pos = code.find ("/");
-  string bit {};
-  if (pos != string::npos) {
+  std::string bit {};
+  if (pos != std::string::npos) {
     size_t pos2 = code.find (" ", pos);
-    if (pos2 != string::npos) {
+    if (pos2 != std::string::npos) {
       bit = code.substr (pos, pos2 - pos);
     } else {
       bit = code.substr (pos, 100);
     }
     pos2 = bit.find ("*");
-    if (pos2 != string::npos) {
+    if (pos2 != std::string::npos) {
       bit = bit.substr (0, pos2);
     }
-    string marker = bit.substr (1, 100);
+    const std::string marker = bit.substr (1, 100);
     if (find (markers_stylesheet.begin(), markers_stylesheet.end(), marker) != markers_stylesheet.end ()) {
       add_result (translate ("Forward slash instead of backslash:") + " " + bit, display_nothing);
     }
@@ -250,8 +249,8 @@ void Checks_Usfm::forward_slash (const string & usfm)
 
 void Checks_Usfm::widow_back_slash ()
 {
-  string marker = usfm_item;
-  marker = filter_string_trim (marker);
+  std::string marker = usfm_item;
+  marker = filter::strings::trim (marker);
   if (marker.length() == 1) {
     add_result (translate ("Widow backslash"), display_current);
   }
@@ -260,10 +259,10 @@ void Checks_Usfm::widow_back_slash ()
 
 void Checks_Usfm::matching_endmarker ()
 {
-  string marker = usfm_item;
+  std::string marker = usfm_item;
   // Remove the initial backslash, e.g. '\add' becomes 'add'.
   marker = marker.substr (1);
-  marker = filter_string_trim (marker);
+  marker = filter::strings::trim (marker);
   bool isOpener = filter::usfm::is_opening_marker (marker);
   if (!isOpener) {
    if (!marker.empty ()) marker = marker.substr (0, marker.length () - 1);
@@ -277,9 +276,9 @@ void Checks_Usfm::matching_endmarker ()
     }
   } else {
     if (in_array (marker, open_matching_markers)) {
-      open_matching_markers = filter_string_array_diff (open_matching_markers, {marker});
+      open_matching_markers = filter::strings::array_diff (open_matching_markers, {marker});
     } else {
-      add_result (translate ("Closing marker does not match opening marker") + " " + filter_string_implode (open_matching_markers, " "), display_current);
+      add_result (translate ("Closing marker does not match opening marker") + " " + filter::strings::implode (open_matching_markers, " "), display_current);
     }
   }
 }
@@ -288,13 +287,13 @@ void Checks_Usfm::matching_endmarker ()
 void Checks_Usfm::embedded_marker ()
 {
   // The marker, e.g. '\add'.
-  string marker = usfm_item;
+  std::string marker = usfm_item;
 
   // Remove the initial backslash, e.g. '\add' becomes 'add'.
   marker = marker.substr (1);
-  marker = filter_string_trim (marker);
+  marker = filter::strings::trim (marker);
 
-  bool isOpener = filter::usfm::is_opening_marker (marker);
+  const bool isOpener = filter::usfm::is_opening_marker (marker);
 
   // Clean a closing marker, e.g. '\add*' becomes '\add'.
   if (!isOpener) {
@@ -323,7 +322,7 @@ void Checks_Usfm::embedded_marker ()
     }
   } else {
     if (in_array (marker, open_embeddable_markers)) {
-      open_embeddable_markers = filter_string_array_diff (open_embeddable_markers, {marker});
+      open_embeddable_markers = filter::strings::array_diff (open_embeddable_markers, {marker});
       if (!open_embeddable_markers.empty ()) {
         checkEmbedding = true;
       }
@@ -338,17 +337,17 @@ void Checks_Usfm::embedded_marker ()
 }
 
 
-void Checks_Usfm::toc (string usfm)
+void Checks_Usfm::toc (std::string usfm)
 {
   // Only check the 66 canonical books.
   // Skip any of the other books.
-  book_type type = database::books::get_type (static_cast<book_id>(book_number));
+  const book_type type = database::books::get_type (static_cast<book_id>(book_number));
   if ((type == book_type::old_testament) || (type == book_type::new_testament)) {
 
     // Check on the presence of the table of contents markers in this chapter.
-    bool toc1_present = usfm.find (filter::usfm::get_opening_usfm (long_toc1_marker)) != string::npos;
-    bool toc2_present = usfm.find (filter::usfm::get_opening_usfm (short_toc2_marker)) != string::npos;
-    bool toc3_present = usfm.find (filter::usfm::get_opening_usfm (abbrev_toc3_marker)) != string::npos;
+    bool toc1_present = usfm.find (filter::usfm::get_opening_usfm (long_toc1_marker)) != std::string::npos;
+    bool toc2_present = usfm.find (filter::usfm::get_opening_usfm (short_toc2_marker)) != std::string::npos;
+    bool toc3_present = usfm.find (filter::usfm::get_opening_usfm (abbrev_toc3_marker)) != std::string::npos;
 
     // The markers should be on chapter 0 only.
     if (chapter_number == 0) {
@@ -361,7 +360,7 @@ void Checks_Usfm::toc (string usfm)
         add_result (translate ("The book lacks the marker for the short book name:") + " " + filter::usfm::get_opening_usfm (short_toc2_marker), display_nothing);
       }
     } else {
-      string msg = translate ("The following marker belongs in chapter 0:") + " ";
+      const std::string msg = translate ("The following marker belongs in chapter 0:") + " ";
       // Required markers.
       if (toc1_present) {
         add_result (msg + filter::usfm::get_opening_usfm (long_toc1_marker), display_nothing);
@@ -381,36 +380,35 @@ void Checks_Usfm::toc (string usfm)
 void Checks_Usfm::figure ()
 {
   if (usfm_item == R"(\fig )") {
-    string usfm = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
-    string caption, alt, src, size, loc, copy, ref;
+    std::string usfm = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
+    std::string caption, alt, src, size, loc, copy, ref;
     filter::usfm::extract_fig (usfm, caption, alt, src, size, loc, copy, ref);
     if (src.empty()) {
       add_result (translate ("Empty figure source:") + " " + usfm, display_nothing);
     } else {
-      Database_BibleImages database_bibleimages;
-      string image_contents = database_bibleimages.get (src);
+      const std::string image_contents = database::bible_images::get (src);
       if (image_contents.empty()) {
         add_result (translate ("Could not find Bible image:") + " " + src, display_nothing);
       }
     }
-    size_t pos = usfm.find("“");
-    if (pos != string::npos) {
+    const size_t pos = usfm.find("“");
+    if (pos != std::string::npos) {
       add_result (translate ("Unusual quotation mark found:") + " " + usfm, display_nothing);
     }
   }
 }
 
 
-vector <pair<int, string>> Checks_Usfm::get_results ()
+std::vector <std::pair<int, std::string>> Checks_Usfm::get_results ()
 {
   return checking_results;
 }
 
 
-void Checks_Usfm::add_result (string text, int modifier)
+void Checks_Usfm::add_result (std::string text, int modifier)
 {
-  string current = usfm_item;
-  string next = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
+  std::string current = usfm_item;
+  std::string next = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
   next = next.substr (0, 20);
   switch (modifier) {
     case display_nothing:
@@ -427,7 +425,7 @@ void Checks_Usfm::add_result (string text, int modifier)
     default:
       break;
   }
-  checking_results.push_back (pair (verse_number, text));
+  checking_results.push_back (std::pair (verse_number, text));
 }
 
 
@@ -435,7 +433,7 @@ void Checks_Usfm::add_result (string text, int modifier)
 void Checks_Usfm::empty_markup ()
 {
   // Get the current item (markup or text).
-  string current_item = usfm_item;
+  const std::string current_item = usfm_item;
 
   // Flags that will describe the current item.
   // bool current_is_text = false;
@@ -506,7 +504,7 @@ void Checks_Usfm::note ()
   // From here on it is assumed that the current item is USFM, not text.
 
   // Get the plain marker, e.g. '\f ' becomes "f".
-  string current_marker = filter::usfm::get_marker (usfm_item);
+  const std::string current_marker = filter::usfm::get_marker (usfm_item);
   
   // Get this style's properties.
   Database_Styles_Item style = style_items [current_marker];
@@ -531,7 +529,7 @@ void Checks_Usfm::note ()
   if (!within_note) return;
 
   // Get the next item, that is the item following the current item.
-  string next_item = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
+  const std::string next_item = filter::usfm::peek_text_following_marker (usfm_markers_and_text, usfm_markers_and_text_pointer);
   
   // Flags that describe the next item.
   bool next_is_text {false};
@@ -550,7 +548,7 @@ void Checks_Usfm::note ()
 
   // Change, e.g. '\f ' to '\f'.
   // Remove the initial backslash, e.g. '\f' becomes 'f'.
-  string next_marker = filter::usfm::get_marker(next_item);
+  const std::string next_marker = filter::usfm::get_marker(next_item);
 
   // If the current item is opening markup ...
   if (!current_is_opener) return;
