@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2024 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -76,10 +76,16 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <limits>
 #include <atomic>
 #include <unordered_map>
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
 #include <codecvt>
+#pragma clang diagnostic pop
 #include <memory>
 #include <tuple>
-//#include <filesystem>
+#ifdef USE_STD_FILESYSTEM
+#include <filesystem>
+#endif
+#include <optional>
 
 
 // Headers dependencies.
