@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -26,7 +26,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <database/logs.h>
 #include <database/logic.h>
 #include <database/config/general.h>
-using namespace std;
 
 
 // Databases resilience:
@@ -35,34 +34,39 @@ using namespace std;
 // Often read from.
 
 
-string Database_Cache::fragment ()
-{
-  return "cache_resource_";
-}
+namespace database::cache::sql {
 
 
-string Database_Cache::path (string resource, int book)
-{
-  return filter_url_create_path ({database_logic_databases (), filename (filter_url_urlencode (resource), book) + database_sqlite_suffix ()});
-}
+constexpr auto max_book {100};
 
-
-string Database_Cache::filename (string resource, int book)
+static std::string filename (std::string resource, int book)
 {
   // Name of the database for this resource.
   resource = filter_url_clean_filename (resource);
-  string book_fragment;
+  std::string book_fragment;
   if (book) {
-    book_fragment = "_" + filter::strings::convert_to_string (book);
+    book_fragment = "_" + std::to_string (book);
   }
   return fragment () + resource + book_fragment;
 }
 
 
-void Database_Cache::create (string resource, int book)
+std::string fragment ()
 {
-  SqliteDatabase sql = SqliteDatabase (filename (resource, book));
+  return "cache_resource_";
+}
 
+
+std::string path (const std::string& resource, int book)
+{
+  return filter_url_create_path ({database_logic_databases (), filename (filter_url_urlencode (resource), book) + database::sqlite::suffix ()});
+}
+
+
+void create (const std::string& resource, int book)
+{
+  SqliteDatabase sql (filename (resource, book));
+  
   sql.add ("CREATE TABLE IF NOT EXISTS cache (chapter integer, verse integer, value text);");
   sql.execute ();
   
@@ -73,17 +77,17 @@ void Database_Cache::create (string resource, int book)
 }
 
 
-void Database_Cache::remove (string resource)
+void remove (const std::string& resource)
 {
-  for (int book = 0; book < 100; book++) {
+  for (int book = 0; book < max_book; book++) {
     remove (resource, book);
   }
 }
 
 
-void Database_Cache::remove (string resource, int book)
+void remove (const std::string& resource, int book)
 {
-  string file = database_sqlite_file (filename (resource, book));
+  const std::string file = database::sqlite::get_file (filename (resource, book));
   if (file_or_dir_exists (file)) {
     filter_url_unlink (file);
   }
@@ -91,25 +95,26 @@ void Database_Cache::remove (string resource, int book)
 
 
 // Returns true if the cache for the $resource exists.
-bool Database_Cache::exists (string resource)
+bool exists (const std::string& resource)
 {
-  for (int book = 0; book < 100; book++) {
-    if (exists (resource, book)) return true;
+  for (int book = 0; book < max_book; book++) {
+    if (exists (resource, book))
+      return true;
   }
   return false;
 }
 
 
 // Returns true if the cache for the $resource $book exists.
-bool Database_Cache::exists (string resource, int book)
+bool exists (const std::string& resource, int book)
 {
-  string file = database_sqlite_file (filename (resource, book));
+  const std::string file = database::sqlite::get_file (filename (resource, book));
   return file_or_dir_exists (file);
 }
 
 
 // Returns true if a cached value for $resource/book/chapter/verse exists.
-bool Database_Cache::exists (string resource, int book, int chapter, int verse)
+bool exists (const std::string& resource, int book, int chapter, int verse)
 {
   // If the the book-based cache exists, check existence from there.
   if (exists (resource, book)) {
@@ -119,9 +124,10 @@ bool Database_Cache::exists (string resource, int book, int chapter, int verse)
     sql.add ("AND verse = ");
     sql.add (verse);
     sql.add (";");
-    vector <string> result = sql.query () ["count(*)"];
+    std::vector <std::string> result = sql.query () ["count(*)"];
     int count = 0;
-    if (!result.empty ()) count = filter::strings::convert_to_int (result [0]);
+    if (!result.empty ()) 
+      count = filter::strings::convert_to_int (result.at(0));
     return (count > 0);
   }
   // Else if the previous cache layout exists, check that.
@@ -134,9 +140,10 @@ bool Database_Cache::exists (string resource, int book, int chapter, int verse)
     sql.add ("AND verse = ");
     sql.add (verse);
     sql.add (";");
-    vector <string> result = sql.query () ["count(*)"];
+    std::vector <std::string> result = sql.query () ["count(*)"];
     int count = 0;
-    if (!result.empty ()) count = filter::strings::convert_to_int (result [0]);
+    if (!result.empty ()) 
+      count = filter::strings::convert_to_int (result [0]);
     return (count > 0);
   }
   // Nothing exists.
@@ -145,10 +152,10 @@ bool Database_Cache::exists (string resource, int book, int chapter, int verse)
 
 
 // Caches a value.
-void Database_Cache::cache (string resource, int book, int chapter, int verse, string value)
+void cache (const std::string& resource, int book, int chapter, int verse, const std::string& value)
 {
-  SqliteDatabase sql = SqliteDatabase (filename (resource, book));
-
+  SqliteDatabase sql (filename (resource, book));
+  
   sql.clear ();
   sql.add ("DELETE FROM cache WHERE chapter = ");
   sql.add (chapter);
@@ -170,7 +177,7 @@ void Database_Cache::cache (string resource, int book, int chapter, int verse, s
 
 
 // Retrieves a cached value.
-string Database_Cache::retrieve (string resource, int book, int chapter, int verse)
+std::string retrieve (const std::string& resource, const int book, const int chapter, const int verse)
 {
   // If the the book-based cache exists, retrieve it from there.
   if (exists (resource, book)) {
@@ -180,9 +187,10 @@ string Database_Cache::retrieve (string resource, int book, int chapter, int ver
     sql.add ("AND verse = ");
     sql.add (verse);
     sql.add (";");
-    vector <string> result = sql.query () ["value"];
-    if (result.empty ()) return "";
-    return result [0];
+    const std::vector <std::string> result = sql.query () ["value"];
+    if (result.empty ())
+      return std::string();
+    return result.at(0);
   }
   // Else if the previous cache layout exists, retrieve it from there.
   if (exists (resource, 0)) {
@@ -194,20 +202,21 @@ string Database_Cache::retrieve (string resource, int book, int chapter, int ver
     sql.add ("AND verse = ");
     sql.add (verse);
     sql.add (";");
-    vector <string> result = sql.query () ["value"];
-    if (result.empty ()) return "";
-    return result [0];
+    const std::vector <std::string> result = sql.query () ["value"];
+    if (result.empty ())
+      return std::string();
+    return result.at(0);
   }
-  return "";
+  return std::string();
 }
 
 
 // Returns how many element are in cache $resource.
-int Database_Cache::count (string resource)
+int count (const std::string& resource)
 {
   int count = 0;
   // Book 0 is for the old layout. Book 1++ is for the new layout.
-  for (int book = 0; book < 100; book++) {
+  for (int book = 0; book < max_book; book++) {
     if (exists (resource, book)) {
       count ++;
     }
@@ -217,13 +226,13 @@ int Database_Cache::count (string resource)
 
 
 // Return true if the database has loaded all its expected content.
-bool Database_Cache::ready (string resource, int book)
+bool ready (const std::string& resource, const int book)
 {
-  SqliteDatabase sql = SqliteDatabase (filename (resource, book));
+  SqliteDatabase sql (filename (resource, book));
   sql.add ("SELECT ready FROM ready;");
-  vector <string> result = sql.query () ["ready"];
+  const std::vector <std::string> result = sql.query () ["ready"];
   if (!result.empty()) {
-    auto ready = result[0];
+    const auto ready = result.at(0);
     return filter::strings::convert_to_bool (ready);
   }
   return false;
@@ -231,9 +240,9 @@ bool Database_Cache::ready (string resource, int book)
 
 
 // Sets the 'ready' flag in the database.
-void Database_Cache::ready (string resource, int book, bool ready)
+void ready (const std::string& resource, const int book, const bool ready)
 {
-  SqliteDatabase sql = SqliteDatabase (filename (resource, book));
+  SqliteDatabase sql (filename (resource, book));
   
   sql.clear ();
   sql.add ("DELETE FROM ready;");
@@ -247,14 +256,20 @@ void Database_Cache::ready (string resource, int book, bool ready)
 }
 
 
-int Database_Cache::size (string resource, int book)
+int size (const std::string& resource, const int book)
 {
-  string file = database_sqlite_file (filename (resource, book));
+  const std::string file = database::sqlite::get_file (filename (resource, book));
   return filter_url_filesize (file);
 }
 
 
-string database_cache_full_path (string file)
+} // namespace.
+
+
+namespace database::cache::file {
+
+
+static std::string full_path (std::string file)
 {
   return filter_url_create_root_path ({database_logic_databases (), "cache", file});
 }
@@ -263,7 +278,7 @@ string database_cache_full_path (string file)
 // The purpose of splitting the file up into paths is
 // to avoid that the cache folder would contain too many files
 // and so would become slow.
-string database_cache_split_file (string file)
+static std::string split_file (std::string file)
 {
   if (file.size () > 9) file.insert (9, "/");
   if (file.size () > 18) file.insert (18, "/");
@@ -273,166 +288,73 @@ string database_cache_split_file (string file)
 }
 
 
-bool database_filebased_cache_exists (string schema)
+bool exists (std::string schema)
 {
   schema = filter_url_clean_filename (schema);
-  schema = database_cache_split_file (schema);
-  schema = database_cache_full_path (schema);
+  schema = database::cache::file::split_file (schema);
+  schema = database::cache::file::full_path (schema);
   return file_or_dir_exists (schema);
 }
 
 
-void database_filebased_cache_put (string schema, string contents)
+void put (std::string schema, const std::string& contents)
 {
   schema = filter_url_clean_filename (schema);
-  schema = database_cache_split_file (schema);
-  schema = database_cache_full_path (schema);
-  string path = filter_url_dirname (schema);
-  if (!file_or_dir_exists (path)) filter_url_mkdir (path);
+  schema = split_file (schema);
+  schema = full_path (schema);
+  const std::string path = filter_url_dirname (schema);
+  if (!file_or_dir_exists (path)) 
+    filter_url_mkdir (path);
   filter_url_file_put_contents (schema, contents);
 }
 
 
-string database_filebased_cache_get (string schema)
+std::string get (std::string schema)
 {
   schema = filter_url_clean_filename (schema);
-  schema = database_cache_split_file (schema);
-  schema = database_cache_full_path (schema);
+  schema = database::cache::file::split_file (schema);
+  schema = database::cache::file::full_path (schema);
   return filter_url_file_get_contents (schema);
 }
 
 
-void database_filebased_cache_remove (string schema)
+void remove (std::string schema)
 {
   schema = filter_url_clean_filename (schema);
-  schema = database_cache_split_file (schema);
-  schema = database_cache_full_path (schema);
+  schema = split_file (schema);
+  schema = full_path (schema);
   filter_url_unlink (schema);
 }
 
 
-// Create a file name based on the client's IPv4 and a unique data identifier.
-string database_filebased_cache_name_by_ip (string address, string id)
-{
-  id = "_" + id;
-  string ipv4_sp = "::ffff:";
-  const unsigned long pos = address.find (ipv4_sp);
-  if (address.find (ipv4_sp) != string::npos) address.erase (pos, ipv4_sp.length ());
-  if (address.find (id) == string::npos) address.append (id);
-  return address;
-}
-
-
-// Create a file name based on the client's session id and a unique
-// data identifier.
-string database_filebased_cache_name_by_session_id (string sid, string id)
-{
-  id = "_" + id;
-  if (sid.find (id) == string::npos) sid.append (id);
-  return sid;
-}
-
-
-// File name for focused book file based database cache by session id
-// plus abbreviation.
-string focused_book_filebased_cache_filename (string sid)
-{
-  return database_filebased_cache_name_by_session_id (sid, "focbo");
-}
-
-
-// File name for focused chapter file based database cache by session
-// id plus abbreviation.
-string focused_chapter_filebased_cache_filename (string sid)
-{
-  return database_filebased_cache_name_by_session_id (sid, "focch");
-}
-
-
-// File name for focused verse file based database cache by session id
-// plus abbreviation.
-string focused_verse_filebased_cache_filename (string sid)
-{
-  return database_filebased_cache_name_by_session_id (sid, "focve");
-}
-
-
-// File name for general font size file based database cache by
-// session id plus abbreviation.
-string general_font_size_filebased_cache_filename (string sid)
-{
-  return database_filebased_cache_name_by_session_id (sid, "genfs");
-}
-
-
-// File name for menu font size file based database cache by session
-// id plus abbreviation.
-string menu_font_size_filebased_cache_filename (string sid)
-{
-  return database_filebased_cache_name_by_session_id (sid, "menfs");
-}
-
-
-// File name for resource font size file based database cache by
-// session id plus abbreviation.
-string resource_font_size_filebased_cache_filename (string sid)
-{
-  return database_filebased_cache_name_by_session_id (sid, "resfs");
-}
-
-
-// File name for hebrew font size file based database cache by
-// session id plus abbreviation.
-string hebrew_font_size_filebased_cache_filename (string sid)
-{
-  return database_filebased_cache_name_by_session_id (sid, "hebfs");
-}
-
-
-// File name for greek font size file based database cache by session
-// id plus abbreviation.
-string greek_font_size_filebased_cache_filename (string sid)
-{
-  return database_filebased_cache_name_by_session_id (sid, "grefs");
-}
-
-
-// File name for current theme file based database cache by session
-// id plus abbreviation.
-string current_theme_filebased_cache_filename (string sid)
-{
-  return database_filebased_cache_name_by_session_id (sid, "curth");
-}
-
-
 // Deletes expired cached items.
-void database_cache_trim (bool clear)
+void trim (bool clear)
 {
-  if (clear) Database_Logs::log ("Clearing cache");
-
-  string output, error;
-
+  if (clear)
+    Database_Logs::log ("Clearing cache");
+  
   // The directory that contains the file-based cache files.
-  string path = database_cache_full_path ("");
+  std::string path = database::cache::file::full_path ("");
   
   // Get the free space on the file system that contains the cache.
-  output.clear ();
-  error.clear ();
-  filter_shell_run (path, "df", {"."}, &output, &error);
-  if (!error.empty ()) Database_Logs::log (error);
-  int percentage_disk_in_use = 0;
+  std::string output, error;
+  filter::shell::run (path, filter::shell::get_executable(filter::shell::Executable::df), {"."}, &output, &error);
+  if (!error.empty ())
+    Database_Logs::log (error);
+  int percentage_disk_in_use {0};
   {
-    vector<string> bits = filter::strings::explode(output, ' ');
-    for (auto bit : bits) {
-      if (bit.find ("%") != string::npos) {
+    const std::vector<std::string> bits = filter::strings::explode(output, ' ');
+    for (const auto& bit : bits) {
+      if (bit.find ("%") != std::string::npos) {
         percentage_disk_in_use = filter::strings::convert_to_int(bit);
         // If a real percentage was found, other than 0, then skip the remainder.
         // On macOS the first percentage found is %iused, so will be skipped.
-        if (percentage_disk_in_use != 0) break;
+        if (percentage_disk_in_use != 0)
+          break;
       }
     }
   }
-  Database_Logs::log ("Disk space in use is " + filter::strings::convert_to_string(percentage_disk_in_use) + "%");
+  Database_Logs::log ("Disk space in use is " + std::to_string(percentage_disk_in_use) + "%");
   
   // There have been instances that the cache takes up 4, 5, or 6 Gbytes in the Cloud.
   // If the cache is left untrimmed, the size can be even larger.
@@ -440,14 +362,17 @@ void database_cache_trim (bool clear)
   // Therefore it's good to remove cached files older than a couple of hours
   // in cases where disk space is tight.
   // Two hours.
-  string minutes = "+120";
+  std::string minutes = "+120";
   // One day.
-  if (percentage_disk_in_use < 70) minutes = "+1440";
+  if (percentage_disk_in_use < 70)
+    minutes = "+1440";
   // One week.
-  if (percentage_disk_in_use < 50) minutes = "+10080";
-
+  if (percentage_disk_in_use < 50)
+    minutes = "+10080";
+  
   // Handle clearing the cache immediately.
-  if (clear) minutes = "+0";
+  if (clear)
+    minutes = "+0";
   
   // Remove files that have not been modified for x minutes.
   // It uses a Linux shell command.
@@ -460,62 +385,80 @@ void database_cache_trim (bool clear)
   // The fix is to do "cd /path/to/cache; find . ...".
   output.clear ();
   error.clear ();
-  filter_shell_run (path, "find", {".", "-amin", minutes, "-delete"}, &output, &error);
+  filter::shell::run (path, filter::shell::get_executable(filter::shell::Executable::find), {".", "-amin", minutes, "-delete"}, &output, &error);
   if (!output.empty ()) Database_Logs::log (output);
   if (!error.empty ()) Database_Logs::log (error);
   
   // Remove empty directories.
   output.clear ();
   error.clear ();
-  filter_shell_run (path, "find", {".", "-type", "d", "-empty", "-delete"}, &output, &error);
+  filter::shell::run (path, filter::shell::get_executable(filter::shell::Executable::find), {".", "-type", "d", "-empty", "-delete"}, &output, &error);
   if (!output.empty ()) Database_Logs::log (output);
   if (!error.empty ()) Database_Logs::log (error);
   
   // The directory that contains the database-based cache files.
   path = filter_url_create_root_path ({database_logic_databases ()});
-
+  
   // The number of days to keep cached data depends on the percentage of the disk in use.
   // There have been instances that the cache takes up 4, 5, or 6 Gbytes in the Cloud.
   // This can be even more.
   // This may lead to errors when the disk runs out of space.
   // Therefore it's good to limit caches more if the space is tight.
   // By default keep the resources cache for 30 days.
-  string days = "+30";
+  std::string days = "+30";
   // If keeping the resources cache for an extended period of time, keep it for a full year.
-  if (Database_Config_General::getKeepResourcesCacheForLong()) days = "+365";
+  if (database::config::general::get_keep_resources_cache_for_long())
+    days = "+365";
   // If free disk space is tighter, keep the caches for a shorter period.
-  if (percentage_disk_in_use > 80) days = "+14";
-  if (percentage_disk_in_use > 85) days = "+7";
-  if (percentage_disk_in_use > 90) days = "+1";
-
+  if (percentage_disk_in_use > 80)
+    days = "+14";
+  if (percentage_disk_in_use > 85)
+    days = "+7";
+  if (percentage_disk_in_use > 90)
+    days = "+1";
+  
   // Handle clearing the cache immediately.
-  if (clear) days = "0";
-
+  if (clear)
+    days = "0";
+  
   Database_Logs::log ("Will remove resource caches not accessed for " + days + " days");
   
   // Remove database-based cached files that have not been modified for x days.
   output.clear ();
   error.clear ();
-  filter_shell_run (path, "find", {path, "-name", Database_Cache::fragment () + "*", "-atime", days, "-delete"}, &output, &error);
+  filter::shell::run (path, filter::shell::get_executable(filter::shell::Executable::find), {path, "-name", database::cache::sql::fragment () + "*", "-atime", days, "-delete"}, &output, &error);
   if (!output.empty ()) Database_Logs::log (output);
   if (!error.empty ()) Database_Logs::log (error);
   
-  if (clear) Database_Logs::log ("Ready clearing  cache");
+  if (clear)
+    Database_Logs::log ("Ready clearing  cache");
 }
 
 
+} // namespace.
+
+
+namespace database::cache {
+
+
 // This returns true if the $html can be cached.
-bool database_cache_can_cache (const string & error, const string & html)
+bool can_cache (const std::string& error, const std::string& html)
 {
   // Normally if everything is fine, then caching is possible.
   bool cache = true;
   
   // Do not cache the data in an error situation.
   if (!error.empty()) cache = false;
-
-  // Do not cache the data if Cloudflare does DDoS protection.
+  
+  // Do not cache the data if Cloudflare does any kind of protection.
   // https://github.com/bibledit/cloud/issues/693.
-  if (html.find ("Cloudflare") != string::npos) cache = false;
-
+  if (html.find ("Cloudflare") != std::string::npos) cache = false;
+  
   return cache;
 }
+
+
+} // namespace.
+
+
+
