@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -19,11 +19,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include <database/check.h>
 #include <filter/url.h>
+#include <filter/passage.h>
 #include <filter/string.h>
 #include <config/globals.h>
 #include <database/sqlite.h>
+#include <database/check.h>
 #include <locale/translate.h>
-using namespace std;
 
 
 // Database resilience.
@@ -35,19 +36,19 @@ using namespace std;
 // before running setup.
 
 
-const char * Database_Check::filename ()
+constexpr const auto database_name {"check"};
+
+
+namespace database::check {
+
+
+void create ()
 {
-  return "check";
-}
-
-
-void Database_Check::create ()
-{
-  SqliteDatabase sql (filename ());
-
+  SqliteDatabase sql (database_name);
+  
   sql.add ("DROP TABLE IF EXISTS output;");
   sql.execute ();
-
+  
   sql.clear ();
   
   sql.add ("CREATE TABLE IF NOT EXISTS output2 ("
@@ -65,7 +66,7 @@ void Database_Check::create ()
   sql.execute ();
   
   sql.clear ();
-
+  
   sql.add ("CREATE TABLE IF NOT EXISTS suppress2 ("
            " bible text,"
            " book integer,"
@@ -77,17 +78,17 @@ void Database_Check::create ()
 }
 
 
-void Database_Check::optimize ()
+void optimize ()
 {
-  SqliteDatabase sql (filename ());
+  SqliteDatabase sql (database_name);
   sql.add ("VACUUM;");
   sql.execute ();
 }
 
 
-void Database_Check::truncateOutput (string bible)
+void truncate_output (const std::string& bible)
 {
-  SqliteDatabase sql (filename ());
+  SqliteDatabase sql (database_name);
   if (bible == "") {
     sql.add ("DELETE FROM output2;");
   } else {
@@ -99,9 +100,9 @@ void Database_Check::truncateOutput (string bible)
 }
 
 
-void Database_Check::recordOutput (string bible, int book, int chapter, int verse, string data)
+void record_output (const std::string& bible, int book, int chapter, int verse, std::string data)
 {
-  SqliteDatabase sql (filename ());
+  SqliteDatabase sql (database_name);
   int count = 0;
   // Check whether this is a suppressed item.
   // If it was suppressed, do not record it.
@@ -117,9 +118,9 @@ void Database_Check::recordOutput (string bible, int book, int chapter, int vers
   sql.add ("AND data = ");
   sql.add (data);
   sql.add (";");
-  vector <string> result = sql.query () ["count(*)"];
+  std::vector <std::string> result = sql.query () ["count(*)"];
   if (!result.empty ()) {
-    count = convert_to_int (result [0]);
+    count = filter::strings::convert_to_int (result [0]);
   }
   if (count == 0) {
     // Check how often $data has been recorded already.
@@ -129,9 +130,9 @@ void Database_Check::recordOutput (string bible, int book, int chapter, int vers
     sql.add ("AND data = ");
     sql.add (data);
     sql.add (";");
-    vector <string> count_result = sql.query () ["count(*)"];
+    std::vector <std::string> count_result = sql.query () ["count(*)"];
     if (!count_result.empty ()) {
-      count = convert_to_int (count_result [0]);
+      count = filter::strings::convert_to_int (count_result [0]);
     }
     // Record the data no more than so often.
     if (count < 10) {
@@ -174,25 +175,25 @@ void Database_Check::recordOutput (string bible, int book, int chapter, int vers
 }
 
 
-vector <Database_Check_Hit> Database_Check::getHits ()
+std::vector <database::check::Hit> get_hits ()
 {
-  vector <Database_Check_Hit> hits;
-  SqliteDatabase sql (filename ());
+  std::vector <database::check::Hit> hits;
+  SqliteDatabase sql (database_name);
   sql.add ("SELECT rowid, bible, book, chapter, verse, data FROM output2;");
-  map <string, vector <string> > result = sql.query ();
-  vector <string> rowids = result ["rowid"];
-  vector <string> bibles = result ["bible"];
-  vector <string> books = result ["book"];
-  vector <string> chapters = result ["chapter"];
-  vector <string> verses = result ["verse"];
-  vector <string> data = result ["data"];
+  std::map <std::string, std::vector <std::string> > result = sql.query ();
+  std::vector <std::string> rowids = result ["rowid"];
+  std::vector <std::string> bibles = result ["bible"];
+  std::vector <std::string> books = result ["book"];
+  std::vector <std::string> chapters = result ["chapter"];
+  std::vector <std::string> verses = result ["verse"];
+  std::vector <std::string> data = result ["data"];
   for (unsigned int i = 0; i < rowids.size(); i++) {
-    Database_Check_Hit hit = Database_Check_Hit ();
-    hit.rowid = convert_to_int (rowids [i]);
+    database::check::Hit hit = database::check::Hit ();
+    hit.rowid = filter::strings::convert_to_int (rowids [i]);
     hit.bible = bibles [i];
-    hit.book = convert_to_int (books [i]);
-    hit.chapter = convert_to_int (chapters [i]);
-    hit.verse = convert_to_int (verses [i]);
+    hit.book = filter::strings::convert_to_int (books [i]);
+    hit.chapter = filter::strings::convert_to_int (chapters [i]);
+    hit.verse = filter::strings::convert_to_int (verses [i]);
     hit.data = data [i];
     hits.push_back (hit);
   }
@@ -200,10 +201,10 @@ vector <Database_Check_Hit> Database_Check::getHits ()
 }
 
 
-void Database_Check::approve (int id)
+void approve (int id)
 {
   // The query moves all values, apart from the auto_increment id.
-  SqliteDatabase sql (filename ());
+  SqliteDatabase sql (database_name);
   sql.add ("INSERT INTO suppress2 (bible, book, chapter, verse, data) SELECT bible, book, chapter, verse, data FROM output2 WHERE rowid =");
   sql.add (id);
   sql.add (";");
@@ -216,9 +217,9 @@ void Database_Check::approve (int id)
 }
 
 
-void Database_Check::erase (int id)
+void erase (int id)
 {
-  SqliteDatabase sql (filename ());
+  SqliteDatabase sql (database_name);
   sql.add ("DELETE FROM output2 WHERE rowid =");
   sql.add (id);
   sql.add (";");
@@ -226,43 +227,43 @@ void Database_Check::erase (int id)
 }
 
 
-Passage Database_Check::getPassage (int id)
+Passage get_passage (int id)
 {
-  SqliteDatabase sql (filename ());
+  SqliteDatabase sql (database_name);
   sql.add ("SELECT book, chapter, verse FROM output2 WHERE rowid =");
   sql.add (id);
   sql.add (";");
-  map <string, vector <string> > result = sql.query ();
-  vector <string> books = result ["book"];
-  vector <string> chapters = result ["chapter"];
-  vector <string> verses = result ["verse"];
+  std::map <std::string, std::vector <std::string> > result = sql.query ();
+  std::vector <std::string> books = result ["book"];
+  std::vector <std::string> chapters = result ["chapter"];
+  std::vector <std::string> verses = result ["verse"];
   if (!books.empty()) {
-    Passage passage = Passage ("", convert_to_int (books[0]), convert_to_int (chapters[0]), verses[0]);
+    Passage passage = Passage ("", filter::strings::convert_to_int (books[0]), filter::strings::convert_to_int (chapters[0]), verses[0]);
     return passage;
   }
   return Passage ("", 0, 0, "");
 }
 
 
-vector <Database_Check_Hit> Database_Check::getSuppressions ()
+std::vector <database::check::Hit> get_suppressions ()
 {
-  SqliteDatabase sql (filename ());
-  vector <Database_Check_Hit> hits;
+  SqliteDatabase sql (database_name);
+  std::vector <database::check::Hit> hits;
   sql.add ("SELECT rowid, bible, book, chapter, verse, data FROM suppress2;");
-  map <string, vector <string> > result = sql.query ();
-  vector <string> rowids = result ["rowid"];
-  vector <string> bibles = result ["bible"];
-  vector <string> books = result ["book"];
-  vector <string> chapters = result ["chapter"];
-  vector <string> verses = result ["verse"];
-  vector <string> data = result ["data"];
+  std::map <std::string, std::vector <std::string> > result = sql.query ();
+  std::vector <std::string> rowids = result ["rowid"];
+  std::vector <std::string> bibles = result ["bible"];
+  std::vector <std::string> books = result ["book"];
+  std::vector <std::string> chapters = result ["chapter"];
+  std::vector <std::string> verses = result ["verse"];
+  std::vector <std::string> data = result ["data"];
   for (unsigned int i = 0; i < rowids.size(); i++) {
-    Database_Check_Hit hit = Database_Check_Hit ();
-    hit.rowid = convert_to_int (rowids [i]);
+    database::check::Hit hit = database::check::Hit ();
+    hit.rowid = filter::strings::convert_to_int (rowids [i]);
     hit.bible = bibles [i];
-    hit.book = convert_to_int (books [i]);
-    hit.chapter = convert_to_int (chapters [i]);
-    hit.verse = convert_to_int (verses [i]);
+    hit.book = filter::strings::convert_to_int (books [i]);
+    hit.chapter = filter::strings::convert_to_int (chapters [i]);
+    hit.verse = filter::strings::convert_to_int (verses [i]);
     hit.data = data [i];
     hits.push_back (hit);
   }
@@ -270,9 +271,9 @@ vector <Database_Check_Hit> Database_Check::getSuppressions ()
 }
 
 
-void Database_Check::release (int id)
+void release (int id)
 {
-  SqliteDatabase sql (filename ());
+  SqliteDatabase sql (database_name);
   sql.add ("INSERT INTO output2 (bible, book, chapter, verse, data) SELECT bible, book, chapter, verse, data FROM suppress2 WHERE rowid =");
   sql.add (id);
   sql.add (";");
@@ -284,3 +285,5 @@ void Database_Check::release (int id)
   sql.execute ();
 }
 
+
+} // Namespace.
