@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -70,15 +70,14 @@ void database_maintenance ()
   database_users.optimize ();
   
   
-  Database_Mail database_mail = Database_Mail (&webserver_request);
+  Database_Mail database_mail (webserver_request);
   database_mail.trim ();
   database_mail.optimize ();
   
   
 #ifdef HAVE_CLOUD
-  Database_Confirm database_confirm;
-  database_confirm.trim ();
-  database_confirm.optimize ();
+  database::confirm::trim ();
+  database::confirm::optimize ();
 #endif
   
   
@@ -87,22 +86,20 @@ void database_maintenance ()
   // Database_Styles database_styles;
   
   
-  Database_Bibles database_bibles;
-  database_bibles.optimize ();
+  database::bibles::optimize ();
 
   
-  Database_Ipc database_ipc = Database_Ipc (&webserver_request);
+  Database_Ipc database_ipc (webserver_request);
   database_ipc.trim ();
   
   
-  Database_Notes database_notes = Database_Notes (&webserver_request);
+  Database_Notes database_notes (webserver_request);
   database_notes.trim ();
   if (!client_mode) database_notes.trim_server ();
   database_notes.optimize ();
   
   
-  Database_Check database_check = Database_Check ();
-  database_check.optimize ();
+  database::check::optimize ();
   
   
 #ifdef HAVE_CLOUD
@@ -121,7 +118,7 @@ void database_maintenance ()
   database_jobs.optimize ();
   
   
-  Database_Config_User database_config_user = Database_Config_User (&webserver_request);
+  Database_Config_User database_config_user (webserver_request);
   database_config_user.trim ();
   
   
@@ -133,7 +130,7 @@ void database_maintenance ()
   
   
 #ifdef HAVE_CLOUD
-  Database_Git::optimize ();
+  database::git::optimize ();
 #endif
 
   
