@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -43,6 +43,4 @@ public:
   void updateNotes (int oldId, int newId);
   void erase (int rowid);
   bool exists (int note);
-private:
-  sqlite3 * connect ();
 };
