@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/url.h>
 #include <filter/string.h>
 #include <database/sqlite.h>
-using namespace std;
 
 
 // Database resilience: It is only read from.
@@ -29,7 +28,7 @@ using namespace std;
 
 void Database_Sample::create ()
 {
-  string path = database_sqlite_file (name ());
+  std::string path = database::sqlite::get_file (name ());
   filter_url_unlink (path);
   SqliteDatabase sql = SqliteDatabase (name ());
   sql.add ("CREATE TABLE IF NOT EXISTS sample (file text, data text);");
@@ -38,7 +37,7 @@ void Database_Sample::create ()
 
 
 // Store a file and its data the sample.
-void Database_Sample::store (string file, string data)
+void Database_Sample::store (std::string file, std::string data)
 {
   SqliteDatabase sql = SqliteDatabase (name ());
   sql.add ("INSERT INTO sample VALUES (");
@@ -51,29 +50,29 @@ void Database_Sample::store (string file, string data)
 
 
 // Get the row identifiers in the database.
-vector <int> Database_Sample::get ()
+std::vector <int> Database_Sample::get ()
 {
   SqliteDatabase sql = SqliteDatabase (name ());
   sql.add ("SELECT rowid FROM sample;");
-  vector <string> rowids = sql.query () ["rowid"];
-  vector <int> ids;
+  std::vector <std::string> rowids = sql.query () ["rowid"];
+  std::vector <int> ids;
   for (auto rowid : rowids) ids.push_back (filter::strings::convert_to_int (rowid));
   return ids;
 }
 
 
 // Get a a file and its contents.
-void Database_Sample::get (int rowid, string & file, string & data)
+void Database_Sample::get (int rowid, std::string & file, std::string & data)
 {
   SqliteDatabase sql = SqliteDatabase (name ());
   sql.add ("SELECT file, data FROM sample WHERE rowid =");
   sql.add (rowid);
   sql.add (";");
-  map <string, vector <string> > sample = sql.query ();
-  vector <string> files = sample ["file"];
+  std::map <std::string, std::vector <std::string> > sample = sql.query ();
+  std::vector <std::string> files = sample ["file"];
   if (files.empty ()) file.clear ();
   else file = files [0];
-  vector <string> datas = sample ["data"];
+  std::vector <std::string> datas = sample ["data"];
   if (datas.empty ()) data.clear ();
   else data = datas [0];
 }
