@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/md5.h>
 #include <filter/roles.h>
 #include <filter/date.h>
-using namespace std;
 
 
 // This database is resilient.
@@ -52,13 +51,13 @@ void Database_Users::upgrade ()
   // if the columns are not yet there.
   SqliteDatabase sql (filename ());
   sql.add ("PRAGMA table_info (users);");
-  vector <string> columns = sql.query () ["name"];
-  if (!in_array (static_cast<string> ("ldap"), columns)) {
+  std::vector <std::string> columns = sql.query () ["name"];
+  if (!in_array (static_cast<std::string> ("ldap"), columns)) {
     sql.clear ();
     sql.add ("ALTER TABLE users ADD COLUMN ldap boolean;");
     sql.execute ();
   }
-  if (!in_array (static_cast<string> ("disabled"), columns)) {
+  if (!in_array (static_cast<std::string> ("disabled"), columns)) {
     sql.clear ();
     sql.add ("ALTER TABLE users ADD COLUMN disabled boolean;");
     sql.execute ();
@@ -80,7 +79,7 @@ void Database_Users::optimize ()
 
 
 // Add the user details to the database.
-void Database_Users::add_user (string user, string password, int level, string email)
+void Database_Users::add_user (std::string user, std::string password, int level, std::string email)
 {
   {
     SqliteDatabase sql (filename ());
@@ -98,7 +97,7 @@ void Database_Users::add_user (string user, string password, int level, string e
 
 
 // Updates the password for user.
-void Database_Users::set_password (string user, string password)
+void Database_Users::set_password (std::string user, std::string password)
 {
   SqliteDatabase sql (filename ());
   sql.add ("UPDATE users SET password =");
@@ -111,7 +110,7 @@ void Database_Users::set_password (string user, string password)
 
 
 // Returns true if the user and password match.
-bool Database_Users::matchUserPassword (string user, string password)
+bool Database_Users::matchUserPassword (std::string user, std::string password)
 {
   SqliteDatabase sql (filename ());
   sql.add ("SELECT username FROM users WHERE username =");
@@ -119,13 +118,13 @@ bool Database_Users::matchUserPassword (string user, string password)
   sql.add ("AND password =");
   sql.add (md5 (password));
   sql.add ("AND (disabled IS NULL OR disabled = 0);");
-  vector <string> result = sql.query () ["username"];
+  std::vector <std::string> result = sql.query () ["username"];
   return (!result.empty());
 }
 
 
 // Returns true if the email and password match.
-bool Database_Users::matchEmailPassword (string email, string password)
+bool Database_Users::matchEmailPassword (std::string email, std::string password)
 {
   SqliteDatabase sql (filename ());
   sql.add ("SELECT username FROM users WHERE email =");
@@ -133,87 +132,87 @@ bool Database_Users::matchEmailPassword (string email, string password)
   sql.add ("AND password =");
   sql.add (md5 (password));
   sql.add ("AND (disabled IS NULL OR disabled = 0);");
-  vector <string> result = sql.query () ["username"];
+  std::vector <std::string> result = sql.query () ["username"];
   return (!result.empty());
 }
 
 
 // Returns the query to execute to add a new user.
-string Database_Users::add_userQuery (string user, string password, int level, string email)
+std::string Database_Users::add_userQuery (std::string user, std::string password, int level, std::string email)
 {
-  user = database_sqlite_no_sql_injection (user);
+  user = database::sqlite::no_sql_injection (user);
   password = md5 (password);
-  email = database_sqlite_no_sql_injection (email);
-  string query = "INSERT INTO users (username, password, level, email) VALUES ('" + user + "', '" + password + "', " + filter::strings::convert_to_string (level) + ", '" + email + "');";
+  email = database::sqlite::no_sql_injection (email);
+  std::string query = "INSERT INTO users (username, password, level, email) VALUES ('" + user + "', '" + password + "', " + std::to_string (level) + ", '" + email + "');";
   return query;
 }
 
 
 // Returns the username that belongs to the email.
-string Database_Users::getEmailToUser (string email)
+std::string Database_Users::getEmailToUser (std::string email)
 {
   SqliteDatabase sql (filename ());
   sql.add ("SELECT username FROM users WHERE email =");
   sql.add (email);
   sql.add (";");
-  vector <string> result = sql.query () ["username"];
+  std::vector <std::string> result = sql.query () ["username"];
   if (!result.empty()) return result [0];
-  return "";
+  return std::string();
 }
 
 
 // Returns the email address that belongs to user.
-string Database_Users::get_email (string user)
+std::string Database_Users::get_email (std::string user)
 {
   SqliteDatabase sql (filename ());
   sql.add ("SELECT email FROM users WHERE username = ");
   sql.add (user);
   sql.add (";");
-  vector <string> result = sql.query () ["email"];
+  std::vector <std::string> result = sql.query () ["email"];
   if (!result.empty()) return result [0];
-  return "";
+  return std::string();
 }
 
 
 // Returns true if the username exists in the database.
-bool Database_Users::usernameExists (string user)
+bool Database_Users::usernameExists (std::string user)
 {
   SqliteDatabase sql (filename ());
   sql.add ("SELECT username FROM users WHERE username =");
   sql.add (user);
   sql.add (";");
-  vector <string> result = sql.query () ["username"];
+  std::vector <std::string> result = sql.query () ["username"];
   return !result.empty ();
 }
 
 
 // Returns true if the email address exists in the database.
-bool Database_Users::emailExists (string email)
+bool Database_Users::emailExists (std::string email)
 {
   SqliteDatabase sql (filename ());
   sql.add ("SELECT username FROM users WHERE email = ");
   sql.add (email);
   sql.add (";");
-  vector <string> result = sql.query () ["username"];
+  std::vector <std::string> result = sql.query () ["username"];
   return !result.empty ();
 }
 
 
 // Returns the level that belongs to the user.
-int Database_Users::get_level (string user)
+int Database_Users::get_level (std::string user)
 {
   SqliteDatabase sql (filename ());
   sql.add ("SELECT level FROM users WHERE username = ");
   sql.add (user);
   sql.add (";");
-  vector <string> result = sql.query () ["level"];
+  std::vector <std::string> result = sql.query () ["level"];
   if (!result.empty()) return filter::strings::convert_to_int (result [0]);
   return Filter_Roles::guest ();
 }
 
 
 // Updates the level of a given user.
-void Database_Users::set_level (string user, int level)
+void Database_Users::set_level (std::string user, int level)
 {
   SqliteDatabase sql (filename ());
   sql.add ("UPDATE users SET level =");
@@ -226,7 +225,7 @@ void Database_Users::set_level (string user, int level)
 
 
 // Remove a user from the database.
-void Database_Users::removeUser (string user)
+void Database_Users::removeUser (std::string user)
 {
   SqliteDatabase sql (filename ());
   sql.add ("DELETE FROM users WHERE username =");
@@ -237,19 +236,19 @@ void Database_Users::removeUser (string user)
 
 
 // Returns an array with the usernames of the site administrators.
-vector <string> Database_Users::getAdministrators ()
+std::vector <std::string> Database_Users::getAdministrators ()
 {
   SqliteDatabase sql (filename ());
   sql.add ("SELECT username FROM users WHERE level =");
   sql.add (Filter_Roles::admin ());
   sql.add ("AND (disabled IS NULL OR disabled = 0);");
-  vector <string> result = sql.query () ["username"];
+  std::vector <std::string> result = sql.query () ["username"];
   return result;
 }
 
 
 // Returns the query to update a user's email address.
-string Database_Users::updateEmailQuery (string user, string email)
+std::string Database_Users::updateEmailQuery (std::string user, std::string email)
 {
   SqliteDatabase sql (filename ());
   sql.add ("UPDATE users SET email =");
@@ -257,51 +256,51 @@ string Database_Users::updateEmailQuery (string user, string email)
   sql.add ("WHERE username =");
   sql.add (user);
   sql.add (";");
-  return sql.sql;
+  return sql.get_sql();
 }
 
 
 // Updates the "email" for "user".
-void Database_Users::updateUserEmail (string user, string email)
+void Database_Users::updateUserEmail (std::string user, std::string email)
 {
   execute (updateEmailQuery (user, email));
 }
 
 
 // Return an array with the available users.
-vector <string> Database_Users::get_users ()
+std::vector <std::string> Database_Users::get_users ()
 {
   SqliteDatabase sql (filename ());
   sql.add ("SELECT username FROM users;");
-  vector <string> result = sql.query () ["username"];
+  std::vector <std::string> result = sql.query () ["username"];
   return result;
 }
 
 
 // Returns the md5 hash for the $user's password.
-string Database_Users::get_md5 (string user)
+std::string Database_Users::get_md5 (std::string user)
 {
   SqliteDatabase sql (filename ());
   sql.add ("SELECT password FROM users WHERE username =");
   sql.add (user);
   sql.add (";");
-  vector <string> result = sql.query () ["password"];
+  std::vector <std::string> result = sql.query () ["password"];
   if (!result.empty()) return result [0];
-  return "";
+  return std::string();
 }
 
 
 // Executes the SQL fragment.
-void Database_Users::execute (string sqlfragment)
+void Database_Users::execute (std::string sqlfragment)
 {
   SqliteDatabase sql (filename ());
-  sql.sql = sqlfragment;
+  sql.set_sql (sqlfragment);
   sql.execute ();
 }
 
 
 // Set the LDAP state for the $user account $on or off.
-void Database_Users::set_ldap (string user, bool on)
+void Database_Users::set_ldap (std::string user, bool on)
 {
   SqliteDatabase sql (filename ());
   sql.add ("UPDATE users SET ldap =");
@@ -314,13 +313,13 @@ void Database_Users::set_ldap (string user, bool on)
 
 
 // Get whether the $user account comes from a LDAP server.
-bool Database_Users::get_ldap (string user)
+bool Database_Users::get_ldap (std::string user)
 {
   SqliteDatabase sql (filename ());
   sql.add ("SELECT ldap FROM users WHERE username =");
   sql.add (user);
   sql.add (";");
-  vector <string> result = sql.query () ["ldap"];
+  std::vector <std::string> result = sql.query () ["ldap"];
   if (!result.empty()) {
     bool ldap_is_on = filter::strings::convert_to_bool (result [0]);
     return ldap_is_on;
@@ -330,7 +329,7 @@ bool Database_Users::get_ldap (string user)
 
 
 // Enable the $user account.
-void Database_Users::set_enabled (string user, bool on)
+void Database_Users::set_enabled (std::string user, bool on)
 {
   SqliteDatabase sql (filename ());
   sql.add ("UPDATE users SET disabled =");
@@ -343,13 +342,13 @@ void Database_Users::set_enabled (string user, bool on)
 
 
 // Disable the $user account.
-bool Database_Users::get_enabled (string user)
+bool Database_Users::get_enabled (std::string user)
 {
   SqliteDatabase sql (filename ());
   sql.add ("SELECT disabled FROM users WHERE username =");
   sql.add (user);
   sql.add (";");
-  vector <string> result = sql.query () ["disabled"];
+  std::vector <std::string> result = sql.query () ["disabled"];
   if (!result.empty()) return !filter::strings::convert_to_bool (result [0]);
   return false;
 }
