@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,45 +21,39 @@
 #include <assets/view.h>
 #include <assets/page.h>
 #include <filter/url.h>
-using namespace std;
 
 
 // Dialog that enables the user to upload a file.
 // $url: The url of the page where to go to on clicking Cancel or Upload.
 // $question: The question to ask.
-Dialog_Upload::Dialog_Upload (string url, string question)
+Dialog_Upload::Dialog_Upload (std::string url, std::string question)
 {
-  Assets_View * view = new Assets_View ();
   base_url = url;
-  view->set_variable ("question", question);
-  assets_view = view;
+  assets_view.set_variable ("question", question);
 }
 
 
 Dialog_Upload::~Dialog_Upload ()
 {
-  Assets_View * view = static_cast<Assets_View *>(assets_view);
-  delete view;
 }
 
 
 // Adds a query to the URL for going to the page on clicking Upload.
-void Dialog_Upload::add_upload_query (string parameter, string value)
+void Dialog_Upload::add_upload_query (std::string parameter, std::string value)
 {
   upload_query [parameter] = value;
 }
 
 
-string Dialog_Upload::run ()
+std::string Dialog_Upload::run ()
 {
-  Assets_View * view = static_cast<Assets_View *>(assets_view);
-  string import;
-  for (auto & element : upload_query) {
+  std::string import;
+  for (const auto & element : upload_query) {
     import = filter_url_build_http_query (base_url, element.first, element.second);
   }
-  view->set_variable ("import", import);
-  view->set_variable ("cancel", base_url);
-  string page = view->render ("dialog", "upload");
+  assets_view.set_variable ("import", import);
+  assets_view.set_variable ("cancel", base_url);
+  std::string page = assets_view.render ("dialog", "upload");
   page += assets_page::footer ();
   return page;
 }
