@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #pragma once
 
 #include <config/libraries.h>
+#include <assets/view.h>
 
 class Dialog_Yes
 {
@@ -31,6 +32,6 @@ public:
   void add_query (std::string parameter, std::string value);
   std::string run ();
 private:
-  void * assets_view {nullptr};
+  Assets_View assets_view {};
   std::string base_url {};
 };
