@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -26,35 +26,31 @@
 #include <ipc/focus.h>
 #include <database/ipc.h>
 #include <access/bible.h>
-using namespace std;
 
 
-string edit_id_url ()
+std::string edit_id_url ()
 {
   return "edit/id";
 }
 
 
-bool edit_id_acl (void * webserver_request)
+bool edit_id_acl (Webserver_Request& webserver_request)
 {
-  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
+  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ()))
+    return true;
   auto [ read, write ] = access_bible::any (webserver_request);
   return read;
 }
 
 
-string edit_id (void * webserver_request)
+std::string edit_id (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-
-  
   // Update the timestamp indicating that the Bible editor is alive.
-  request->database_config_user()->setLiveBibleEditor (filter::date::seconds_since_epoch ());
-
+  webserver_request.database_config_user()->setLiveBibleEditor (filter::date::seconds_since_epoch ());
   
-  string bible = request->query ["bible"];
-  int book = filter::strings::convert_to_int (request->query ["book"]);
-  int chapter = filter::strings::convert_to_int (request->query ["chapter"]);
-  int id = request->database_bibles()->getChapterId (bible, book, chapter);
-  return filter::strings::convert_to_string (id);
+  const std::string bible = webserver_request.query ["bible"];
+  const int book = filter::strings::convert_to_int (webserver_request.query ["book"]);
+  const int chapter = filter::strings::convert_to_int (webserver_request.query ["chapter"]);
+  const int id = database::bibles::get_chapter_id (bible, book, chapter);
+  return std::to_string (id);
 }
