@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,5 +21,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include <config/libraries.h>
 
-void storeLoadedUsfm2 (void * webserver_request, std::string bible, int book, int chapter, std::string editor, const char * message = "");
-std::string getLoadedUsfm2 (void * webserver_request, std::string bible, int book, int chapter, std::string editor);
+class Webserver_Request;
+
+void store_loaded_usfm (Webserver_Request& webserver_request,
+                        const std::string& bible, const int book, const int chapter,
+                        const std::string& editor);
+std::string get_loaded_usfm (Webserver_Request& webserver_request,
+                             const std::string& bible, const int book, const int chapter,
+                             const std::string& editor);
