@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2024 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -37,32 +37,36 @@ class Editor_Html2Usfm
 {
 public:
   void load (std::string html);
-  void stylesheet (std::string stylesheet);
+  void stylesheet (const std::string& stylesheet);
   void run ();
   std::string get ();
 private:
   pugi::xml_document document {}; // DOMDocument holding the html.
   std::map <std::string, Database_Styles_Item> styles {}; // Style information.
   std::vector <std::string> output {}; // Output USFM.
-  std::string currentLine {}; // Growing current USFM line.
+  std::string current_line {}; // Growing current USFM line.
   bool mono {false}; // Monospace font.
-  std::set <std::string> suppressEndMarkers {}; // Markers which should not have endmarkers, e.g. \v does not have \v*
-  std::set <std::string> noteOpeners {};
-  std::vector <std::string> characterStyles {}; // Active character styles.
-  bool processingNote {false}; // Note processing flag.
-  std::string lastNoteStyle {}; // The most recent style opened inside a note.
-  void preprocess ();
-  void flushLine ();
-  void postprocess ();
-  void process ();
-  void processNode (pugi::xml_node node);
-  void openElementNode (pugi::xml_node node);
-  void closeElementNode (pugi::xml_node node);
-  void openInline (std::string className);
-  void processNoteCitation (pugi::xml_node node);
-  std::string cleanUSFM (std::string usfm);
-  pugi::xml_node get_note_pointer (pugi::xml_node body, std::string id);
+  std::set <std::string> suppress_end_markers {}; // Markers which should not have endmarkers, e.g. \v does not have \v*
+  std::set <std::string> note_openers {};
+  std::vector <std::string> character_styles {}; // Active character styles.
+  bool processing_note {false}; // Note processing flag.
+  std::string last_note_style {}; // The most recent style opened inside a note.
+  void pre_process ();
+  void flush_line ();
+  void post_process ();
+  void main_process ();
+  void process_node (pugi::xml_node& node);
+  void open_element_node (pugi::xml_node& node);
+  void close_element_node (const pugi::xml_node& node);
+  void open_inline (const std::string& class_name);
+  void process_note_citation (pugi::xml_node& node);
+  std::string clean_usfm (std::string usfm);
+  pugi::xml_node get_note_pointer (const pugi::xml_node& body, const std::string& id);
   std::string update_quill_class (std::string classname);
+  // Storge fot all the word-level attributes.
+  std::map<std::string,std::string> m_word_level_attributes{};
+  // The last added text fragment, for analysis.
+  std::string m_last_added_text_fragment{};
 };
 
-std::string editor_export_verse_quill (std::string stylesheet, std::string html);
+std::string editor_export_verse_quill (const std::string& stylesheet, std::string html);
