@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -26,39 +26,38 @@
 #include <access/bible.h>
 
 
-string editusfm_load_url ()
+std::string editusfm_load_url ()
 {
   return "editusfm/load";
 }
 
 
-bool editusfm_load_acl (void * webserver_request)
+bool editusfm_load_acl (Webserver_Request& webserver_request)
 {
-  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  auto [ read, write ] = AccessBible::Any (webserver_request);
+  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ()))
+    return true;
+  auto [ read, write ] = access_bible::any (webserver_request);
   return read;
 }
 
 
-string editusfm_load (void * webserver_request)
+std::string editusfm_load (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-
-  string bible = request->query ["bible"];
-  int book = convert_to_int (request->query ["book"]);
-  int chapter = convert_to_int (request->query ["chapter"]);
-  string unique_id = request->query ["id"];
+  std::string bible = webserver_request.query ["bible"];
+  int book = filter::strings::convert_to_int (webserver_request.query ["book"]);
+  int chapter = filter::strings::convert_to_int (webserver_request.query ["chapter"]);
+  std::string unique_id = webserver_request.query ["id"];
 
   // Store a copy of the USFM loaded in the editor for later reference.
-  storeLoadedUsfm2 (webserver_request, bible, book, chapter, unique_id);
+  store_loaded_usfm (webserver_request, bible, book, chapter, unique_id);
 
-  string usfm = request->database_bibles()->getChapter (bible, book, chapter);
+  std::string usfm = database::bibles::get_chapter (bible, book, chapter);
 
   // Escape the XML special characters so they load properly in the editor.
-  usfm = escape_special_xml_characters (usfm);
+  usfm = filter::strings::escape_special_xml_characters (usfm);
 
-  string user = request->session_logic ()->currentUser ();
-  bool write = AccessBible::BookWrite (webserver_request, user, bible, book);
+  const std::string& user = webserver_request.session_logic ()->get_username ();
+  bool write = access_bible::book_write (webserver_request, user, bible, book);
 
-  return Checksum_Logic::send (usfm, write);
+  return checksum_logic::send (usfm, write);
 }
