@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -36,31 +36,30 @@
 #include <styles/sheets.h>
 
 
-void export_esword (string bible, bool log)
+void export_esword (const std::string& bible, bool log)
 {
-  string directory = filter_url_create_path ({Export_Logic::bibleDirectory (bible), "esword"});
-  if (!file_or_dir_exists (directory)) filter_url_mkdir (directory);
+  const std::string directory = filter_url_create_path ({export_logic::bible_directory (bible), "esword"});
+  if (!file_or_dir_exists (directory))
+    filter_url_mkdir (directory);
   
   
-  string filename = filter_url_create_path ({directory, "bible.bblx"});
+  const std::string filename = filter_url_create_path ({directory, "bible.bblx"});
 
   
-  if (file_or_dir_exists (filename)) filter_url_unlink (filename);
+  if (file_or_dir_exists (filename)) 
+    filter_url_unlink (filename);
   
   
-  Database_Bibles database_bibles;
-  
-  
-  string stylesheet = Database_Config_Bible::getExportStylesheet (bible);
+  const std::string stylesheet = database::config::bible::get_export_stylesheet (bible);
   
   
   Filter_Text filter_text_bible = Filter_Text (bible);
   filter_text_bible.esword_text = new Esword_Text (bible);
-  vector <int> books = database_bibles.getBooks (bible);
-  for (auto book : books) {
-    vector <int> chapters = database_bibles.getChapters (bible, book);
-    for (auto chapter : chapters) {
-      string chapter_data = database_bibles.getChapter (bible, book, chapter);
+  const std::vector <int> books = database::bibles::get_books (bible);
+  for (const auto book : books) {
+    const std::vector <int> chapters = database::bibles::get_chapters (bible, book);
+    for (const auto chapter : chapters) {
+      const std::string chapter_data = database::bibles::get_chapter (bible, book, chapter);
       filter_text_bible.add_usfm_code (chapter_data);
     }
   }
@@ -69,8 +68,9 @@ void export_esword (string bible, bool log)
   filter_text_bible.esword_text->createModule (filename);
 
   
-  Database_State::clearExport (bible, 0, Export_Logic::export_esword);
+  Database_State::clearExport (bible, 0, export_logic::export_esword);
 
   
-  if (log) Database_Logs::log (translate("Exported to e-Sword") + " " + bible, Filter_Roles::translator ());
+  if (log) 
+    Database_Logs::log (translate("Exported to e-Sword") + " " + bible, Filter_Roles::translator ());
 }
