@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2024 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -101,7 +101,7 @@ void export_html_book (const std::string& bible, const int book, const bool log)
   
   
   // Save any images that were included.
-  for (const auto src : filter_text.image_sources) {
+  for (const auto& src : filter_text.image_sources) {
     const std::string contents = database::bible_images::get(src);
     const std::string filename = filter_url_create_path ({directory, src});
     filter_url_file_put_contents(filename, contents);
