@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -102,9 +102,9 @@ int numerical_year (int seconds)
 // This function gives the number of microseconds within the current second.
 int numerical_microseconds ()
 {
-  auto now = chrono::system_clock::now ();
+  auto now = std::chrono::system_clock::now ();
   auto duration = now.time_since_epoch ();
-  auto microseconds = chrono::duration_cast<std::chrono::microseconds>(duration).count();
+  auto microseconds = std::chrono::duration_cast<std::chrono::microseconds>(duration).count();
   int usecs = static_cast<int>(microseconds % 1000000);
   return usecs;
 }
@@ -113,9 +113,9 @@ int numerical_microseconds ()
 // This function returns the seconds since the Unix epoch, which is 1 January 1970 UTC.
 int seconds_since_epoch ()
 {
-  auto now = chrono::system_clock::now ();
+  auto now = std::chrono::system_clock::now ();
   auto duration = now.time_since_epoch ();
-  int seconds = static_cast<int>(chrono::duration_cast<std::chrono::seconds>(duration).count());
+  int seconds = static_cast<int>(std::chrono::duration_cast<std::chrono::seconds>(duration).count());
   return seconds;
 }
 
@@ -144,7 +144,7 @@ int seconds_since_epoch (int year, int month, int day)
 // and returns it.
 int local_seconds (int seconds)
 {
-  int offset = Database_Config_General::getTimezone ();
+  int offset = database::config::general::get_timezone ();
   seconds += (offset * 3600);
   return seconds;
 }
@@ -217,7 +217,7 @@ void get_next_month (int & month, int & year)
 }
 
 
-string day_rfc822 (int day)
+std::string day_rfc822 (int day)
 {
   if (day == 0) return "Sun";
   if (day == 1) return "Mon";
@@ -226,11 +226,11 @@ string day_rfc822 (int day)
   if (day == 4) return "Thu";
   if (day == 5) return "Fri";
   if (day == 6) return "Sat";
-  return "";
+  return std::string();
 }
 
 
-string month_rfc822 (int month)
+std::string month_rfc822 (int month)
 {
   if (month ==  1) return "Jan";
   if (month ==  2) return "Feb";
@@ -244,16 +244,16 @@ string month_rfc822 (int month)
   if (month == 10) return "Oct";
   if (month == 11) return "Nov";
   if (month == 12) return "Dec";
-  return "";
+  return std::string();
 }
 
 
 // Converts the number of $seconds since the Unix epoch
 // to date and time values according to RFC 822,
 // e.g.: Wed, 02 Oct 2002 15:00:00 +0200.
-string rfc822 (int seconds)
+std::string rfc822 (int seconds)
 {
-  string rfc822;
+  std::string rfc822;
   // The feed validator at https://validator.w3.org/feed/ says:
   // <pubDate>Wed, 18 Feb 2017 12:26:39 +0100</pubDate>
   // This feed does not validate: Incorrect day of week: Wed (2 occurrences).
@@ -264,29 +264,29 @@ string rfc822 (int seconds)
   // int weekday = numerical_week_day (seconds);
   // rfc822.append (day_rfc822 (weekday));
   // rfc822.append (", ");
-  string monthday = convert_to_string (numerical_month_day (seconds));
-  rfc822.append (filter_string_fill (monthday, 2, '0'));
+  std::string monthday = std::to_string (numerical_month_day (seconds));
+  rfc822.append (filter::strings::fill (monthday, 2, '0'));
   rfc822.append (" ");
   int month = numerical_month (seconds);
   rfc822.append (month_rfc822 (month));
   rfc822.append (" ");
   int year = numerical_year (seconds);
-  rfc822.append (convert_to_string (year));
+  rfc822.append (std::to_string (year));
   rfc822.append (" ");
-  string hour = convert_to_string (numerical_hour (seconds));
-  rfc822.append (filter_string_fill (hour, 2, '0'));
+  std::string hour = std::to_string (numerical_hour (seconds));
+  rfc822.append (filter::strings::fill (hour, 2, '0'));
   rfc822.append (":");
-  string minute = convert_to_string (numerical_minute (seconds));
-  rfc822.append (filter_string_fill (minute, 2, '0'));
+  std::string minute = std::to_string (numerical_minute (seconds));
+  rfc822.append (filter::strings::fill (minute, 2, '0'));
   rfc822.append (":");
-  string second = convert_to_string (numerical_second (seconds));
-  rfc822.append (filter_string_fill (second, 2, '0'));
+  std::string second = std::to_string (numerical_second (seconds));
+  rfc822.append (filter::strings::fill (second, 2, '0'));
   rfc822.append (" ");
-  int timezone = Database_Config_General::getTimezone ();
+  int timezone = database::config::general::get_timezone ();
   if (timezone >= 0) rfc822.append ("+");
   else rfc822.append ("-");
   if (timezone < 0) timezone = 0 - timezone;
-  rfc822.append (filter_string_fill (convert_to_string (timezone), 2, '0'));
+  rfc822.append (filter::strings::fill (std::to_string (timezone), 2, '0'));
   rfc822.append ("00");
   return rfc822;
 }
@@ -296,49 +296,49 @@ string rfc822 (int seconds)
 // It returns the elapsed number of microseconds.
 long elapsed_microseconds (long start)
 {
-  auto now = chrono::system_clock::now ();
+  auto now = std::chrono::system_clock::now ();
   auto duration = now.time_since_epoch ();
-  auto microseconds = chrono::duration_cast<std::chrono::microseconds>(duration).count();
+  auto microseconds = std::chrono::duration_cast<std::chrono::microseconds>(duration).count();
   long elapsed = microseconds - start;
   return elapsed;
 }
 
 
-string localized_date_format ()
+std::string localized_date_format ()
 {
   time_t tt;
   time (&tt);
-  struct tm * localtm = localtime (&tt);
+  tm * localtm = localtime (&tt);
   char buffer[20];
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wformat-y2k"
   strftime(buffer, sizeof(buffer), "%x", localtm);
 #pragma GCC diagnostic pop
-  return string (buffer);
+  return std::string (buffer);
 }
 
 
-string date_format_to_text (date_format format)
+std::string date_format_to_text (date_format format)
 {
   switch (format) {
     case dd_mm_yyyy: return "dd/mm/yyyy";
     case mm_dd_yyyy: return "mm/dd/yyyy";
     case yyyy_mn_dd: return "yyyy-mm-dd";
+    default: return std::string();
   }
-  return string();
+  return std::string();
 }
 
 
-string localized_date_format (void * webserver_request)
+std::string localized_date_format (Webserver_Request& webserver_request)
 {
   int time = seconds_since_epoch ();
   
-  string day = convert_to_string (numerical_month_day (time));
-  string month = convert_to_string (numerical_month (time));
-  string year = convert_to_string (numerical_year (time));
+  std::string day = std::to_string (numerical_month_day (time));
+  std::string month = std::to_string (numerical_month (time));
+  std::string year = std::to_string (numerical_year (time));
 
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  date_format df = static_cast<date_format>(request->database_config_user()->getNotesDateFormat());
+  date_format df = static_cast<date_format>(webserver_request.database_config_user()->getNotesDateFormat());
 
   switch (df) {
     case dd_mm_yyyy:
@@ -356,9 +356,8 @@ string localized_date_format (void * webserver_request)
     }
   }
   
-  return string();
+  return std::string();
 }
 
 
 }
-
