@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include <config/libraries.h>
 
+class Webserver_Request;
+
 namespace filter::usfm {
 
 class BookChapterData
@@ -54,20 +56,21 @@ std::string peek_text_following_marker (const std::vector <std::string>& usfm, u
 std::string peek_verse_number (std::string usfm);
 std::string get_opening_usfm (std::string text, bool embedded = false);
 std::string get_closing_usfm (std::string text, bool embedded = false);
-std::string save_is_safe (void * webserver_request, std::string oldtext, std::string newtext, bool chapter, std::string & explanation);
-std::string safely_store_chapter (void * webserver_request,
-                             std::string bible, int book, int chapter, std::string usfm, std::string & explanation);
-std::string safely_store_verse (void * webserver_request,
-                           std::string bible, int book, int chapter, int verse, std::string usfm,
-                           std::string & explanation, bool quill);
+std::string save_is_safe (Webserver_Request& webserver_request, 
+                          std::string oldtext, std::string newtext, bool chapter, std::string & explanation);
+std::string safely_store_chapter (Webserver_Request& webserver_request,
+                                  std::string bible, int book, int chapter, std::string usfm, std::string & explanation);
+std::string safely_store_verse (Webserver_Request& webserver_request,
+                                std::string bible, int book, int chapter, int verse, std::string usfm,
+                                std::string & explanation, bool quill);
 bool contains_empty_verses (std::string usfm);
 bool handle_verse_range (std::string verse, std::vector <int> & verses);
 bool handle_verse_sequence (std::string verse, std::vector <int> & verses);
 const char * marker_v ();
 const char * marker_va ();
 const char * marker_vp ();
-void remove_word_level_attributes (const std::string & marker,
-                                   std::vector <std::string> & container, unsigned int & pointer);
+void remove_word_level_attributes (const std::string& marker,
+                                   std::vector <std::string> & container, const unsigned int pointer);
 std::string extract_fig (std::string usfm, std::string & caption, std::string & alt, std::string& src, std::string& size, std::string& loc, std::string& copy, std::string& ref);
 bool is_standard_q_poetry (const std::string & marker);
 
