@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -29,21 +29,17 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 HtmlText::HtmlText (const std::string& title)
 {
-  current_paragraph_style.clear();
-  current_paragraph_content.clear();
-  note_count = 0;
-  
   // <html>
-  xml_node root_node = document.append_child ("html");
+  pugi::xml_node root_node = document.append_child ("html");
   
   // <head>
-  head_node = root_node.append_child ("head");
+  pugi::xml_node head_node {root_node.append_child ("head")};
   
-  xml_node title_node = head_node.append_child ("title");
+  pugi::xml_node title_node = head_node.append_child ("title");
   title_node.text ().set (title.c_str());
   
   // <meta http-equiv="content-type" content="text/html; charset=UTF-8" />
-  xml_node meta_node = head_node.append_child ("meta");
+  pugi::xml_node meta_node = head_node.append_child ("meta");
   meta_node.append_attribute ("http-equiv") = "content-type";
   meta_node.append_attribute ("content") = "text/html; charset=UTF-8";
 
@@ -55,7 +51,7 @@ HtmlText::HtmlText (const std::string& title)
   meta_node.append_attribute ("content") = "width=device-width, initial-scale=1.0";
 
   // <link rel="stylesheet" type="text/css" href="stylesheet.css">
-  xml_node link_node = head_node.append_child ("link");
+  pugi::xml_node link_node = head_node.append_child ("link");
   link_node.append_attribute ("rel") = "stylesheet";
   link_node.append_attribute ("type") = "text/css";
   link_node.append_attribute ("href") = "stylesheet.css";
@@ -70,11 +66,20 @@ HtmlText::HtmlText (const std::string& title)
 
 void HtmlText::new_paragraph (const std::string& style)
 {
+  // First close a previous paragraph, if there's any open.
+  if (current_p_node_open) {
+    // Deal with a blank line.
+    // If the paragraph is empty, add a <br> to it.
+    if (current_paragraph_content.empty()) {
+      current_p_node.append_child("br");
+    }
+  }
+  // Secondly open the paragraph.
   current_p_node = body_node.append_child ("p");
   if (!style.empty()) {
     std::string clss = style;
     if (!custom_class.empty()) {
-      clss += " " + custom_class;
+      clss.append (" " + custom_class);
     }
     current_p_node.append_attribute ("class") = clss.c_str();
   }
@@ -89,23 +94,24 @@ void HtmlText::new_paragraph (const std::string& style)
 void HtmlText::add_text (const std::string& text)
 {
   if (!text.empty()) {
-    if (!current_p_node_open) new_paragraph ();
-    xml_node span = current_p_node.append_child ("span");
+    if (!current_p_node_open) 
+      new_paragraph ();
+    pugi::xml_node span = current_p_node.append_child ("span");
     span.text().set (text.c_str());
     if (!current_text_style.empty ()) {
       // Take character style(s) as specified in the object.
       span.append_attribute ("class") = filter::strings::implode (current_text_style, " ").c_str();
     }
-    current_paragraph_content += text;
+    current_paragraph_content.append(text);
   }
 }
 
 
 // This creates a <h1> heading with contents.
 // $text: Contents.
-void HtmlText::new_heading1 (const std::string& text, const bool hide)
+void HtmlText::new_heading1 (const std::string& text)
 {
-  new_named_heading ("h1", text, hide);
+  new_named_heading ("h1", text);
 }
 
 
@@ -131,12 +137,14 @@ void HtmlText::new_page_break ()
 //                  false: close any existing text style, and open the new style.
 void HtmlText::open_text_style (const Database_Styles_Item& style, const bool note, const bool embed)
 {
-  std::string marker = style.marker;
+  const std::string& marker {style.marker};
   if (note) {
-    if (!embed) current_note_text_style.clear();
+    if (!embed) 
+      current_note_text_style.clear();
     current_note_text_style.push_back (marker);
   } else {
-    if (!embed) current_text_style.clear();
+    if (!embed) 
+      current_text_style.clear();
     current_text_style.push_back (marker);
   }
 }
@@ -150,11 +158,15 @@ void HtmlText::open_text_style (const Database_Styles_Item& style, const bool no
 void HtmlText::close_text_style (const bool note, const bool embed)
 {
   if (note) {
-    if (!current_note_text_style.empty()) current_note_text_style.pop_back ();
-    if (!embed) current_note_text_style.clear();
+    if (!current_note_text_style.empty()) 
+      current_note_text_style.pop_back ();
+    if (!embed) 
+      current_note_text_style.clear();
   } else {
-    if (!current_text_style.empty()) current_text_style.pop_back ();
-    if (!embed) current_text_style.clear ();
+    if (!current_text_style.empty()) 
+      current_text_style.pop_back ();
+    if (!embed) 
+      current_text_style.clear ();
   }
 }
 
@@ -166,14 +178,17 @@ void HtmlText::close_text_style (const bool note, const bool embed)
 void HtmlText::add_note (const std::string& citation, const std::string& style, [[maybe_unused]] const bool endnote)
 {
   // Ensure that a paragraph is open, so that the note can be added to it.
-  if (!current_p_node_open) new_paragraph ();
+  if (!current_p_node_open) 
+    new_paragraph ();
   
   note_count++;
   
   // Add the link with all relevant data for the note citation.
-  std::string reference = "#note" + filter::strings::convert_to_string (note_count);
-  std::string identifier = "citation" + filter::strings::convert_to_string (note_count);
-  add_link (current_p_node, reference, identifier, "", "superscript", citation, add_popup_notes);
+  {
+    const std::string reference = "#note" + std::to_string (note_count);
+    const std::string identifier = "citation" + std::to_string (note_count);
+    add_link (current_p_node, reference, identifier, "", "superscript", citation, add_popup_notes);
+  }
   
   // Open a paragraph element for the note body.
   note_p_node = notes_div_node.append_child ("p");
@@ -183,9 +198,11 @@ void HtmlText::add_note (const std::string& citation, const std::string& style,
   close_text_style (true, false);
   
   // Add the link with all relevant data for the note body.
-  reference = "#citation" + filter::strings::convert_to_string (note_count);
-  identifier = "note" + filter::strings::convert_to_string (note_count);
-  add_link (note_p_node, reference, identifier, "", "", citation);
+  {
+    const std::string reference = "#citation" + std::to_string (note_count);
+    const std::string identifier = "note" + std::to_string (note_count);
+    add_link (note_p_node, reference, identifier, "", "", citation);
+  }
   
   // Add a space.
   add_note_text (" ");
@@ -196,17 +213,19 @@ void HtmlText::add_note (const std::string& citation, const std::string& style,
 // $text: The text to add.
 void HtmlText::add_note_text (const std::string& text)
 {
-  if (text.empty()) return;
-  if (!note_p_node_open) add_note ("?", "");
-  xml_node span_node = note_p_node.append_child ("span");
-  span_node.text().set (text.c_str());
+  if (text.empty()) 
+    return;
+  if (!note_p_node_open) 
+    add_note ("?", "");
+  pugi::xml_node span_node1 = note_p_node.append_child ("span");
+  span_node1.text().set (text.c_str());
   if (!current_note_text_style.empty ()) {
     // Take character style as specified in this object.
-    span_node.append_attribute ("class") = filter::strings::implode (current_note_text_style, " ").c_str();
+    span_node1.append_attribute ("class") = filter::strings::implode (current_note_text_style, " ").c_str();
   }
   if (popup_node) {
-    xml_node span_node_2 = popup_node.append_child ("span");
-    span_node_2.text().set (text.c_str());
+    pugi::xml_node span_node2 = popup_node.append_child ("span");
+    span_node2.text().set (text.c_str());
   }
 }
 
@@ -226,17 +245,19 @@ void HtmlText::close_current_note ()
 // $title: The link's title, to make it accessible, e.g. for screenreaders.
 // $style: The link text's style.
 // $text: The link's text.
-void HtmlText::add_link (xml_node node,
+void HtmlText::add_link (pugi::xml_node node,
                          const std::string& reference, const std::string& identifier,
                          const std::string& title, const std::string& style, const std::string& text,
                          const bool add_popup)
 {
-  xml_node a_node = node.append_child ("a");
+  pugi::xml_node a_node = node.append_child ("a");
   a_node.append_attribute ("href") = reference.c_str();
   a_node.append_attribute ("id") = identifier.c_str();
-  if (!title.empty ()) a_node.append_attribute ("title") = title.c_str();
-  if (!style.empty()) a_node.append_attribute ("class") = style.c_str();
-  xml_node pcdata = a_node.append_child (node_pcdata);
+  if (!title.empty ()) 
+    a_node.append_attribute ("title") = title.c_str();
+  if (!style.empty()) 
+    a_node.append_attribute ("class") = style.c_str();
+  pugi::xml_node pcdata = a_node.append_child (pugi::node_pcdata);
   pcdata.set_value(text.c_str());
   // Whether to add a popup span in a note.
   if (add_popup) {
@@ -251,7 +272,7 @@ std::string HtmlText::get_html ()
 {
   // Move any notes into place: At the end of the body.
   // Or remove empty notes container.
-  if (note_count > 0) {
+  if (note_count) {
     body_node.append_move (notes_div_node);
   } else {
     body_node.remove_child (notes_div_node);
@@ -259,8 +280,8 @@ std::string HtmlText::get_html ()
   note_count = 0;
 
   // Get the html.
-  std::stringstream output;
-  document.print (output, "", format_raw);
+  std::stringstream output {};
+  document.print (output, "", pugi::format_raw);
   std::string html = output.str ();
   
   // Add html5 doctype.
@@ -274,12 +295,12 @@ std::string HtmlText::get_html ()
 std::string HtmlText::get_inner_html ()
 {
   std::string page = get_html ();
-  size_t pos = page.find ("<body>");
-  if (pos != std::string::npos) {
-    page = page.substr (pos + 6);
-    pos = page.find ("</body>");
-    if (pos != std::string::npos) {
-      page = page.substr (0, pos);
+  if (const auto pos1 = page.find ("<body>");
+      pos1 != std::string::npos) {
+    page = page.substr (pos1 + 6);
+    if (const auto pos2 = page.find ("</body>");
+        pos2 != std::string::npos) {
+      page = page.substr (0, pos2);
     }
   }
   return page;
@@ -288,7 +309,7 @@ std::string HtmlText::get_inner_html ()
 
 // This saves the web page to file
 // $name: the name of the file to save to.
-void HtmlText::save (std::string name)
+void HtmlText::save (const std::string& name)
 {
   const std::string html = get_html ();
   filter_url_file_put_contents (name, html);
@@ -297,45 +318,46 @@ void HtmlText::save (std::string name)
 
 // This adds a new table to the html DOM.
 // Returns: The new $tableElement
-xml_node HtmlText::new_table ()
+pugi::xml_node HtmlText::new_table ()
 {
   // Adding subsequent text should create a new paragraph.
   current_p_node_open = false;
   current_paragraph_style.clear();
   current_paragraph_content.clear();
   // Append the table.
-  xml_node tableElement = body_node.append_child ("table");
-  tableElement.append_attribute ("width") = "100%";
-  return tableElement;
+  pugi::xml_node table_element = body_node.append_child ("table");
+  table_element.append_attribute ("width") = "100%";
+  return table_element;
 }
 
 
-// This adds a new row to an existing $tableElement.
-// Returns: The new $tableRowElement.
-xml_node HtmlText::new_table_row (xml_node tableElement)
+// This adds a new row to an existing $table_element.
+// Returns: The new $table_row_element.
+pugi::xml_node HtmlText::new_table_row (pugi::xml_node table_element)
 {
-  xml_node tableRowElement = tableElement.append_child ("tr");
-  return tableRowElement;
+  pugi::xml_node table_row_element = table_element.append_child ("tr");
+  return table_row_element;
 }
 
 
-// This adds a new data cell to an existing $tableRowElement.
-// Returns: The new $tableDataElement.
-xml_node HtmlText::new_table_data (xml_node tableRowElement, const bool alignRight)
+// This adds a new data cell to an existing $table_row_element.
+// Returns: The new $table_data_element.
+pugi::xml_node HtmlText::new_table_data (pugi::xml_node table_row_element, const bool align_right)
 {
-  xml_node tableDataElement = tableRowElement.append_child ("td");
-  if (alignRight) tableDataElement.append_attribute ("align") = "right";
-  return tableDataElement;
+  pugi::xml_node table_data_element = table_row_element.append_child ("td");
+  if (align_right) 
+    table_data_element.append_attribute ("align") = "right";
+  return table_data_element;
 }
 
 
 // This creates a heading with styled content.
 // $style: A style name.
 // $text: Content.
-void HtmlText::new_named_heading (const std::string& style, const std::string& text, [[maybe_unused]] const bool hide)
+void HtmlText::new_named_heading (const std::string& style, const std::string& text)
 {
-  xml_node textHDomElement = body_node.append_child (style.c_str());
-  textHDomElement.text ().set (text.c_str());
+  pugi::xml_node text_h_dom_element = body_node.append_child (style.c_str());
+  text_h_dom_element.text ().set (text.c_str());
   // Make paragraph null, so that adding subsequent text creates a new paragraph.
   current_p_node_open = false;
   current_paragraph_style.clear ();
@@ -351,9 +373,12 @@ void HtmlText::have_popup_notes ()
 
 
 // Add an image to the html.
-void HtmlText::add_image (const std::string& style, const std::string& alt, const std::string& src, const std::string& caption)
+void HtmlText::add_image (const std::string& style,
+                          const std::string& alt,
+                          const std::string& src,
+                          const std::string& caption)
 {
-  xml_node img_node = body_node.append_child ("img");
+  pugi::xml_node img_node = body_node.append_child ("img");
   img_node.append_attribute("alt") = alt.c_str();
   img_node.append_attribute("src") = src.c_str();
   img_node.append_attribute ("width") = "100%";
