@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,17 +17,11 @@
  */
 
 
-#ifndef INCLUDED_LDAP_LOGIC_H
-#define INCLUDED_LDAP_LOGIC_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 void ldap_logic_initialize ();
 void ldap_logic_clear ();
 bool ldap_logic_is_on (bool log = false);
-bool ldap_logic_fetch (string user, string password, bool & access, string & email, int & role, bool log);
-
-
-#endif
+bool ldap_logic_fetch (const std::string& user, const std::string& password, bool& access, std::string& email, int& role, bool log);
