@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,12 @@
  */
 
 
-#ifndef INCLUDED_PUBLIC_CHAPTER_H
-#define INCLUDED_PUBLIC_CHAPTER_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+class Webserver_Request;
 
-string public_chapter_url ();
-bool public_chapter_acl (void * webserver_request);
-string public_chapter (void * webserver_request);
-
-
-#endif
+std::string public_chapter_url ();
+bool public_chapter_acl (Webserver_Request& webserver_request);
+std::string public_chapter (Webserver_Request& webserver_request);
