@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -33,23 +33,21 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/url.h>
 #include <filter/string.h>
 #include <filter/usfm.h>
-using namespace std;
-using namespace pugi;
 
 
 // Internal function that searches related passages in the XML DOM.
-void related_logic_search_related (const string & bookname, int input_chapter, const string & input_verse,
-                                   const xml_node & node, vector <int> & passages)
+void related_logic_search_related (const std::string& bookname, int input_chapter, const std::string& input_verse,
+                                   const pugi::xml_node & node, std::vector <int> & passages)
 {
-  for (xml_node set : node.children ()) {
+  for (pugi::xml_node set : node.children ()) {
     bool match = false;
-    for (xml_node reference : set.children ()) {
+    for (pugi::xml_node reference : set.children ()) {
       
       // If a match was found, skip further processing.
       if (match) continue;
       
       // Match on book.
-      string book = reference.attribute ("book").value ();
+      std::string book = reference.attribute ("book").value ();
       match = (book == bookname);
       
       // Match on chapter.
@@ -60,8 +58,8 @@ void related_logic_search_related (const string & bookname, int input_chapter, c
       
       // Match on verse(s).
       if (match) {
-        string verse = reference.attribute ("verse").value ();
-        vector <int> verses;
+        std::string verse = reference.attribute ("verse").value ();
+        std::vector <int> verses;
         if (filter::usfm::handle_verse_range (verse, verses)) {
           match = in_array (filter::strings::convert_to_int (input_verse), verses);
         } else {
@@ -71,17 +69,17 @@ void related_logic_search_related (const string & bookname, int input_chapter, c
       
       // Store all related passages.
       if (match) {
-        for (xml_node passage_node : set.children ()) {
-          string related_bookname = passage_node.attribute ("book").value ();
+        for (pugi::xml_node passage_node : set.children ()) {
+          std::string related_bookname = passage_node.attribute ("book").value ();
           book_id related_book = database::books::get_id_from_english (related_bookname);
           int related_chapter = filter::strings::convert_to_int (passage_node.attribute ("chapter").value ());
-          string verse = passage_node.attribute ("verse").value ();
-          vector <int> verses {};
+          std::string verse = passage_node.attribute ("verse").value ();
+          std::vector <int> verses {};
           if (filter::usfm::handle_verse_range (verse, verses));
           else verses.push_back (filter::strings::convert_to_int (verse));
           for (auto related_verse : verses) {
             if ((related_book != book_id::_unknown) && related_chapter) {
-              Passage passage (string(), static_cast<int>(related_book), related_chapter, filter::strings::convert_to_string (related_verse));
+              Passage passage (std::string(), static_cast<int>(related_book), related_chapter, std::to_string (related_verse));
               int i = filter_passage_to_integer (passage);
               // No duplicate passages to be included.
               if (!in_array (i, passages)) {
@@ -98,9 +96,9 @@ void related_logic_search_related (const string & bookname, int input_chapter, c
 
 // This fetches related verses.
 // It takes the passages from $input, and returns them plus their related passages, if there's any.
-vector <Passage> related_logic_get_verses (const vector <Passage> & input)
+std::vector <Passage> related_logic_get_verses (const std::vector <Passage> & input)
 {
-  vector <int> related_passages;
+  std::vector <int> related_passages;
   
   
   if (!input.empty ()) {
@@ -108,18 +106,18 @@ vector <Passage> related_logic_get_verses (const vector <Passage> & input)
 
     // Get details about the book in the passage.
     // It assumes all input passages refer to the same book.
-    string bookname = database::books::get_english_from_id (static_cast<book_id>(input[0].m_book));
+    std::string bookname = database::books::get_english_from_id (static_cast<book_id>(input[0].m_book));
     book_type booktype = database::books::get_type (static_cast<book_id>(input[0].m_book));
     bool is_ot = (booktype == book_type::old_testament);
     bool is_nt = (booktype == book_type::new_testament);
     
     
     // Load the parallel passages and the quotations.
-    xml_document parallel_document;
-    xml_document quotation_document;
+    pugi::xml_document parallel_document;
+    pugi::xml_document quotation_document;
     if (is_ot || is_nt) {
-      string book_type_name = database::books::book_type_to_string(booktype);
-      string path = filter_url_create_root_path ({"related", "parallel-passages-" + book_type_name + ".xml"});
+      std::string book_type_name = database::books::book_type_to_string(booktype);
+      std::string path = filter_url_create_root_path ({"related", "parallel-passages-" + book_type_name + ".xml"});
       parallel_document.load_file (path.c_str());
       path = filter_url_create_root_path ({"related", "ot-quotations-in-nt.xml"});
       quotation_document.load_file (path.c_str());
@@ -129,13 +127,13 @@ vector <Passage> related_logic_get_verses (const vector <Passage> & input)
     // Deal with all of the input passages.
     for (auto & input_passage : input) {
       // Search for parallel passages.
-      for (xml_node passages : parallel_document.children ()) {
-        for (xml_node section : passages.children ()) {
+      for (pugi::xml_node passages : parallel_document.children ()) {
+        for (pugi::xml_node section : passages.children ()) {
           related_logic_search_related (bookname, input_passage.m_chapter, input_passage.m_verse, section, related_passages);
         }
       }
       // Search for quotes.
-      for (xml_node passages : quotation_document.children ()) {
+      for (pugi::xml_node passages : quotation_document.children ()) {
         related_logic_search_related (bookname, input_passage.m_chapter, input_passage.m_verse, passages, related_passages);
       }
     }
@@ -143,7 +141,7 @@ vector <Passage> related_logic_get_verses (const vector <Passage> & input)
 
   
   // Sort the passages and convert them.
-  vector <Passage> output;
+  std::vector <Passage> output;
   sort (related_passages.begin (), related_passages.end ());
   for (auto & related_passage : related_passages) {
     Passage passage = filter_integer_to_passage (related_passage);
