@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -34,43 +34,40 @@
 #include <menu/logic.h>
 
 
-string resource_images_url ()
+std::string resource_images_url ()
 {
   return "resource/images";
 }
 
 
-bool resource_images_acl (void * webserver_request)
+bool resource_images_acl (Webserver_Request& webserver_request)
 {
   return Filter_Roles::access_control (webserver_request, Filter_Roles::manager ());
 }
 
 
-string resource_images (void * webserver_request)
+std::string resource_images (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-
-  
-  string page;
-  Assets_Header header = Assets_Header (translate("Image resources"), request);
-  header.addBreadCrumb (menu_logic_settings_menu (), menu_logic_settings_text ());
+  std::string page;
+  Assets_Header header = Assets_Header (translate("Image resources"), webserver_request);
+  header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
   page = header.run ();
   Assets_View view;
-  string error, success;
+  std::string error, success;
   
 
   Database_ImageResources database_imageresources;
   
   
   // New image resource handler.
-  if (request->query.count ("new")) {
+  if (webserver_request.query.count ("new")) {
     Dialog_Entry dialog_entry = Dialog_Entry ("images", translate("Please enter a name for the new empty image resource"), "", "new", "");
     page += dialog_entry.run ();
     return page;
   }
-  if (request->post.count ("new")) {
-    string resource = request->post ["entry"];
-    vector <string> resources = database_imageresources.names ();
+  if (webserver_request.post.count ("new")) {
+    std::string resource = webserver_request.post ["entry"];
+    std::vector <std::string> resources = database_imageresources.names ();
     if (in_array (resource, resources)) {
       error = translate("This image resource already exists");
     } else if (resource.empty ()) {
@@ -83,9 +80,9 @@ string resource_images (void * webserver_request)
 
   
   // Delete resource.
-  string remove = request->query ["delete"];
+  std::string remove = webserver_request.query ["delete"];
   if (remove != "") {
-    string confirm = request->query ["confirm"];
+    std::string confirm = webserver_request.query ["confirm"];
     if (confirm == "") {
       Dialog_Yes dialog_yes = Dialog_Yes ("images", translate("Would you like to delete this resource?"));
       dialog_yes.add_query ("delete", remove);
@@ -98,8 +95,8 @@ string resource_images (void * webserver_request)
   }
 
 
-  vector <string> resources = database_imageresources.names ();
-  vector <string> resourceblock;
+  std::vector <std::string> resources = database_imageresources.names ();
+  std::vector <std::string> resourceblock;
   for (auto & resource : resources) {
     resourceblock.push_back ("<p>");
     resourceblock.push_back ("<a href=\"image?name=" + resource + "\">");
@@ -107,12 +104,12 @@ string resource_images (void * webserver_request)
     resourceblock.push_back ("</a>");
     resourceblock.push_back ("</p>");
   }
-  view.set_variable ("resourceblock", filter_string_implode (resourceblock, "\n"));
+  view.set_variable ("resourceblock", filter::strings::implode (resourceblock, "\n"));
 
    
   view.set_variable ("success", success);
   view.set_variable ("error", error);
   page += view.render ("resource", "images");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
