@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -28,37 +28,37 @@
 #include <database/logic.h>
 
 
-string search_logic_index_folder ()
+std::string search_logic_index_folder ()
 {
   return filter_url_create_root_path ({database_logic_databases (), "search"});
 }
 
 
-string search_logic_bible_fragment (string bible)
+std::string search_logic_bible_fragment (std::string bible)
 {
   return filter_url_create_path ({search_logic_index_folder (), bible + "_"});
 }
 
 
-string search_logic_book_fragment (string bible, int book)
+std::string search_logic_book_fragment (std::string bible, int book)
 {
-  return search_logic_bible_fragment (bible) + convert_to_string (book) + "_";
+  return search_logic_bible_fragment (bible) + std::to_string (book) + "_";
 }
 
 
-string search_logic_chapter_file (string bible, int book, int chapter)
+std::string search_logic_chapter_file (std::string bible, int book, int chapter)
 {
-  return search_logic_book_fragment (bible, book) + convert_to_string (chapter);
+  return search_logic_book_fragment (bible, book) + std::to_string (chapter);
 }
 
 
-string search_logic_verse_separator ()
+std::string search_logic_verse_separator ()
 {
   return "v#e#r#s#e#s#e#p#a#r#a#t#o#r";
 }
 
 
-string search_logic_index_separator ()
+std::string search_logic_index_separator ()
 {
   return "i#n#d#e#x#s#e#p#a#r#a#t#o#r";
 }
@@ -71,22 +71,20 @@ string search_logic_index_separator ()
 
 
 // Indexes a $bible $book $chapter for searching.
-void search_logic_index_chapter (string bible, int book, int chapter)
+void search_logic_index_chapter (std::string bible, int book, int chapter)
 {
-  Database_Bibles database_bibles;
-  
-  string usfm = database_bibles.getChapter (bible, book, chapter);
-  string stylesheet = Database_Config_Bible::getExportStylesheet (bible);
+  std::string usfm = database::bibles::get_chapter (bible, book, chapter);
+  const std::string stylesheet = database::config::bible::get_export_stylesheet (bible);
 
-  vector <string> index;
+  std::vector <std::string> index;
   
-  set <string> already_processed;
+  std::set <std::string> already_processed;
   
-  vector <int> verses = filter::usfm::get_verse_numbers (usfm);
+  std::vector <int> verses = filter::usfm::get_verse_numbers (usfm);
   
   for (auto verse : verses) {
 
-    string raw_usfm = filter_string_trim (filter::usfm::get_verse_text (usfm, verse));
+    std::string raw_usfm = filter::strings::trim (filter::usfm::get_verse_text (usfm, verse));
 
     // In case of combined verses, the bit of USFM may have been indexed already.
     // Skip it in that case.
@@ -94,12 +92,12 @@ void search_logic_index_chapter (string bible, int book, int chapter)
     already_processed.insert (raw_usfm);
 
     index.push_back (search_logic_verse_separator ());
-    index.push_back (convert_to_string (verse));
+    index.push_back (std::to_string (verse));
     index.push_back (search_logic_index_separator ());
 
     index.push_back (raw_usfm);
     
-    string usfm_lower = unicode_string_casefold (raw_usfm);
+    std::string usfm_lower = filter::strings::unicode_string_casefold (raw_usfm);
 
     index.push_back (search_logic_index_separator ());
 
@@ -112,27 +110,27 @@ void search_logic_index_chapter (string bible, int book, int chapter)
     filter_text.add_usfm_code (raw_usfm);
     filter_text.run (stylesheet);
 
-    string raw_plain;
+    std::string raw_plain;
     // Add the clean verse texts.
-    map <int, string> texts = filter_text.getVersesText ();
+    std::map <int, std::string> texts = filter_text.getVersesText ();
     for (auto & element : texts) {
       raw_plain.append (element.second + "\n");
     }
     // Add any clean headings.
-    map <int, string> headings = filter_text.verses_headings;
+    std::map <int, std::string> headings = filter_text.verses_headings;
     for (auto & element : headings) {
       raw_plain.append (element.second + "\n");
     }
     // Add any footnotes.
     raw_plain.append (filter_text.text_text->getnote ());
     // Clean up.
-    raw_plain = filter_string_trim (raw_plain);
+    raw_plain = filter::strings::trim (raw_plain);
     
     index.push_back (search_logic_index_separator ());
 
     index.push_back (raw_plain);
     
-    string plain_lower = unicode_string_casefold (raw_plain);
+    std::string plain_lower = filter::strings::unicode_string_casefold (raw_plain);
 
     index.push_back (search_logic_index_separator ());
 
@@ -142,8 +140,8 @@ void search_logic_index_chapter (string bible, int book, int chapter)
   index.push_back (search_logic_index_separator ());
   
   // Store everything.
-  string path = search_logic_chapter_file (bible, book, chapter);
-  filter_url_file_put_contents (path, filter_string_implode (index, "\n"));
+  std::string path = search_logic_chapter_file (bible, book, chapter);
+  filter_url_file_put_contents (path, filter::strings::implode (index, "\n"));
 }
 
 
@@ -151,31 +149,30 @@ void search_logic_index_chapter (string bible, int book, int chapter)
 // Returns an array with matching passages.
 // $search: Contains the text to search for.
 // $bibles: Array of Bible names to search in.
-vector <Passage> search_logic_search_text (string search, vector <string> bibles)
+std::vector <Passage> search_logic_search_text (std::string search, std::vector <std::string> bibles)
 {
-  vector <Passage> passages;
+  std::vector <Passage> passages;
   
   if (search == "") return passages;
   
-  search = unicode_string_casefold (search);
-  search = filter_string_str_replace (",", "", search);
+  search = filter::strings::unicode_string_casefold (search);
+  search = filter::strings::replace (",", "", search);
   
-  Database_Bibles database_bibles;
   for (auto bible : bibles) {
-    vector <int> books = database_bibles.getBooks (bible);
+    std::vector <int> books = database::bibles::get_books (bible);
     for (auto book : books) {
-      vector <int> chapters = database_bibles.getChapters (bible, book);
+      std::vector <int> chapters = database::bibles::get_chapters (bible, book);
       for (auto chapter : chapters) {
-        string path = search_logic_chapter_file (bible, book, chapter);
-        string index = filter_url_file_get_contents (path);
-        if (index.find (search) != string::npos) {
-          vector <string> lines = filter_string_explode (index, '\n');
+        std::string path = search_logic_chapter_file (bible, book, chapter);
+        std::string index = filter_url_file_get_contents (path);
+        if (index.find (search) != std::string::npos) {
+          std::vector <std::string> lines = filter::strings::explode (index, '\n');
           int index_verse = 0;
           bool read_index_verse = false;
           int index_item = 0;
           for (auto & line : lines) {
             if (read_index_verse) {
-              index_verse = convert_to_int (line);
+              index_verse = filter::strings::convert_to_int (line);
               read_index_verse = false;
             } else if (line == search_logic_verse_separator ()) {
               read_index_verse = true;
@@ -183,8 +180,8 @@ vector <Passage> search_logic_search_text (string search, vector <string> bibles
             } else if (line == search_logic_index_separator ()) {
               index_item++;
             } else if (index_item == PLAIN_LOWER) {
-              if (line.find (search) != string::npos) {
-                passages.push_back (Passage (bible, book, chapter, convert_to_string (index_verse)));
+              if (line.find (search) != std::string::npos) {
+                passages.push_back (Passage (bible, book, chapter, std::to_string (index_verse)));
               }
             }
           }
@@ -200,29 +197,28 @@ vector <Passage> search_logic_search_text (string search, vector <string> bibles
 // Performs a case-insensitive search of the text of one $bible.
 // Returns an array with the matching passages.
 // $search: Contains the text to search for.
-vector <Passage> search_logic_search_bible_text (string bible, string search)
+std::vector <Passage> search_logic_search_bible_text (std::string bible, std::string search)
 {
-  vector <Passage> passages;
+  std::vector <Passage> passages;
   
   if (search == "") return passages;
   
-  search = unicode_string_casefold (search);
+  search = filter::strings::unicode_string_casefold (search);
   
-  Database_Bibles database_bibles;
-  vector <int> books = database_bibles.getBooks (bible);
+  std::vector <int> books = database::bibles::get_books (bible);
   for (auto book : books) {
-    vector <int> chapters = database_bibles.getChapters (bible, book);
+    std::vector <int> chapters = database::bibles::get_chapters (bible, book);
     for (auto chapter : chapters) {
-      string path = search_logic_chapter_file (bible, book, chapter);
-      string index = filter_url_file_get_contents (path);
-      if (index.find (search) != string::npos) {
-        vector <string> lines = filter_string_explode (index, '\n');
+      std::string path = search_logic_chapter_file (bible, book, chapter);
+      std::string index = filter_url_file_get_contents (path);
+      if (index.find (search) != std::string::npos) {
+        std::vector <std::string> lines = filter::strings::explode (index, '\n');
         int index_verse = 0;
         bool read_index_verse = false;
         int index_item = 0;
         for (auto & line : lines) {
           if (read_index_verse) {
-            index_verse = convert_to_int (line);
+            index_verse = filter::strings::convert_to_int (line);
             read_index_verse = false;
           } else if (line == search_logic_verse_separator ()) {
             read_index_verse = true;
@@ -230,8 +226,8 @@ vector <Passage> search_logic_search_bible_text (string bible, string search)
           } else if (line == search_logic_index_separator ()) {
             index_item++;
           } else if (index_item == PLAIN_LOWER) {
-            if (line.find (search) != string::npos) {
-              passages.push_back (Passage (bible, book, chapter, convert_to_string (index_verse)));
+            if (line.find (search) != std::string::npos) {
+              passages.push_back (Passage (bible, book, chapter, std::to_string (index_verse)));
             }
           }
         }
@@ -246,27 +242,26 @@ vector <Passage> search_logic_search_bible_text (string bible, string search)
 // Performs a case-sensitive search of the text of one $bible.
 // Returns an array with the rowid's of matching verses.
 // $search: Contains the text to search for.
-vector <Passage> search_logic_search_bible_text_case_sensitive (string bible, string search)
+std::vector <Passage> search_logic_search_bible_text_case_sensitive (std::string bible, std::string search)
 {
-  vector <Passage> passages;
+  std::vector <Passage> passages;
   
   if (search == "") return passages;
   
-  Database_Bibles database_bibles;
-  vector <int> books = database_bibles.getBooks (bible);
+  std::vector <int> books = database::bibles::get_books (bible);
   for (auto book : books) {
-    vector <int> chapters = database_bibles.getChapters (bible, book);
+    std::vector <int> chapters = database::bibles::get_chapters (bible, book);
     for (auto chapter : chapters) {
-      string path = search_logic_chapter_file (bible, book, chapter);
-      string index = filter_url_file_get_contents (path);
-      if (index.find (search) != string::npos) {
-        vector <string> lines = filter_string_explode (index, '\n');
+      std::string path = search_logic_chapter_file (bible, book, chapter);
+      std::string index = filter_url_file_get_contents (path);
+      if (index.find (search) != std::string::npos) {
+        std::vector <std::string> lines = filter::strings::explode (index, '\n');
         int index_verse = 0;
         bool read_index_verse = false;
         int index_item = 0;
         for (auto & line : lines) {
           if (read_index_verse) {
-            index_verse = convert_to_int (line);
+            index_verse = filter::strings::convert_to_int (line);
             read_index_verse = false;
           } else if (line == search_logic_verse_separator ()) {
             read_index_verse = true;
@@ -274,8 +269,8 @@ vector <Passage> search_logic_search_bible_text_case_sensitive (string bible, st
           } else if (line == search_logic_index_separator ()) {
             index_item++;
           } else if (index_item == PLAIN_RAW) {
-            if (line.find (search) != string::npos) {
-              passages.push_back (Passage (bible, book, chapter, convert_to_string (index_verse)));
+            if (line.find (search) != std::string::npos) {
+              passages.push_back (Passage (bible, book, chapter, std::to_string (index_verse)));
             }
           }
         }
@@ -290,29 +285,28 @@ vector <Passage> search_logic_search_bible_text_case_sensitive (string bible, st
 // Performs a case-insensitive search of the USFM of one bible.
 // Returns an array with the rowid's of matching verses.
 // search: Contains the text to search for.
-vector <Passage> search_logic_search_bible_usfm (string bible, string search)
+std::vector <Passage> search_logic_search_bible_usfm (std::string bible, std::string search)
 {
-  vector <Passage> passages;
+  std::vector <Passage> passages;
   
   if (search == "") return passages;
   
-  search = unicode_string_casefold (search);
+  search = filter::strings::unicode_string_casefold (search);
   
-  Database_Bibles database_bibles;
-  vector <int> books = database_bibles.getBooks (bible);
+  std::vector <int> books = database::bibles::get_books (bible);
   for (auto book : books) {
-    vector <int> chapters = database_bibles.getChapters (bible, book);
+    std::vector <int> chapters = database::bibles::get_chapters (bible, book);
     for (auto chapter : chapters) {
-      string path = search_logic_chapter_file (bible, book, chapter);
-      string index = filter_url_file_get_contents (path);
-      if (index.find (search) != string::npos) {
-        vector <string> lines = filter_string_explode (index, '\n');
+      std::string path = search_logic_chapter_file (bible, book, chapter);
+      std::string index = filter_url_file_get_contents (path);
+      if (index.find (search) != std::string::npos) {
+        std::vector <std::string> lines = filter::strings::explode (index, '\n');
         int index_verse = 0;
         bool read_index_verse = false;
         int index_item = 0;
         for (auto & line : lines) {
           if (read_index_verse) {
-            index_verse = convert_to_int (line);
+            index_verse = filter::strings::convert_to_int (line);
             read_index_verse = false;
           } else if (line == search_logic_verse_separator ()) {
             read_index_verse = true;
@@ -320,8 +314,8 @@ vector <Passage> search_logic_search_bible_usfm (string bible, string search)
           } else if (line == search_logic_index_separator ()) {
             index_item++;
           } else if (index_item == USFM_LOWER) {
-            if (line.find (search) != string::npos) {
-              passages.push_back (Passage (bible, book, chapter, convert_to_string (index_verse)));
+            if (line.find (search) != std::string::npos) {
+              passages.push_back (Passage (bible, book, chapter, std::to_string (index_verse)));
             }
           }
         }
@@ -336,27 +330,26 @@ vector <Passage> search_logic_search_bible_usfm (string bible, string search)
 // Performs a case-sensitive search of the USFM of one $bible.
 // Returns an array with the rowid's of matching verses.
 // $search: Contains the text to search for.
-vector <Passage> search_logic_search_bible_usfm_case_sensitive (string bible, string search)
+std::vector <Passage> search_logic_search_bible_usfm_case_sensitive (std::string bible, std::string search)
 {
-  vector <Passage> passages;
+  std::vector <Passage> passages;
   
   if (search == "") return passages;
   
-  Database_Bibles database_bibles;
-  vector <int> books = database_bibles.getBooks (bible);
+  std::vector <int> books = database::bibles::get_books (bible);
   for (auto book : books) {
-    vector <int> chapters = database_bibles.getChapters (bible, book);
+    std::vector <int> chapters = database::bibles::get_chapters (bible, book);
     for (auto chapter : chapters) {
-      string path = search_logic_chapter_file (bible, book, chapter);
-      string index = filter_url_file_get_contents (path);
-      if (index.find (search) != string::npos) {
-        vector <string> lines = filter_string_explode (index, '\n');
+      std::string path = search_logic_chapter_file (bible, book, chapter);
+      std::string index = filter_url_file_get_contents (path);
+      if (index.find (search) != std::string::npos) {
+        std::vector <std::string> lines = filter::strings::explode (index, '\n');
         int index_verse = 0;
         bool read_index_verse = false;
         int index_item = 0;
         for (auto & line : lines) {
           if (read_index_verse) {
-            index_verse = convert_to_int (line);
+            index_verse = filter::strings::convert_to_int (line);
             read_index_verse = false;
           } else if (line == search_logic_verse_separator ()) {
             read_index_verse = true;
@@ -364,8 +357,8 @@ vector <Passage> search_logic_search_bible_usfm_case_sensitive (string bible, st
           } else if (line == search_logic_index_separator ()) {
             index_item++;
           } else if (index_item == USFM_RAW) {
-            if (line.find (search) != string::npos) {
-              passages.push_back (Passage (bible, book, chapter, convert_to_string (index_verse)));
+            if (line.find (search) != std::string::npos) {
+              passages.push_back (Passage (bible, book, chapter, std::to_string (index_verse)));
             }
           }
         }
@@ -378,18 +371,18 @@ vector <Passage> search_logic_search_bible_usfm_case_sensitive (string bible, st
 
 
 // Gets the plain raw text for the bible and passage given.
-string search_logic_get_bible_verse_text (string bible, int book, int chapter, int verse)
+std::string search_logic_get_bible_verse_text (std::string bible, int book, int chapter, int verse)
 {
-  vector <string> texts;
-  string path = search_logic_chapter_file (bible, book, chapter);
-  string index = filter_url_file_get_contents (path);
-  vector <string> lines = filter_string_explode (index, '\n');
+  std::vector <std::string> texts;
+  std::string path = search_logic_chapter_file (bible, book, chapter);
+  std::string index = filter_url_file_get_contents (path);
+  std::vector <std::string> lines = filter::strings::explode (index, '\n');
   int index_verse = 0;
   bool read_index_verse = false;
   int index_item = 0;
   for (auto & line : lines) {
     if (read_index_verse) {
-      index_verse = convert_to_int (line);
+      index_verse = filter::strings::convert_to_int (line);
       read_index_verse = false;
     } else if (line == search_logic_verse_separator ()) {
       read_index_verse = true;
@@ -402,23 +395,23 @@ string search_logic_get_bible_verse_text (string bible, int book, int chapter, i
       }
     }
   }
-  return filter_string_implode (texts, "\n");
+  return filter::strings::implode (texts, "\n");
 }
 
 
 // Gets the raw USFM for the bible and passage given.
-string search_logic_get_bible_verse_usfm (string bible, int book, int chapter, int verse)
+std::string search_logic_get_bible_verse_usfm (std::string bible, int book, int chapter, int verse)
 {
-  vector <string> texts;
-  string path = search_logic_chapter_file (bible, book, chapter);
-  string index = filter_url_file_get_contents (path);
-  vector <string> lines = filter_string_explode (index, '\n');
+  std::vector <std::string> texts;
+  std::string path = search_logic_chapter_file (bible, book, chapter);
+  std::string index = filter_url_file_get_contents (path);
+  std::vector <std::string> lines = filter::strings::explode (index, '\n');
   int index_verse = 0;
   bool read_index_verse = false;
   int index_item = 0;
   for (auto & line : lines) {
     if (read_index_verse) {
-      index_verse = convert_to_int (line);
+      index_verse = filter::strings::convert_to_int (line);
       read_index_verse = false;
     } else if (line == search_logic_verse_separator ()) {
       read_index_verse = true;
@@ -431,46 +424,46 @@ string search_logic_get_bible_verse_usfm (string bible, int book, int chapter, i
       }
     }
   }
-  return filter_string_implode (texts, "\n");
+  return filter::strings::implode (texts, "\n");
 }
 
 
-void search_logic_delete_bible (string bible)
+void search_logic_delete_bible (std::string bible)
 {
-  string fragment = search_logic_bible_fragment (bible);
+  std::string fragment = search_logic_bible_fragment (bible);
   fragment = filter_url_basename (fragment);
-  vector <string> files = filter_url_scandir (search_logic_index_folder ());
+  std::vector <std::string> files = filter_url_scandir (search_logic_index_folder ());
   for (auto & file : files) {
     if (file.find (fragment) == 0) {
-      string path = filter_url_create_path ({search_logic_index_folder (), file});
+      std::string path = filter_url_create_path ({search_logic_index_folder (), file});
       filter_url_unlink (path);
     }
   }
 }
 
 
-void search_logic_delete_book (string bible, int book)
+void search_logic_delete_book (std::string bible, int book)
 {
-  string fragment = search_logic_book_fragment (bible, book);
+  std::string fragment = search_logic_book_fragment (bible, book);
   fragment = filter_url_basename (fragment);
-  vector <string> files = filter_url_scandir (search_logic_index_folder ());
+  std::vector <std::string> files = filter_url_scandir (search_logic_index_folder ());
   for (auto & file : files) {
     if (file.find (fragment) == 0) {
-      string path = filter_url_create_path ({search_logic_index_folder (), file});
+      std::string path = filter_url_create_path ({search_logic_index_folder (), file});
       filter_url_unlink (path);
     }
   }
 }
 
 
-void search_logic_delete_chapter (string bible, int book, int chapter)
+void search_logic_delete_chapter (std::string bible, int book, int chapter)
 {
-  string fragment = search_logic_chapter_file (bible, book, chapter);
+  std::string fragment = search_logic_chapter_file (bible, book, chapter);
   fragment = filter_url_basename (fragment);
-  vector <string> files = filter_url_scandir (search_logic_index_folder ());
+  std::vector <std::string> files = filter_url_scandir (search_logic_index_folder ());
   for (auto & file : files) {
     if (file.find (fragment) == 0) {
-      string path = filter_url_create_path ({search_logic_index_folder (), file});
+      std::string path = filter_url_create_path ({search_logic_index_folder (), file});
       filter_url_unlink (path);
     }
   }
@@ -478,17 +471,16 @@ void search_logic_delete_chapter (string bible, int book, int chapter)
 
 
 // Returns the total verse count within a $bible.
-int search_logic_get_verse_count (string bible)
+int search_logic_get_verse_count (std::string bible)
 {
   int verse_count = 0;
-  Database_Bibles database_bibles;
-  vector <int> books = database_bibles.getBooks (bible);
+  std::vector <int> books = database::bibles::get_books (bible);
   for (auto book : books) {
-    vector <int> chapters = database_bibles.getChapters (bible, book);
+    std::vector <int> chapters = database::bibles::get_chapters (bible, book);
     for (auto chapter : chapters) {
-      string path = search_logic_chapter_file (bible, book, chapter);
-      string index = filter_url_file_get_contents (path);
-      vector <string> lines = filter_string_explode (index, '\n');
+      std::string path = search_logic_chapter_file (bible, book, chapter);
+      std::string index = filter_url_file_get_contents (path);
+      std::vector <std::string> lines = filter::strings::explode (index, '\n');
       for (auto & line : lines) {
         if (line == search_logic_verse_separator ()) {
           verse_count++;
@@ -501,18 +493,18 @@ int search_logic_get_verse_count (string bible)
 
 
 // Copies the search index of Bible $original to Bible $destination.
-void search_logic_copy_bible (string original, string destination)
+void search_logic_copy_bible (std::string original, std::string destination)
 {
-  string original_fragment = search_logic_bible_fragment (original);
+  std::string original_fragment = search_logic_bible_fragment (original);
   original_fragment = filter_url_basename (original_fragment);
-  string destination_fragment = search_logic_bible_fragment (destination);
+  std::string destination_fragment = search_logic_bible_fragment (destination);
   destination_fragment = filter_url_basename (destination_fragment);
-  vector <string> files = filter_url_scandir (search_logic_index_folder ());
-  for (auto & file : files) {
+  std::vector <std::string> files = filter_url_scandir (search_logic_index_folder ());
+  for (const auto& file : files) {
     if (file.find (original_fragment) == 0) {
-      string original_path = filter_url_create_path ({search_logic_index_folder (), file});
-      string destination_file = destination_fragment + file.substr (original_fragment.length ());
-      string destination_path = filter_url_create_path ({search_logic_index_folder (), destination_file});
+      const std::string original_path = filter_url_create_path ({search_logic_index_folder (), file});
+      const std::string destination_file = destination_fragment + file.substr (original_fragment.length ());
+      const std::string destination_path = filter_url_create_path ({search_logic_index_folder (), destination_file});
       filter_url_file_cp (original_path, destination_path);
     }
   }
@@ -520,7 +512,7 @@ void search_logic_copy_bible (string original, string destination)
 
 
 // This generated the plain text that can be used as a reference during a replace operation.
-string search_logic_plain_replace_verse_text (string usfm)
+std::string search_logic_plain_replace_verse_text (std::string usfm)
 {
   // Text filter for getting the plain text.
   Filter_Text filter_text = Filter_Text ("");
@@ -530,16 +522,16 @@ string search_logic_plain_replace_verse_text (string usfm)
   filter_text.run (styles_logic_standard_sheet ());
   
   // The resulting plain text.
-  string plain_text;
+  std::string plain_text;
 
   // Add the clean verse texts.
-  map <int, string> texts = filter_text.getVersesText ();
+  std::map <int, std::string> texts = filter_text.getVersesText ();
   for (auto & element : texts) {
     plain_text.append (element.second + "\n");
   }
 
   // Add any clean headings.
-  map <int, string> headings = filter_text.verses_headings;
+  std::map <int, std::string> headings = filter_text.verses_headings;
   for (auto & element : headings) {
     plain_text.append (element.second + "\n");
   }
@@ -548,7 +540,7 @@ string search_logic_plain_replace_verse_text (string usfm)
   plain_text.append (filter_text.text_text->getnote ());
   
   // Clean up.
-  plain_text = filter_string_trim (plain_text);
+  plain_text = filter::strings::trim (plain_text);
   
   // Done.
   return plain_text;
