@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -32,57 +32,55 @@
 #include <search/logic.h>
 #include <menu/logic.h>
 #include <dialog/list2.h>
-using namespace std;
 
 
-string search_replace_url ()
+std::string search_replace_url ()
 {
   return "search/replace";
 }
 
 
-bool search_replace_acl (void * webserver_request)
+bool search_replace_acl (Webserver_Request& webserver_request)
 {
-  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
+  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ()))
+    return true;
   auto [ read, write ] = access_bible::any (webserver_request);
   return write;
 }
 
 
-string search_replace (void * webserver_request)
+std::string search_replace (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+  const std::string siteUrl = config::logic::site_url (webserver_request);
   
-  string siteUrl = config::logic::site_url (webserver_request);
-  
-  string bible = request->database_config_user()->getBible ();
-  if (request->query.count ("b")) {
-    bible = request->query ["b"];
+  std::string bible = webserver_request.database_config_user()->getBible ();
+  if (webserver_request.query.count ("b")) {
+    bible = webserver_request.query ["b"];
   }
   
-  string searchfor = request->query ["q"];
-  string replacewith = request->query ["r"];
-  string id = request->query ["id"];
+  std::string searchfor = webserver_request.query ["q"];
+  std::string replacewith = webserver_request.query ["r"];
+  std::string id = webserver_request.query ["id"];
   
   if (!id.empty ()) {
     
     // Get the Bible and passage for this identifier.
     Passage passage = Passage::decode (id);
-    string bible2 = passage.m_bible;
+    std::string bible2 = passage.m_bible;
     int book = passage.m_book;
     int chapter = passage.m_chapter;
-    string verse = passage.m_verse;
+    std::string verse = passage.m_verse;
     
     // Get the plain text.
-    string text = search_logic_get_bible_verse_text (bible2, book, chapter, filter::strings::convert_to_int (verse));
+    std::string text = search_logic_get_bible_verse_text (bible2, book, chapter, filter::strings::convert_to_int (verse));
     
     // Format it.
-    string link = filter_passage_link_for_opening_editor_at (book, chapter, verse);
-    string oldtext = text;
-    string newtext = filter::strings::replace (searchfor, replacewith, text);
+    std::string link = filter_passage_link_for_opening_editor_at (book, chapter, verse);
+    std::string oldtext = text;
+    std::string newtext = filter::strings::replace (searchfor, replacewith, text);
     if (replacewith != "") newtext = filter::strings::markup_words ({replacewith}, newtext);
     
-    string output =
+    std::string output =
     "<div id=\"" + filter::strings::convert_to_string (id) + "\">\n"
     "<p><a href=\"replace\"> ✔ </a> <a href=\"delete\">" + filter::strings::emoji_wastebasket () + "</a> $link</p>\n"
     "<p>" + oldtext + "</p>\n"
@@ -94,23 +92,23 @@ string search_replace (void * webserver_request)
   }
 
   // Set the user chosen Bible as the current Bible.
-  if (request->post.count ("bibleselect")) {
-    string bibleselect = request->post ["bibleselect"];
-    request->database_config_user ()->setBible (bibleselect);
-    return string();
+  if (webserver_request.post.count ("bibleselect")) {
+    std::string bibleselect = webserver_request.post ["bibleselect"];
+    webserver_request.database_config_user ()->setBible (bibleselect);
+    return std::string();
   }
   
-  string page;
+  std::string page;
   
-  Assets_Header header = Assets_Header (translate("Replace"), request);
+  Assets_Header header = Assets_Header (translate("Replace"), webserver_request);
   header.add_bread_crumb (menu_logic_search_menu (), menu_logic_search_text ());
   page = header.run ();
   
   Assets_View view;
 
   {
-    string bible_html;
-    vector <string> accessible_bibles = access_bible::bibles (request);
+    std::string bible_html;
+    std::vector <std::string> accessible_bibles = access_bible::bibles (webserver_request);
     for (auto selectable_bible : accessible_bibles) {
       bible_html = Options_To_Select::add_selection (selectable_bible, selectable_bible, bible_html);
     }
@@ -118,8 +116,8 @@ string search_replace (void * webserver_request)
   }
   view.set_variable ("bible", bible);
   
-  stringstream script {};
-  script << "var searchBible = " << quoted(bible) << ";";
+  std::stringstream script {};
+  script << "var searchBible = " << std::quoted(bible) << ";";
   view.set_variable ("script", script.str());
   
   page += view.render ("search", "replace");
