@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,12 @@
  */
 
 
-#ifndef INCLUDED_SEARCH_SEARCH2_H
-#define INCLUDED_SEARCH_SEARCH2_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+class Webserver_Request;
 
-string search_search2_url ();
-bool search_search2_acl (void * webserver_request);
-string search_search2 (void * webserver_request);
-
-
-#endif
+std::string search_search2_url ();
+bool search_search2_acl (Webserver_Request& webserver_request);
+std::string search_search2 (Webserver_Request& webserver_request);
