@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2024 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -246,7 +246,7 @@ void sendreceive_bibles ()
   // The client compares the two checksums.
   // If they match, it means everything is in sync.
   bibles = database::bibles::get_bibles ();
-  std::string client_checksum = checksum_logic::get_bibles (webserver_request, bibles);
+  std::string client_checksum = checksum_logic::get_bibles (bibles);
   post ["a"] = std::to_string (Sync_Logic::bibles_get_total_checksum);
   std::string server_checksum = sync_logic.post (post, url, error);
   if (!error.empty ()) {
@@ -326,7 +326,7 @@ void sendreceive_bibles ()
     
     // Compare the checksum of the whole Bible on client and server
     // to see if this Bible is in sync.
-    std::string client_checksum_bible = checksum_logic::get_bible (webserver_request, bible);
+    std::string client_checksum_bible = checksum_logic::get_bible (bible);
     post ["a"] = std::to_string (Sync_Logic::bibles_get_bible_checksum);
     post ["b"] = bible;
     std::string server_checksum_bible = sync_logic.post (post, url, error);
@@ -397,7 +397,7 @@ void sendreceive_bibles ()
       
       
       // Compare the checksum for the whole book on the client with the same on the server to see if this book is in sync.
-      std::string client_checksum_book = checksum_logic::get_book (webserver_request, bible, book);
+      std::string client_checksum_book = checksum_logic::get_book (bible, book);
       post ["a"] = std::to_string (Sync_Logic::bibles_get_book_checksum);
       post ["bk"] = std::to_string (book);
       std::string server_checksum_book = sync_logic.post (post, url, error);
@@ -469,7 +469,7 @@ void sendreceive_bibles ()
         
         // Get checksum for the chapter on client and on server.
         // If both are the same, it means the USFM in both is the same, and we're done.
-        std::string client_checksum_chapter = checksum_logic::get_chapter (webserver_request, bible, book, chapter);
+        std::string client_checksum_chapter = checksum_logic::get_chapter (bible, book, chapter);
         post ["a"] = std::to_string (Sync_Logic::bibles_get_chapter_checksum);
         post ["c"] = std::to_string (chapter);
         std::string server_checksum_chapter = sync_logic.post (post, url, error);
