@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -35,7 +35,6 @@
 #include <database/logs.h>
 #include <database/config/general.h>
 #include <database/privileges.h>
-using namespace std;
 
 
 int sendreceive_files_watchdog {0};
@@ -48,19 +47,19 @@ void sendreceive_files_done ()
 }
 
 
-string sendreceive_files_text ()
+std::string sendreceive_files_text ()
 {
   return translate("Files") + ": ";
 }
 
 
-string sendreceive_files_sendreceive_text ()
+std::string sendreceive_files_sendreceive_text ()
 {
   return sendreceive_files_text () + translate ("Synchronizing");
 }
 
 
-string sendreceive_files_up_to_date_text ()
+std::string sendreceive_files_up_to_date_text ()
 {
   return sendreceive_files_text () + translate ("Up to date");
 }
@@ -70,7 +69,7 @@ void sendreceive_files ()
 {
   // Watchdog handler.
   if (sendreceive_files_watchdog) {
-    int time = filter::date::seconds_since_epoch ();
+    const int time = filter::date::seconds_since_epoch ();
     if (time < (sendreceive_files_watchdog + 900)) {
       Database_Logs::log (sendreceive_files_text () + translate("Still busy"), Filter_Roles::translator ());
       return;
@@ -84,59 +83,59 @@ void sendreceive_files ()
   // If any of the prioritized synchronization tasks run, postpone the current task and do not start it.
   if (sendreceive_logic_prioritized_task_is_active ()) {
     sendreceive_files_done ();
-    this_thread::sleep_for (chrono::seconds (5));
-    tasks_logic_queue (SYNCFILES);
+    std::this_thread::sleep_for (std::chrono::seconds (5));
+    tasks_logic_queue (task::sync_files);
     return;
   }
   
   
-  Webserver_Request request;
-  Sync_Logic sync_logic = Sync_Logic (&request);
+  Webserver_Request webserver_request {};
+  Sync_Logic sync_logic (webserver_request);
 
   
   Database_Logs::log (sendreceive_files_sendreceive_text (), Filter_Roles::translator ());
+
   
-  
-  string address = Database_Config_General::getServerAddress ();
-  int port = Database_Config_General::getServerPort ();
-  string url = client_logic_url (address, port, sync_files_url ());
+  const std::string address = database::config::general::get_server_address ();
+  const int port = database::config::general::get_server_port ();
+  const std::string url = client_logic_url (address, port, sync_files_url ());
   
   
   // The verion number of the set of directories this client uses.
-  int version = 5;
+  const int version {5};
   
   
-  map <string, string> post;
+  std::map <std::string, std::string> post {};
 
   
   // The client user is the sole user registered on the system.
-  vector <string> users = request.database_users ()->get_users ();
+  const std::vector <std::string> users = webserver_request.database_users ()->get_users ();
   if (users.empty ()) {
     Database_Logs::log (translate("No user found"), Filter_Roles::translator ());
     sendreceive_files_done ();
     return;
   }
-  string user = users [0];
-  post ["u"] = bin2hex (user);
+  const std::string user {users.at(0)};
+  post ["u"] = filter::strings::bin2hex (user);
 
   
-  post ["v"] = convert_to_string (version);
-  string error;
-  string response;
-  int iresponse { 0 };
+  post ["v"] = std::to_string (version);
+  std::string error {};
+  std::string response {};
+  int iresponse {0};
   
 
   // Request the checksum of all relevant files on the server.
   // Compare it with the local checksum for the same set of files.
   // If the two match: Ready.
-  post ["a"] = convert_to_string (Sync_Logic::files_total_checksum);
+  post ["a"] = std::to_string (Sync_Logic::files_total_checksum);
   response = sync_logic.post (post, url, error);
   if (!error.empty ()) {
     Database_Logs::log (sendreceive_files_text () + "Failure requesting total checksum: " + error, Filter_Roles::translator ());
     sendreceive_files_done ();
     return;
   }
-  iresponse = convert_to_int (response);
+  iresponse = filter::strings::convert_to_int (response);
   int checksum = Sync_Logic::files_get_total_checksum (version, user);
   if (iresponse == checksum) {
     Database_Logs::log (sendreceive_files_up_to_date_text (), Filter_Roles::translator ());
@@ -146,28 +145,28 @@ void sendreceive_files ()
 
   
   // Go through the directories relevant to the version.
-  vector <string> directories = Sync_Logic::files_get_directories (version, user);
+  const std::vector <std::string> directories = Sync_Logic::files_get_directories (version, user);
   for (size_t d = 0; d < directories.size (); d++) {
     
 
     // The directory name itself is not posted to the server,
     // but rather the index of the directory in the entire list.
     // This is for security reasons.
-    post ["d"] = convert_to_string (d);
-    string directory = directories [d];
+    post ["d"] = std::to_string (d);
+    const std::string directory = directories [d];
     
 
     // Request the total checksum of a directory on the server.
     // Compare it with the local checksum for the directory on the client.
     // If the two match: This directory is ready.
-    post ["a"] = convert_to_string (Sync_Logic::files_directory_checksum);
+    post ["a"] = std::to_string (Sync_Logic::files_directory_checksum);
     response = sync_logic.post (post, url, error);
     if (!error.empty ()) {
       Database_Logs::log (sendreceive_files_text () + "Failure requesting directory checksum: " + error, Filter_Roles::translator ());
       sendreceive_files_done ();
       return;
     }
-    iresponse = convert_to_int (response);
+    iresponse = filter::strings::convert_to_int (response);
     int checksum_d = Sync_Logic::files_get_directory_checksum (directory);
     if (iresponse == checksum_d) {
       continue;
@@ -175,22 +174,22 @@ void sendreceive_files ()
 
     
     // Retrieve the list of files in a directory on the server.
-    post ["a"] = convert_to_string (Sync_Logic::files_directory_files);
+    post ["a"] = std::to_string (Sync_Logic::files_directory_files);
     response = sync_logic.post (post, url, error);
     if (!error.empty ()) {
       Database_Logs::log (sendreceive_files_text () + "Failure requesting directory files: " + error, Filter_Roles::translator ());
       sendreceive_files_done ();
       return;
     }
-    vector <string> server_files = filter_string_explode (response, '\n');
+    const std::vector <std::string> server_files = filter::strings::explode (response, '\n');
     
     
     // Delete files that exist locally but not on the server.
-    vector <string> client_files = Sync_Logic::files_get_files (directory);
-    vector <string> files = filter_string_array_diff (client_files, server_files);
-    for (auto file : files) {
+    const std::vector <std::string> client_files = Sync_Logic::files_get_files (directory);
+    const std::vector <std::string> files = filter::strings::array_diff (client_files, server_files);
+    for (const auto& file : files) {
       Database_Logs::log (sendreceive_files_text () + "Deleting file: " + filter_url_create_path ({directory, file}), Filter_Roles::translator ());
-      string path = filter_url_create_root_path ({directory, file});
+      std::string path = filter_url_create_root_path ({directory, file});
       filter_url_unlink (path);
       // Attempt to delete the directory, which will only succeed if it is empty.
       path = filter_url_dirname (path);
@@ -199,13 +198,13 @@ void sendreceive_files ()
     
 
     // Deal with each file individually.
-    for (auto & file : server_files) {
+    for (const auto& file : server_files) {
 
 
       // Request checksum of this file,
       // compare it with the local checksum,
       // and skip the file if the checksums match.
-      post ["a"] = convert_to_string (Sync_Logic::files_file_checksum);
+      post ["a"] = std::to_string (Sync_Logic::files_file_checksum);
       post ["f"] = file;
       response = sync_logic.post (post, url, error);
       if (!error.empty ()) {
@@ -213,8 +212,8 @@ void sendreceive_files ()
         sendreceive_files_done ();
         return;
       }
-      int iresponse_file = convert_to_int (response);
-      int checksum_file = Sync_Logic::files_get_file_checksum (directory, file);
+      const int iresponse_file = filter::strings::convert_to_int (response);
+      const int checksum_file = Sync_Logic::files_get_file_checksum (directory, file);
       if (iresponse_file == checksum_file) {
         continue;
       }
@@ -226,16 +225,16 @@ void sendreceive_files ()
       // Download the file from the server, and store it locally on the client.
       Database_Logs::log (sendreceive_files_text () + "Downloading " + filter_url_create_path ({directory, file}), Filter_Roles::translator ());
       // Local file path where to save resource.
-      string fullpath = filter_url_create_root_path ({directory, file});
+      const std::string fullpath = filter_url_create_root_path ({directory, file});
       // Create directory if it does not yet exist.
-      string dirpath = filter_url_dirname (fullpath);
+      const std::string dirpath = filter_url_dirname (fullpath);
       if (!file_or_dir_exists (dirpath)) {
         filter_url_mkdir (dirpath);
       }
-      string download_url = filter_url_build_http_query (url, "a", convert_to_string (Sync_Logic::files_file_download));
-      download_url = filter_url_build_http_query (download_url, "v", convert_to_string (version));
-      download_url = filter_url_build_http_query (download_url, "d", convert_to_string (d));
-      download_url = filter_url_build_http_query (download_url, "u", bin2hex (user));
+      std::string download_url = filter_url_build_http_query (url, "a", std::to_string (Sync_Logic::files_file_download));
+      download_url = filter_url_build_http_query (download_url, "v", std::to_string (version));
+      download_url = filter_url_build_http_query (download_url, "d", std::to_string (d));
+      download_url = filter_url_build_http_query (download_url, "u", filter::strings::bin2hex (user));
       download_url = filter_url_build_http_query (download_url, "f", filter_url_urlencode (file));
       // Download and save file locally.
       filter_url_download_file (download_url, fullpath, error, true);
@@ -247,7 +246,7 @@ void sendreceive_files ()
       // When downloading privileges, load them in the database on the client.
       if (directory == database_privileges_directory (user)) {
         if (file == database_privileges_file ()) {
-          Database_Privileges::load (user, filter_url_file_get_contents (fullpath));
+          DatabasePrivileges::load (user, filter_url_file_get_contents (fullpath));
         }
       }
     }
