@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -40,25 +40,24 @@
 #include <checksum/logic.h>
 #include <bb/logic.h>
 #include <notes/logic.h>
-using namespace std;
 
 
 int sendreceive_notes_watchdog = 0;
 
 
-string sendreceive_notes_text ()
+std::string sendreceive_notes_text ()
 {
   return translate("Notes") + ": ";
 }
 
 
-string sendreceive_notes_sendreceive_text ()
+std::string sendreceive_notes_sendreceive_text ()
 {
   return sendreceive_notes_text () + translate ("Send/receive");
 }
 
 
-string sendreceive_notes_up_to_date_text ()
+std::string sendreceive_notes_up_to_date_text ()
 {
   return sendreceive_notes_text () + translate ("Up to date");
 }
@@ -98,16 +97,16 @@ void sendreceive_notes ()
 // Upload all note actions to the server.
 bool sendreceive_notes_upload ()
 {
-  Webserver_Request request;
-  Sync_Logic sync_logic = Sync_Logic (&request);
-  Database_Notes database_notes (&request);
+  Webserver_Request webserver_request;
+  Sync_Logic sync_logic (webserver_request);
+  Database_Notes database_notes (webserver_request);
   Database_NoteActions database_noteactions = Database_NoteActions ();
   
   
   Database_Logs::log (sendreceive_notes_sendreceive_text (), Filter_Roles::translator ());
   
   
-  string response = client_logic_connection_setup ("", "");
+  std::string response = client_logic_connection_setup ("", "");
   int iresponse = filter::strings::convert_to_int (response);
   if (iresponse < Filter_Roles::guest () || iresponse > Filter_Roles::admin ()) {
     Database_Logs::log (sendreceive_notes_text () + translate("Failure to initiate connection"), Filter_Roles::translator ());
@@ -116,31 +115,31 @@ bool sendreceive_notes_upload ()
   
   
   // Set the correct user in the session: The sole user on the Client.
-  vector <string> users = request.database_users ()->get_users ();
+  std::vector <std::string> users = webserver_request.database_users ()->get_users ();
   if (users.empty ()) {
     Database_Logs::log (sendreceive_notes_text () + translate("No local user found"), Filter_Roles::translator ());
     return false;
   }
-  string user = users [0];
-  request.session_logic ()->set_username (user);
+  std::string user = users [0];
+  webserver_request.session_logic ()->set_username (user);
   
   
   // The basic request to be POSTed to the server.
   // It contains the user's credentials.
-  map <string, string> post;
+  std::map <std::string, std::string> post;
   post ["u"] = filter::strings::bin2hex (user);
-  post ["p"] = request.database_users ()->get_md5 (user);
-  post ["l"] = filter::strings::convert_to_string (request.database_users ()->get_level (user));
+  post ["p"] = webserver_request.database_users ()->get_md5 (user);
+  post ["l"] = std::to_string (webserver_request.database_users ()->get_level (user));
   
   
   // Error variable.
-  string error;
+  std::string error;
   
   
   // Server URL to call.
-  string address = Database_Config_General::getServerAddress ();
-  int port = Database_Config_General::getServerPort ();
-  string url = client_logic_url (address, port, sync_notes_url ());
+  std::string address = database::config::general::get_server_address ();
+  int port = database::config::general::get_server_port ();
+  std::string url = client_logic_url (address, port, sync_notes_url ());
   
   
   // Check on communication errors to be careful that there will be no loss of notes data on the client.
@@ -152,36 +151,36 @@ bool sendreceive_notes_upload ()
   // While sending note actions, the database method to retrieve them
   // keeps the sequence of the actions as they occurred,
   // as later updates can undo or affect earlier updates.
-  vector <int> notes = database_noteactions.getNotes ();
+  std::vector <int> notes = database_noteactions.getNotes ();
   for (auto identifier : notes) {
     
 
-    string summary = database_notes.get_summary (identifier);
+    std::string summary = database_notes.get_summary (identifier);
     if (summary.empty ()) summary = "<deleted>";
     Database_Logs::log (sendreceive_notes_text () + translate("Sending note to server") + ": " + summary, Filter_Roles::translator ());
     
     
     // Get all the actions for the current note.
-    vector <Database_Note_Action> note_actions = database_noteactions.getNoteData (identifier);
+    std::vector <Database_Note_Action> note_actions = database_noteactions.getNoteData (identifier);
     
     
     // Due to some updates sent out here, record final actions to get the updated note from the server.
-    map <int, bool> final_get_actions;
+    std::map <int, bool> final_get_actions;
     
     
     // Deal with the note actions for this note.
     for (auto note_action : note_actions) {
       
       int rowid = note_action.rowid;
-      string username = note_action.username;
+      std::string username = note_action.username;
       //int timestamp = note_action.timestamp;
       int action = note_action.action;
-      string content = note_action.content;
+      std::string content = note_action.content;
       
       
       // Generate a POST request.
-      post ["i"] = filter::strings::convert_to_string (identifier);
-      post ["a"] = filter::strings::convert_to_string (action);
+      post ["i"] = std::to_string (identifier);
+      post ["a"] = std::to_string (action);
       switch (action) {
         case Sync_Logic::notes_put_create_initiate: break;
         case Sync_Logic::notes_put_create_complete: break;
@@ -208,7 +207,7 @@ bool sendreceive_notes_upload ()
         }
         case Sync_Logic::notes_put_severity:
         {
-          content = filter::strings::convert_to_string (database_notes.get_raw_severity (identifier));
+          content = std::to_string (database_notes.get_raw_severity (identifier));
           break;
         }
         case Sync_Logic::notes_put_bible:
@@ -284,10 +283,10 @@ bool sendreceive_notes_upload ()
     
     // Deal with the extra, added, note actions.
     for (int action = Sync_Logic::notes_get_total; action <= Sync_Logic::notes_get_modified; action++) {
-      map <string, string> post2;
+      std::map <std::string, std::string> post2;
       post2 ["u"] = filter::strings::bin2hex (user);
-      post2 ["i"] = filter::strings::convert_to_string (identifier);
-      post2 ["a"] = filter::strings::convert_to_string (action);
+      post2 ["i"] = std::to_string (identifier);
+      post2 ["a"] = std::to_string (action);
       sendreceive_notes_kick_watchdog ();
       response = sync_logic.post (post2, url, error);
       if (error.empty ()) {
@@ -297,11 +296,11 @@ bool sendreceive_notes_upload ()
           }
         }
         if (action == Sync_Logic::notes_get_subscribers) {
-          vector <string> subscribers = filter::strings::explode (response, '\n');
+          std::vector <std::string> subscribers = filter::strings::explode (response, '\n');
           database_notes.set_subscribers (identifier, subscribers);
         }
         if (action == Sync_Logic::notes_get_assignees) {
-          vector <string> assignees = filter::strings::explode (response, '\n');
+          std::vector <std::string> assignees = filter::strings::explode (response, '\n');
           database_notes.set_assignees (identifier, assignees);
         }
         if (action == Sync_Logic::notes_get_modified) {
@@ -318,13 +317,13 @@ bool sendreceive_notes_upload ()
 // The function is called with the first and last note identifier to deal with.
 bool sendreceive_notes_download (int lowId, int highId)
 {
-  Webserver_Request request;
-  Database_Notes database_notes (&request);
+  Webserver_Request webserver_request;
+  Database_Notes database_notes (webserver_request);
   Database_NoteActions database_noteactions = Database_NoteActions ();
-  Sync_Logic sync_logic = Sync_Logic (&request);
+  Sync_Logic sync_logic (webserver_request);
   
   
-  string response = client_logic_connection_setup ("", "");
+  std::string response = client_logic_connection_setup ("", "");
   int iresponse = filter::strings::convert_to_int (response);
   if (iresponse < Filter_Roles::guest () || iresponse > Filter_Roles::admin ()) {
     Database_Logs::log (sendreceive_notes_text () + translate("Failure to initiate connection"), Filter_Roles::translator ());
@@ -338,14 +337,14 @@ bool sendreceive_notes_download (int lowId, int highId)
   // The server will use this user to find out the Bibles this user has access to,
   // so the server can select the correct notes for this user.
   // The client selects all available notes on the system.
-  vector <string> users = request.database_users ()->get_users ();
+  std::vector <std::string> users = webserver_request.database_users ()->get_users ();
   if (users.empty ()) {
     Database_Logs::log (sendreceive_notes_text () + translate("No local user found"), Filter_Roles::translator ());
     return false;
   }
-  string user = users [0];
-  request.session_logic ()->set_username (user);
-  string password = request.database_users ()->get_md5 (user);
+  std::string user = users [0];
+  webserver_request.session_logic ()->set_username (user);
+  std::string password = webserver_request.database_users ()->get_md5 (user);
 
   
   // Check for the health of the notes databases and take action if needed.
@@ -359,27 +358,27 @@ bool sendreceive_notes_download (int lowId, int highId)
   
   
   // Server URL to call.
-  string address = Database_Config_General::getServerAddress ();
-  int port = Database_Config_General::getServerPort ();
-  string url = client_logic_url (address, port, sync_notes_url ());
+  std::string address = database::config::general::get_server_address ();
+  int port = database::config::general::get_server_port ();
+  std::string url = client_logic_url (address, port, sync_notes_url ());
   
   
   // The basic request to be POSTed to the server.
-  map <string, string> post;
+  std::map <std::string, std::string> post;
   post ["u"] = filter::strings::bin2hex (user);
-  post ["l"] = filter::strings::convert_to_string (lowId);
-  post ["h"] = filter::strings::convert_to_string (highId);
+  post ["l"] = std::to_string (lowId);
+  post ["h"] = std::to_string (highId);
 
   
   // Error variable.
-  string error;
+  std::string error;
   
   
   // The script requests the total note count from the server, and their total checksum.
   // It compares this with the local notes.
   // If it matches, that means that the local notes match the notes on the server.
   // The script is then ready.
-  post ["a"] = filter::strings::convert_to_string (Sync_Logic::notes_get_total);
+  post ["a"] = std::to_string (Sync_Logic::notes_get_total);
   // Response comes after a relatively long delay: Enable burst mode timing.
   sendreceive_notes_kick_watchdog ();
   response = sync_logic.post (post, url, error, true);
@@ -387,15 +386,15 @@ bool sendreceive_notes_download (int lowId, int highId)
     Database_Logs::log (sendreceive_notes_text () + "Failure requesting totals: " + error, Filter_Roles::translator ());
     return false;
   }
-  vector <string> vresponse = filter::strings::explode (response, '\n');
+  std::vector <std::string> vresponse = filter::strings::explode (response, '\n');
   int server_total = 0;
   if (vresponse.size () >= 1) server_total = filter::strings::convert_to_int (vresponse [0]);
-  string server_checksum;
+  std::string server_checksum;
   if (vresponse.size () >= 2) server_checksum = vresponse [1];
-  vector <int> identifiers = database_notes.get_notes_in_range_for_bibles (lowId, highId, {}, true);
+  std::vector <int> identifiers = database_notes.get_notes_in_range_for_bibles (lowId, highId, {}, true);
   int client_total = static_cast<int>(identifiers.size());
   // Checksum cache to speed things up in case of thousands of notes.
-  string client_checksum = Database_State::getNotesChecksum (lowId, highId);
+  std::string client_checksum = Database_State::getNotesChecksum (lowId, highId);
   if (client_checksum.empty ()) {
     client_checksum = database_notes.get_multiple_checksum (identifiers);
     Database_State::putNotesChecksum (lowId, highId, client_checksum);
@@ -416,7 +415,7 @@ bool sendreceive_notes_download (int lowId, int highId)
   // If the total note count is too high, divide the range of notes into smaller ranges,
   // and then deal with each range.
   if (server_total > 20) {
-     vector <Sync_Logic_Range> ranges = sync_logic.create_range (lowId, highId);
+     std::vector <Sync_Logic_Range> ranges = sync_logic.create_range (lowId, highId);
     for (auto range : ranges) {
       sendreceive_notes_download (range.low, range.high);
     }
@@ -433,15 +432,15 @@ bool sendreceive_notes_download (int lowId, int highId)
   
   
   // Get note identifiers and checksums as on the server.
-  post ["a"] = filter::strings::convert_to_string (Sync_Logic::notes_get_identifiers);
+  post ["a"] = std::to_string (Sync_Logic::notes_get_identifiers);
   sendreceive_notes_kick_watchdog ();
   response = sync_logic.post (post, url, error);
   if (!error.empty ()) {
     Database_Logs::log (sendreceive_notes_text () + "Failure requesting identifiers: " + error, Filter_Roles::translator ());
     return false;
   }
-  vector <int> server_identifiers;
-  vector <string> server_checksums;
+  std::vector <int> server_identifiers;
+  std::vector <std::string> server_checksums;
   vresponse = filter::strings::explode (response, '\n');
   for (size_t i = 0; i < vresponse.size (); i++) {
     if (i % 2 == 0) {
@@ -453,7 +452,7 @@ bool sendreceive_notes_download (int lowId, int highId)
   
 
   // Get note identifiers as locally on the client.
-  vector <int> client_identifiers = database_notes.get_notes_in_range_for_bibles (lowId, highId, {}, true);
+  std::vector <int> client_identifiers = database_notes.get_notes_in_range_for_bibles (lowId, highId, {}, true);
   
   
   // The client deletes notes no longer on the server.
@@ -469,7 +468,7 @@ bool sendreceive_notes_download (int lowId, int highId)
     // Therefore limit the number of notes a client can delete in one go.
     delete_counter++;
     if (delete_counter > 15) continue;
-    string summary = database_notes.get_summary (identifier);
+    std::string summary = database_notes.get_summary (identifier);
     database_notes.erase (identifier);
     Database_Logs::log (sendreceive_notes_text () + "Deleting because it is not on the server: " + summary, Filter_Roles::translator ());
   }
@@ -477,7 +476,7 @@ bool sendreceive_notes_download (int lowId, int highId)
 
   // Check whether the local notes on the client match the ones on the server.
   // If needed, download the note from the server.
-  vector <string> identifiers_bulk_download;
+  std::vector <std::string> identifiers_bulk_download;
   for (size_t i = 0; i < server_identifiers.size (); i++) {
 
     if (i >= server_checksums.size ()) continue;
@@ -487,32 +486,32 @@ bool sendreceive_notes_download (int lowId, int highId)
     // Skip note if it is still to be sent off to the server.
     if (database_noteactions.exists (identifier)) continue;
     
-    string server_checksum_note = server_checksums [i];
-    string client_checksum_note = database_notes.get_checksum (identifier);
+    std::string server_checksum_note = server_checksums [i];
+    std::string client_checksum_note = database_notes.get_checksum (identifier);
     if (client_checksum_note == server_checksum_note) continue;
     
     // Store the identifier to be downloaded as part of a bulk download.
-    identifiers_bulk_download.push_back (filter::strings::convert_to_string (identifier));
+    identifiers_bulk_download.push_back (std::to_string (identifier));
   }
   
   // Download the notes in bulk from the Cloud, for faster transfer.
   if (!identifiers_bulk_download.empty ()) {
     sendreceive_notes_kick_watchdog ();
     if (identifiers_bulk_download.size () >= 3) {
-      Database_Logs::log (sendreceive_notes_text () + "Receiving multiple notes: " + filter::strings::convert_to_string (identifiers_bulk_download.size ()), Filter_Roles::manager ());
+      Database_Logs::log (sendreceive_notes_text () + "Receiving multiple notes: " + std::to_string (identifiers_bulk_download.size ()), Filter_Roles::manager ());
     }
     // Request the JSON from the Cloud: It will contain the requested notes.
     post.clear ();
-    post ["a"] = filter::strings::convert_to_string (Sync_Logic::notes_get_bulk);
-    string bulk_identifiers = filter::strings::implode (identifiers_bulk_download, "\n");
+    post ["a"] = std::to_string (Sync_Logic::notes_get_bulk);
+    std::string bulk_identifiers = filter::strings::implode (identifiers_bulk_download, "\n");
     post ["b"] = bulk_identifiers;
-    string json = sync_logic.post (post, url, error);
+    std::string json = sync_logic.post (post, url, error);
     if (!error.empty ()) {
       Database_Logs::log (sendreceive_notes_text () + "Failure requesting multiple notes: " + error, Filter_Roles::consultant ());
       return false;
     }
     // Store the notes in the file system.
-    vector <string> summaries = database_notes.set_bulk (json);
+    std::vector <std::string> summaries = database_notes.set_bulk (json);
     // More specific feedback in case it downloaded only a few notes, rather than notes in bulk.
     if (identifiers_bulk_download.size () < 3) {
       for (auto & summary : summaries) {
