@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@
 #include <database/privileges.h>
 #include <database/git.h>
 #include <database/statistics.h>
+#include <database/check.h>
 #include <styles/sheets.h>
 #include <filter/string.h>
 #include <filter/url.h>
@@ -48,23 +49,22 @@
 #include <locale/logic.h>
 #include <tasks/logic.h>
 #include <database/logic.h>
-using namespace std;
 
 
 void setup_conditionally (const char * package)
 {
-  string p (package);
+  std::string p (package);
   
   // When the package folder is the same as the document root folder,
   // it may mean that another program installs the data for us.
-  // This is the case on Android.
+  // This is the case on Android and on iOS.
   // In that case, wait till the most important data has been installed.
   if (p == config_globals_document_root) setup_wait_till_main_folders_present ();
   
   // Run the setup if the versions differ.
-  if (config::logic::version () != Database_Config_General::getInstalledDatabaseVersion ()) {
+  if (config::logic::version () != database::config::general::getInstalledDatabaseVersion ()) {
     
-    vector <string> messages;
+    std::vector <std::string> messages {};
 
     // Copy the library into the destination place.
     if (p != config_globals_document_root) {
@@ -79,21 +79,21 @@ void setup_conditionally (const char * package)
     messages.push_back ("Initializing and upgrading data");
     setup_initialize_data ();
     
-    for (auto message : messages) {
+    for (const auto& message : messages) {
       Database_Logs::log (message);
     }
     
 #ifndef HAVE_CLIENT
     // Cloud updates the available SWORD modules and web resources.
-    tasks_logic_queue (REFRESHSWORDMODULES);
-    tasks_logic_queue (REFRESHWEBRESOURCES);
+    tasks_logic_queue (task::refresh_sword_modules);
+    tasks_logic_queue (task::refresh_web_resources);
 #endif
     
     // Update installed version.
-    Database_Config_General::setInstalledDatabaseVersion (config::logic::version ());
+    database::config::general::setInstalledDatabaseVersion (config::logic::version ());
   };
 
-  if (config::logic::version () != Database_Config_General::getInstalledInterfaceVersion ()) {
+  if (config::logic::version () != database::config::general::get_installed_interface_version ()) {
     
     // In client mode or in demo mode do not display the page for entering the admin's details.
 #ifdef HAVE_CLIENT
@@ -121,53 +121,25 @@ void setup_conditionally (const char * package)
   // the app may shut down before the tasks have been completed.
   // Next time the app starts, the tasks will be restarted here, and they will run if a flag was set for them.
   // Once the tasks are really complete, they will clear the flag.
-  tasks_logic_queue (REINDEXBIBLES);
-  tasks_logic_queue (REINDEXNOTES);
+  tasks_logic_queue (task::reindex_bibles);
+  tasks_logic_queue (task::reindex_notes);
 #ifdef HAVE_CLIENT
   // Same for the resource downloader, for the client.
-  tasks_logic_queue (SYNCRESOURCES);
+  tasks_logic_queue (task::sync_resources);
 #endif
 }
 
 
 // Copies the library from $package to the webroot.
-// On a Chrome App, this works a bit different.
 void setup_copy_library (const char * package)
 {
-  /*
-  // The nacl_io library of Chrome OS fails to read the contents of a directory
-  // in the httpfs, that is, in the packaged app.
-  // It also fails to distinguish between folders and regular files in the httpfs.
-  // Therefore there is a list of directories and another one of files in the httpfs.
-  size_t package_length = 1;
-  // Read all directories and create them in the persistent webroot.
-  string path = filter_url_create_path (package, "package_directories.txt");
-  string contents = filter_url_file_get_contents (path);
-  vector <string> paths = filter::strings::explode (contents, '\n');
-  for (auto path : paths) {
-    path = config_globals_document_root + path.substr (package_length);
-    if (path.empty ()) continue;
-    config_globals_setup_message = path;
-    filter_url_mkdir (path);
-  }
-  // Read all files and copy them from the package to the persistent webroot.
-  path = filter_url_create_path (package, "package_files.txt");
-  contents = filter_url_file_get_contents (path);
-  paths = filter::strings::explode (contents, '\n');
-  for (auto path : paths) {
-    string package_path = package + path.substr (package_length);
-    string destination_path = config_globals_document_root + path.substr (package_length);
-    config_globals_setup_message = destination_path;
-    filter_url_file_cp (package_path, destination_path);
-  }
-   */
   size_t package_length = strlen (package);
   filter_url_mkdir (config_globals_document_root);
   config_globals_setup_message = "scanning";
-  vector <string> package_paths;
+  std::vector <std::string> package_paths;
   filter_url_recursive_scandir (package, package_paths);
-  for (auto package_path : package_paths) {
-    string dest_path = config_globals_document_root + package_path.substr (package_length);
+  for (const auto& package_path : package_paths) {
+    const std::string dest_path = config_globals_document_root + package_path.substr (package_length);
     config_globals_setup_message = dest_path;
     if (filter_url_is_dir (package_path)) {
       filter_url_mkdir (dest_path);
@@ -180,9 +152,9 @@ void setup_copy_library (const char * package)
 
 void setup_write_access ()
 {
-  vector <string> folders = {"exports", "git", "revisions", "dyncss", database_logic_databases (), "bibles", "fonts", "logbook", filter_url_temp_dir ()};
-  for (auto folder : folders) {
-    string path = filter_url_create_root_path ({folder});
+  std::vector <std::string> folders = {"exports", "git", "revisions", "dyncss", database_logic_databases (), "bibles", "fonts", "logbook", filter_url_temp_dir ()};
+  for (const auto& folder : folders) {
+    const std::string path = filter_url_create_root_path ({folder});
     if (!filter_url_get_write_permission (path)) {
       filter_url_set_write_permission (path);
     }
@@ -196,14 +168,15 @@ void setup_wait_till_main_folders_present ()
   bool present {true};
   do {
     present = true;
-    vector <string> folders = {"dyncss", database_logic_databases (), "databases/config/general", "logbook", "bibles", "processes"};
+    std::vector <std::string> folders = {"dyncss", database_logic_databases (), "databases/config/general", "logbook", "bibles", "processes"};
     for (const auto & folder : folders) {
-      string path = filter_url_create_root_path ({folder});
+      const std::string path = filter_url_create_root_path ({folder});
       if (!file_or_dir_exists (path)) {
         present = false;
       }
     }
-    if (!present) this_thread::sleep_for (chrono::milliseconds (300));
+    if (!present)
+      std::this_thread::sleep_for (std::chrono::milliseconds (300));
   } while (!present);
 }
 
@@ -211,27 +184,25 @@ void setup_wait_till_main_folders_present ()
 void setup_initialize_data ()
 {
   // Do the database setup.
-  Webserver_Request request;
+  Webserver_Request webserver_request;
   // Display progress in text format.
   // That provides feedback to the user during installation.
   // This alerts the user that installation is in progress, and is not stuck,
   // as the user might think when the install takes longer than expected.
   config_globals_setup_message = "users";
-  request.database_users ()->create ();
-  request.database_users ()->upgrade ();
+  webserver_request.database_users ()->create ();
+  webserver_request.database_users ()->upgrade ();
   config_globals_setup_message = "styles";
-  request.database_styles ()->create ();
+  webserver_request.database_styles ()->create ();
   config_globals_setup_message = "bible actions";
-  Database_BibleActions database_bibleactions;
-  database_bibleactions.create ();
+  database::bible_actions::create ();
   config_globals_setup_message = "checks";
-  request.database_check ()->create ();
+  database::check::create ();
   setup_generate_locale_databases (false);
 #ifdef HAVE_CLOUD
   config_globals_setup_message = "confirmations";
-  Database_Confirm database_confirm;
-  database_confirm.create ();
-  database_confirm.upgrade();
+  database::confirm::create ();
+  database::confirm::upgrade();
 #endif
   config_globals_setup_message = "jobs";
   Database_Jobs database_jobs = Database_Jobs ();
@@ -242,7 +213,7 @@ void setup_initialize_data ()
   database_sprint.create ();
 #endif
   config_globals_setup_message = "mail";
-  Database_Mail database_mail = Database_Mail (&request);
+  Database_Mail database_mail (webserver_request);
   database_mail.create ();
   config_globals_setup_message = "navigation";
   Database_Navigation database_navigation = Database_Navigation ();
@@ -255,10 +226,9 @@ void setup_initialize_data ()
   config_globals_setup_message = "versifications";
   setup_generate_versification_databases ();
   config_globals_setup_message = "modifications";
-  Database_Modifications database_modifications;
-  database_modifications.create ();
+  database::modifications::create ();
   config_globals_setup_message = "notes";
-  Database_Notes database_notes (&request);
+  Database_Notes database_notes (webserver_request);
   database_notes.create ();
   config_globals_setup_message = "state";
   Database_State::create ();
@@ -271,7 +241,7 @@ void setup_initialize_data ()
   DatabasePrivileges::optimize ();
 #ifdef HAVE_CLOUD
   config_globals_setup_message = "git";
-  Database_Git::create ();
+  database::git::create ();
   config_globals_setup_message = "statistics";
   Database_Statistics::create ();
   Database_Statistics::optimize ();
@@ -288,9 +258,9 @@ void setup_initialize_data ()
   // The installation times were so long that user were tempted to think
   // that the install process was stuck.
   // To make installation fast, the creation of the sample Bible is now done in the background.
-  vector <string> bibles = request.database_bibles()->getBibles ();
+  const std::vector <std::string> bibles = database::bibles::get_bibles ();
   if (bibles.empty ()) {
-    tasks_logic_queue (CREATESAMPLEBIBLE);
+    tasks_logic_queue (task::create_sample_bible);
   }
   
   // Schedule reindexing Bible search data.
@@ -299,16 +269,16 @@ void setup_initialize_data ()
    because it takes quite a while on low power devices,
    and the reason for the re-indexing is not clear.
   config_globals_setup_message = "indexes";
-  Database_Config_General::setIndexBibles (true);
+  database::config::general::set_index_bibles (true);
   tasks_logic_queue (REINDEXBIBLES);
   */
 }
 
 
 // Store the admin's details.
-void setup_set_admin_details (string username, string password, string email)
+void setup_set_admin_details (const std::string& username, const std::string& password, const std::string& email)
 {
-  Database_Users database_users;
+  Database_Users database_users{};
   database_users.removeUser (username);
   database_users.add_user (username, password, Filter_Roles::admin (), email);
 }
@@ -317,7 +287,7 @@ void setup_set_admin_details (string username, string password, string email)
 // Set the GUI setup status as completed.
 void setup_complete_gui ()
 {
-  Database_Config_General::setInstalledInterfaceVersion (config::logic::version ());
+  database::config::general::set_installed_interface_version (config::logic::version ());
 }
 
 
@@ -335,14 +305,15 @@ void setup_generate_locale_databases (bool progress)
   return;
 #endif
   // Generate databases for all the localizations.
-  map <string, string> localizations = locale_logic_localizations ();
-  for (auto & element : localizations) {
-    string localization = element.first;
+  const std::map <std::string, std::string> localizations = locale_logic_localizations ();
+  for (const auto& element : localizations) {
+    const std::string localization = element.first;
     if (localization.empty ()) continue;
     config_globals_setup_message = "locale " + localization;
-    if (progress) cout << config_globals_setup_message << endl;
+    if (progress) 
+      std::cout << config_globals_setup_message << std::endl;
     Database_Localization database_localization = Database_Localization (localization);
-    string path = filter_url_create_root_path ({"locale", localization + ".po"});
+    const std::string path = filter_url_create_root_path ({"locale", localization + ".po"});
     database_localization.create (path);
   }
 }
