@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -38,83 +38,82 @@
 #include <email/send.h>
 
 
-string sprint_index_url ()
+std::string sprint_index_url ()
 {
   return "sprint/index";
 }
 
 
-bool sprint_index_acl (void * webserver_request)
+bool sprint_index_acl (Webserver_Request& webserver_request)
 {
   return Filter_Roles::access_control (webserver_request, Filter_Roles::translator ());
 }
 
 
-string sprint_index ([[maybe_unused]] void * webserver_request)
+std::string sprint_index ([[maybe_unused]] Webserver_Request& webserver_request)
 {
 #ifdef HAVE_CLIENT
-  return string();
+  return std::string();
 #endif
 
 #ifdef HAVE_CLOUD
   
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Sprint database_sprint;
 
   
-  string page;
-  Assets_Header header = Assets_Header (translate("Sprint"), request);
-  header.addBreadCrumb (menu_logic_tools_menu (), menu_logic_tools_text ());
+  std::string page;
+  Assets_Header header = Assets_Header (translate("Sprint"), webserver_request);
+  header.add_bread_crumb (menu_logic_tools_menu (), menu_logic_tools_text ());
   page = header.run ();
   Assets_View view;
   
   
-  if (request->query.count ("previoussprint")) {
-    int month = request->database_config_user()->getSprintMonth ();
-    int year = request->database_config_user()->getSprintYear ();
+  if (webserver_request.query.count ("previoussprint")) {
+    int month = webserver_request.database_config_user()->getSprintMonth ();
+    int year = webserver_request.database_config_user()->getSprintYear ();
     filter::date::get_previous_month (month, year);
-    request->database_config_user()->setSprintMonth (month);
-    request->database_config_user()->setSprintYear (year);
+    webserver_request.database_config_user()->setSprintMonth (month);
+    webserver_request.database_config_user()->setSprintYear (year);
   }
   
   
-  if (request->query.count ("currentprint")) {
-    request->database_config_user()->setSprintMonth (filter::date::numerical_month (filter::date::seconds_since_epoch ()));
-    request->database_config_user()->setSprintYear (filter::date::numerical_year (filter::date::seconds_since_epoch ()));
+  if (webserver_request.query.count ("currentprint")) {
+    webserver_request.database_config_user()->setSprintMonth (filter::date::numerical_month (filter::date::seconds_since_epoch ()));
+    webserver_request.database_config_user()->setSprintYear (filter::date::numerical_year (filter::date::seconds_since_epoch ()));
   }
   
   
-  if (request->query.count ("nextsprint")) {
-    int month = request->database_config_user()->getSprintMonth ();
-    int year = request->database_config_user()->getSprintYear ();
+  if (webserver_request.query.count ("nextsprint")) {
+    int month = webserver_request.database_config_user()->getSprintMonth ();
+    int year = webserver_request.database_config_user()->getSprintYear ();
     filter::date::get_next_month (month, year);
-    request->database_config_user()->setSprintMonth (month);
-    request->database_config_user()->setSprintYear (year);
+    webserver_request.database_config_user()->setSprintMonth (month);
+    webserver_request.database_config_user()->setSprintYear (year);
   }
   
   
-  string bible = AccessBible::Clamp (webserver_request, request->database_config_user()->getBible ());
-  int month = request->database_config_user()->getSprintMonth ();
-  int year = request->database_config_user()->getSprintYear ();
+  std::string bible = access_bible::clamp (webserver_request, webserver_request.database_config_user()->getBible ());
+  int month = webserver_request.database_config_user()->getSprintMonth ();
+  int year = webserver_request.database_config_user()->getSprintYear ();
   
 
-  if (request->post.count ("id")) {
-    string id = request->post ["id"];
-    string checked = request->post ["checked"];
+  if (webserver_request.post.count ("id")) {
+    std::string id = webserver_request.post ["id"];
+    std::string checked = webserver_request.post ["checked"];
     if (id.length () >= 9) {
       // Remove "task".
       id.erase (0, 4);
       // Convert the fragment to an integer.
-      int identifier = convert_to_int (id);
+      int identifier = filter::strings::convert_to_int (id);
       // Find the fragment "box".
       size_t pos = id.find ("box");
-      if (pos != string::npos) {
+      if (pos != std::string::npos) {
         // Remove the fragment "box".
         id.erase (0, pos + 3);
         // Convert the box to an integer.
-        int box = convert_to_int (id);
-        string categorytext = Database_Config_Bible::getSprintTaskCompletionCategories (bible);
-        vector <string> categories = filter_string_explode (categorytext, '\n');
+        int box = filter::strings::convert_to_int (id);
+        std::string categorytext = database::config::bible::get_sprint_task_completion_categories (bible);
+        std::vector <std::string> categories = filter::strings::explode (categorytext, '\n');
         size_t category_count = categories.size ();
         float category_percentage = 100.0f / static_cast<float>(category_count);
         int percentage {0};
@@ -124,12 +123,12 @@ string sprint_index ([[maybe_unused]] void * webserver_request)
         database_sprint.updateComplete (identifier, percentage);
       }
     }
-    return "";
+    return std::string();
   }
   
   
-  if (request->post.count ("add")) {
-    string title = request->post ["add"];
+  if (webserver_request.post.count ("add")) {
+    std::string title = webserver_request.post ["add"];
     database_sprint.storeTask (bible, year, month, title);
     view.set_variable ("success", translate("New task added"));
     // Focus the entry for adding tasks only in case a new task was added.
@@ -137,97 +136,97 @@ string sprint_index ([[maybe_unused]] void * webserver_request)
   }
   
   
-  if (request->query.count ("mail")) {
-    int mail_year = request->database_config_user()->getSprintYear ();
-    int mail_month = request->database_config_user()->getSprintMonth ();
+  if (webserver_request.query.count ("mail")) {
+    int mail_year = webserver_request.database_config_user()->getSprintYear ();
+    int mail_month = webserver_request.database_config_user()->getSprintMonth ();
     sprint_burndown (bible, mail_year, mail_month);
     view.set_variable ("success", translate("The information was mailed to the subscribers"));
   }
   
   
-  if (request->query.count ("bible")) {
-    bible = request->query ["bible"];
+  if (webserver_request.query.count ("bible")) {
+    bible = webserver_request.query ["bible"];
     if (bible.empty()) {
       Dialog_List dialog_list = Dialog_List ("index", translate("Select which Bible to display the Sprint for"), "", "");
-      vector <string> bibles = AccessBible::Bibles (request);
+      std::vector <std::string> bibles = access_bible::bibles (webserver_request);
       for (auto & selection_bible : bibles) {
         dialog_list.add_row (selection_bible, "bible", selection_bible);
       }
       page += dialog_list.run ();
       return page;
     } else {
-      request->database_config_user()->setBible (bible);
+      webserver_request.database_config_user()->setBible (bible);
     }
   }
   
   
-  bible = AccessBible::Clamp (webserver_request, request->database_config_user()->getBible ());
+  bible = access_bible::clamp (webserver_request, webserver_request.database_config_user()->getBible ());
   
   
-  int id = convert_to_int (request->query ["id"]);
+  int id = filter::strings::convert_to_int (webserver_request.query ["id"]);
   
   
-  if (request->query.count ("remove")) {
+  if (webserver_request.query.count ("remove")) {
     database_sprint.deleteTask (id);
     view.set_variable ("success", translate("The task was removed"));
   }
   
   
-  if (request->query.count ("moveback")) {
+  if (webserver_request.query.count ("moveback")) {
     filter::date::get_previous_month (month, year);
     database_sprint.updateMonthYear (id, month, year);
     view.set_variable ("success", translate("The task was moved to the previous sprint"));
-    request->database_config_user()->setSprintMonth (month);
-    request->database_config_user()->setSprintYear (year);
+    webserver_request.database_config_user()->setSprintMonth (month);
+    webserver_request.database_config_user()->setSprintYear (year);
   }
                         
                         
-  if (request->query.count ("moveforward")) {
+  if (webserver_request.query.count ("moveforward")) {
     filter::date::get_next_month (month, year);
     database_sprint.updateMonthYear (id, month, year);
     view.set_variable ("success", translate("The task was moved to the next sprint"));
-    request->database_config_user()->setSprintMonth (month);
-    request->database_config_user()->setSprintYear (year);
+    webserver_request.database_config_user()->setSprintMonth (month);
+    webserver_request.database_config_user()->setSprintYear (year);
   }
 
   
-  if (request->post.count ("categories")) {
-    string categories = request->post ["categories"];
-    vector <string> categories2;
-    categories = filter_string_trim (categories);
-    vector <string> vcategories = filter_string_explode (categories, '\n');
+  if (webserver_request.post.count ("categories")) {
+    std::string categories = webserver_request.post ["categories"];
+    std::vector <std::string> categories2;
+    categories = filter::strings::trim (categories);
+    std::vector <std::string> vcategories = filter::strings::explode (categories, '\n');
     for (auto category : vcategories) {
-      category = filter_string_trim (category);
+      category = filter::strings::trim (category);
       if (category != "") categories2.push_back (category);
     }
-    categories = filter_string_implode (categories2, "\n");
-    Database_Config_Bible::setSprintTaskCompletionCategories (bible, categories);
+    categories = filter::strings::implode (categories2, "\n");
+    database::config::bible::set_sprint_task_completion_categories (bible, categories);
   }
   
   
   view.set_variable ("bible", bible);
-  view.set_variable ("sprint", locale_logic_month (month) + " " + convert_to_string (year));
+  view.set_variable ("sprint", locale_logic_month (month) + " " + std::to_string (year));
 
   
-  string categorytext = Database_Config_Bible::getSprintTaskCompletionCategories (bible);
+  std::string categorytext = database::config::bible::get_sprint_task_completion_categories (bible);
   view.set_variable ("categorytext", categorytext);
-  vector <string> vcategories = filter_string_explode (categorytext, '\n');
-  string categories;
+  std::vector <std::string> vcategories = filter::strings::explode (categorytext, '\n');
+  std::string categories;
   for (auto category : vcategories) {
     categories.append ("<td>" + category + "</td>\n");
   }
   view.set_variable ("categories", categories);
   
   
-  string tasks;
-  vector <int> v_tasks = database_sprint.getTasks (bible, year, month);
+  std::string tasks;
+  std::vector <int> v_tasks = database_sprint.getTasks (bible, year, month);
   for (auto & task_id : v_tasks) {
-    string title = escape_special_xml_characters (database_sprint.getTitle (task_id));
+    std::string title = filter::strings::escape_special_xml_characters (database_sprint.getTitle (task_id));
     int percentage = database_sprint.getComplete (task_id);
-    tasks.append ("<tr id=\"a" + convert_to_string (task_id) + "\">\n");
-    tasks.append ("<td><a href=\"?id=" + convert_to_string (task_id) + "&remove=\">" + emoji_wastebasket () + "</a></td>\n");
+    tasks.append ("<tr id=\"a" + std::to_string (task_id) + "\">\n");
+    tasks.append ("<td><a href=\"?id=" + std::to_string (task_id) + "&remove=\">" + filter::strings::emoji_wastebasket () + "</a></td>\n");
     tasks.append ("<td></td>\n");
-    tasks.append ("<td><a href=\"?id=" + convert_to_string (task_id) + "&moveback=\"> « </a></td>\n");
+    tasks.append ("<td><a href=\"?id=" + std::to_string (task_id) + "&moveback=\"> « </a></td>\n");
     tasks.append ("<td>" + title + "</td>\n");
     size_t category_count = vcategories.size();
     float category_percentage = 100.0f / static_cast<float>(category_count);
@@ -235,9 +234,9 @@ string sprint_index ([[maybe_unused]] void * webserver_request)
       int high = static_cast <int> (round (static_cast<float>(i2 + 1) * category_percentage));
       tasks.append ("<td>\n");
       tasks.append ("<input type=\"checkbox\" id=\"task");
-      tasks.append (convert_to_string (task_id));
+      tasks.append (std::to_string (task_id));
       tasks.append ("box");
-      tasks.append (convert_to_string (i2));
+      tasks.append (std::to_string (i2));
       tasks.append ("\"");
       if (percentage >= high)
         tasks.append (" checked");
@@ -247,7 +246,7 @@ string sprint_index ([[maybe_unused]] void * webserver_request)
       
       tasks.append ("</td>\n");
     }
-    tasks.append ("<td><a href=\"?id=" + convert_to_string (task_id) + "&moveforward=\"> » </a></td>\n");
+    tasks.append ("<td><a href=\"?id=" + std::to_string (task_id) + "&moveforward=\"> » </a></td>\n");
     tasks.append ("</tr>\n");
   }
   view.set_variable ("tasks", tasks);
@@ -260,7 +259,7 @@ string sprint_index ([[maybe_unused]] void * webserver_request)
 
 
   page += view.render ("sprint", "index");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 #endif
 }
