@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -29,9 +29,9 @@
 #include <quill/logic.h>
 
 
-Styles_Css::Styles_Css (void * webserver_request, string stylesheet)
+Styles_Css::Styles_Css (Webserver_Request& webserver_request, const std::string& stylesheet):
+m_webserver_request (webserver_request)
 {
-  m_webserver_request = webserver_request;
   m_stylesheet = stylesheet;
 }
 
@@ -60,10 +60,9 @@ void Styles_Css::generate ()
   if (editor_enabled) {
     add_editor_styles ();
   }
-  Webserver_Request * request = static_cast<Webserver_Request *>(m_webserver_request);
-  vector <string> markers = request->database_styles ()->getMarkers (m_stylesheet);
-  for (auto & marker : markers) {
-    Database_Styles_Item style = request->database_styles ()->getMarkerData (m_stylesheet, marker);
+  std::vector <std::string> markers = m_webserver_request.database_styles ()->getMarkers (m_stylesheet);
+  for (const auto& marker : markers) {
+    Database_Styles_Item style = m_webserver_request.database_styles ()->getMarkerData (m_stylesheet, marker);
     evaluate (&style);
   }
 }
@@ -72,7 +71,7 @@ void Styles_Css::generate ()
 // Evaluates the style so as to decide how it should look.
 void Styles_Css::evaluate (void * database_styles_item)
 {
-  Database_Styles_Item * style = static_cast<Database_Styles_Item *> (database_styles_item);
+  Database_Styles_Item* style = static_cast<Database_Styles_Item*> (database_styles_item);
   
   switch (style->type)
   {
@@ -95,6 +94,7 @@ void Styles_Css::evaluate (void * database_styles_item)
           add (style, true, false);
           break;
         }
+        default: break;
       }
       break;
     }
@@ -131,6 +131,7 @@ void Styles_Css::evaluate (void * database_styles_item)
           add (style, false, false);
           break;
         }
+        default: break;
       }
       break;
     }
@@ -150,9 +151,16 @@ void Styles_Css::evaluate (void * database_styles_item)
           add (style, false, false);
           break;
         }
+        default: break;
       }
       break;
     }
+    case StyleTypePicture:
+    {
+      add (style, true, false);
+      break;
+    }
+    default: break;
   }
 }
 
@@ -163,30 +171,30 @@ void Styles_Css::evaluate (void * database_styles_item)
 // $keepwithnext: Keep text in this style together with the next paragraph.
 void Styles_Css::add (void * database_styles_item, bool paragraph, bool keepwithnext)
 {
-  Database_Styles_Item * style = static_cast<Database_Styles_Item *> (database_styles_item);
+  Database_Styles_Item* style = static_cast<Database_Styles_Item*> (database_styles_item);
 
-  string class_ = style->marker;
+  std::string class_name {style->marker};
 
   // The name of the class as used in a Quill-based editor.
-  string quill_class = ", .";
+  std::string quill_class {", ."};
   if (paragraph) {
-    quill_class.append (quill_logic_class_prefix_block ());
+    quill_class.append (quill_class_prefix_block);
   } else {
-    quill_class.append (quill_logic_class_prefix_inline ());
+    quill_class.append (quill_class_prefix_inline);
   }
-  quill_class.append (class_);
+  quill_class.append (class_name);
   
   // Start with the class. Notice the dot.
-  m_code.push_back ("." + class_ + quill_class + " {");
+  m_code.push_back ("." + class_name + quill_class + " {");
   
   // Font size.
   // Since it is html and not pdf for paper, a font size of 12pt is considered to be equal to 100%.
   if (paragraph) {
-    float points = style->fontsize;
-    float percents = points * 100 / 12;
-    int fontsize = convert_to_int (percents);
+    float points {style->fontsize};
+    float percents {points * 100 / 12};
+    int fontsize = filter::strings::convert_to_int (percents);
     if (fontsize != 100) {
-      m_code.push_back ("font-size: " + convert_to_string (fontsize) + "%;");
+      m_code.push_back ("font-size: " + std::to_string (fontsize) + "%;");
     }
   }
   
@@ -232,19 +240,20 @@ void Styles_Css::add (void * database_styles_item, bool paragraph, bool keepwith
   
   // Paragraph layout properties
   if (paragraph) {
-    string spacebefore = convert_to_string (style->spacebefore);
-    string spaceafter = convert_to_string (style->spaceafter);
-    string leftmargin = convert_to_string (style->leftmargin);
-    string rightmargin = convert_to_string (style->rightmargin);
-    string firstlineindent = convert_to_string (style->firstlineindent);
+    std::string spacebefore = filter::strings::convert_to_string (style->spacebefore);
+    std::string spaceafter = filter::strings::convert_to_string (style->spaceafter);
+    std::string leftmargin = filter::strings::convert_to_string (style->leftmargin);
+    std::string rightmargin = filter::strings::convert_to_string (style->rightmargin);
+    std::string firstlineindent = filter::strings::convert_to_string (style->firstlineindent);
     
     // Text alignment options.
-    string alignment;
+    std::string alignment {};
     switch (style->justification) {
-      case AlignmentLeft:    alignment = ""; break;
-      case AlignmentCenter:  alignment = "center"; break;
-      case AlignmentRight:   alignment = "right"; break;
+      case AlignmentLeft:    alignment = "";        break;
+      case AlignmentCenter:  alignment = "center";  break;
+      case AlignmentRight:   alignment = "right";   break;
       case AlignmentJustify: alignment = "justify"; break;
+      default: break;
     }
     if (alignment != "") {
       m_code.push_back ("text-align: " + alignment + ";");
@@ -289,12 +298,12 @@ void Styles_Css::add (void * database_styles_item, bool paragraph, bool keepwith
       m_code.push_back ("vertical-align: super;");
     }
     
-    string color = style->color;
+    std::string color = style->color;
     if (color != "#000000") {
       m_code.push_back ("color: " + color + ";");
     }
     
-    string backgroundcolor = style->backgroundcolor;
+    std::string backgroundcolor = style->backgroundcolor;
     if (backgroundcolor != "#FFFFFF") {
       m_code.push_back ("background-color: " + backgroundcolor + ";");
     }
@@ -309,10 +318,10 @@ void Styles_Css::add (void * database_styles_item, bool paragraph, bool keepwith
 // Deliver the created CSS.
 // $path: If given, it saves the CSS to $path.
 // The function returns the CSS as a string.
-string Styles_Css::css (string path)
+std::string Styles_Css::css (std::string path)
 {
-  string css = filter_string_implode (m_code, "\n");
-  if (path != "") {
+  std::string css = filter::strings::implode (m_code, "\n");
+  if (!path.empty()) {
     filter_url_file_put_contents (path, css);
   }
   return css;
@@ -325,7 +334,13 @@ void Styles_Css::add_exports_styles ()
   m_code.push_back ("body { }");
   m_code.push_back ("p { margin-top: 0; margin-bottom: 0; }");
   m_code.push_back ("p.page { page-break-after: always; }");
-  m_code.push_back ("span.dropcaps { float: left; font-size: 300%; line-height: 0.85em; margin-right: 0.03em; margin-bottom:-0.25em; }");
+  // Old way of having dropcaps in the html export.
+  // But this has problem with negative indent like in poetry, visible in many Psalms.
+  // See issue https://github.com/bibledit/cloud/issues/905
+  // m_code.push_back ("span.dropcaps { float: left; font-size: 300%; line-height: 0.85em; margin-right: 0.03em; margin-bottom:-0.25em; }");
+  // New way of having dropcaps.
+  // Property "vertical-align: top;" could have been added, but then without it, it looks more beautify.
+  m_code.push_back (".dropcaps:nth-of-type(1) { font-size: 300%; line-height: 0.85em; margin-right: 0.03em; margin-bottom:-0.25em; }");
   m_code.push_back ("a { text-decoration: none; background: none; }");
   m_code.push_back ("a:visited { color: #5a3696; }");
   m_code.push_back ("a:active { color: #faa700; }");
@@ -343,15 +358,15 @@ void Styles_Css::add_editor_styles ()
 }
 
 
-void Styles_Css::customize (const string& bible)
+void Styles_Css::customize (const std::string& bible)
 {
-  string cls = Filter_Css::getClass (bible);
-  string font = Fonts_Logic::get_text_font (bible);
-  bool uploaded_font = Fonts_Logic::font_exists (font);
-  font = Fonts_Logic::get_font_path (font);
-  int direction = Database_Config_Bible::getTextDirection (bible);
-  string css = Filter_Css::get_css (cls, font, direction);
-  if (uploaded_font) css = filter_string_str_replace ("../fonts/", "", css);
+  std::string cls = Filter_Css::getClass (bible);
+  std::string font = fonts::logic::get_text_font (bible);
+  bool uploaded_font = fonts::logic::font_exists (font);
+  font = fonts::logic::get_font_path (font);
+  int direction = database::config::bible::get_text_direction (bible);
+  std::string css = Filter_Css::get_css (cls, font, direction);
+  if (uploaded_font) css = filter::strings::replace ("../fonts/", "", css);
   m_code.push_back (css);
 }
 
