@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,19 +21,21 @@
 
 #include <config/libraries.h>
 
+class Webserver_Request;
+
 class Styles_Css
 {
 public:
-  Styles_Css (void * webserver_request, const std::string & stylesheet);
+  Styles_Css (Webserver_Request& webserver_request, const std::string & stylesheet);
   Styles_Css(const Styles_Css&) = delete;
   Styles_Css operator=(const Styles_Css&) = delete;
   void editor ();
   void exports ();
   void generate ();
-  std::string css (std::string path = "");
+  std::string css (std::string path = std::string());
   void customize (const std::string& bible);
 private:
-  void * m_webserver_request {nullptr};
+  Webserver_Request& m_webserver_request;
   std::string m_stylesheet {};
   std::vector <std::string> m_code {};
   bool editor_enabled {false}; // Whether to generate CSS for the Bible text editor.
