@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -40,31 +40,30 @@
 #include <bb/logic.h>
 #include <rss/logic.h>
 #include <sendreceive/logic.h>
-using namespace std;
 
 
-string sync_bibles_url ()
+std::string sync_bibles_url ()
 {
   return "sync/bibles";
 }
 
 
-string sync_bibles_receive_chapter (Webserver_Request * request, string & bible, int book, int chapter)
+std::string sync_bibles_receive_chapter (Webserver_Request& webserver_request, std::string & bible, int book, int chapter)
 {
   // Convert the tags to plus signs, which the client had converted to tags,
   // for safekeeping the + signs during transit.
-  string oldusfm = filter_url_tag_to_plus (request->post ["o"]);
-  string newusfm = filter_url_tag_to_plus (request->post ["n"]);
-  string checksum = request->post ["s"];
+  std::string oldusfm = filter_url_tag_to_plus (webserver_request.post ["o"]);
+  std::string newusfm = filter_url_tag_to_plus (webserver_request.post ["n"]);
+  std::string checksum = webserver_request.post ["s"];
 
   
-  string username = request->session_logic ()->currentUser ();
-  string bookname = database::books::get_english_from_id (static_cast<book_id>(book));
+  const std::string& username = webserver_request.session_logic ()->get_username ();
+  std::string bookname = database::books::get_english_from_id (static_cast<book_id>(book));
   
   
   // Check whether the user has write-access to the Bible book.
-  if (!access_bible::book_write (request, username, bible, book)) {
-    string message = "User " + username + " does not have write access to Bible " + bible;
+  if (!access_bible::book_write (webserver_request, username, bible, book)) {
+    std::string message = "User " + username + " does not have write access to Bible " + bible;
     Database_Logs::log (message, Filter_Roles::manager ());
     // The Cloud will email the user with details about the issue.
     bible_logic::client_no_write_access_mail (bible, book, chapter, username, oldusfm, newusfm);
@@ -76,13 +75,13 @@ string sync_bibles_receive_chapter (Webserver_Request * request, string & bible,
   
   // Check checksum.
   if (checksum != checksum_logic::get (oldusfm + newusfm)) {
-    string message = "The received data is corrupted";
+    std::string message = "The received data is corrupted";
     Database_Logs::log (message, Filter_Roles::manager ());
     return message;
   }
   
   
-  string serverusfm = request->database_bibles()->getChapter (bible, book, chapter);
+  std::string serverusfm = database::bibles::get_chapter (bible, book, chapter);
   
   
   // There have been cases like this:
@@ -97,9 +96,9 @@ string sync_bibles_receive_chapter (Webserver_Request * request, string & bible,
   
 
   // Gather data for recording the changes made by the user, for the change notifications.
-  int old_id = request->database_bibles()->getChapterId (bible, book, chapter);
-  string old_text = serverusfm;
-  string new_text = newusfm;
+  int old_id = database::bibles::get_chapter_id (bible, book, chapter);
+  std::string old_text = serverusfm;
+  std::string new_text = newusfm;
   
   
   // Server logs the change from the client.
@@ -111,8 +110,8 @@ string sync_bibles_receive_chapter (Webserver_Request * request, string & bible,
     bible_logic::store_chapter (bible, book, chapter, newusfm);
   } else if (newusfm != serverusfm) {
     // Do a merge in case the client sends USFM that differs from what's on the server.
-    vector <Merge_Conflict> conflicts;
-    string mergedusfm = filter_merge_run (oldusfm, newusfm, serverusfm, true, conflicts);
+    std::vector <Merge_Conflict> conflicts;
+    std::string mergedusfm = filter_merge_run (oldusfm, newusfm, serverusfm, true, conflicts);
     // Update the server with the new chapter data.
     bible_logic::store_chapter (bible, book, chapter, mergedusfm);
     // Check on the merge.
@@ -124,13 +123,12 @@ string sync_bibles_receive_chapter (Webserver_Request * request, string & bible,
   
 
   // If text was saved, record it as a change entered by the user.
-  int new_id = request->database_bibles()->getChapterId (bible, book, chapter);
+  int new_id = database::bibles::get_chapter_id (bible, book, chapter);
   if (new_id != old_id) {
-    Database_Modifications database_modifications;
-    database_modifications.recordUserSave (username, bible, book, chapter, old_id, old_text, new_id, new_text);
+    database::modifications::recordUserSave (username, bible, book, chapter, old_id, old_text, new_id, new_text);
 #ifdef HAVE_CLOUD
     if (sendreceive_git_repository_linked (bible)) {
-      Database_Git::store_chapter (username, bible, book, chapter, old_text, new_text);
+      database::git::store_chapter (username, bible, book, chapter, old_text, new_text);
     }
     rss_logic_schedule_update (username, bible, book, chapter, old_text, new_text);
 #endif
@@ -146,28 +144,27 @@ string sync_bibles_receive_chapter (Webserver_Request * request, string & bible,
 }
 
 
-string sync_bibles (void * webserver_request)
+std::string sync_bibles (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  Sync_Logic sync_logic = Sync_Logic (webserver_request);
+  Sync_Logic sync_logic (webserver_request);
 
   if (!sync_logic.security_okay ()) {
     // When the Cloud enforces https, inform the client to upgrade.
-    request->response_code = 426;
-    return "";
+    webserver_request.response_code = 426;
+    return std::string();
   }
   
   // Check on the credentials.
-  if (!sync_logic.credentials_okay ()) return "";
+  if (!sync_logic.credentials_okay ()) return std::string();
   
   // Client makes a prioritized server call: Record the client's IP address.
   sync_logic.prioritized_ip_address_record ();
   
   // Get the relevant parameters the client may have POSTed to us, the server.
-  int action = filter::strings::convert_to_int (request->post ["a"]);
-  string bible = request->post ["b"];
-  int book = filter::strings::convert_to_int (request->post ["bk"]);
-  int chapter = filter::strings::convert_to_int (request->post ["c"]);
+  int action = filter::strings::convert_to_int (webserver_request.post ["a"]);
+  std::string bible = webserver_request.post ["b"];
+  int book = filter::strings::convert_to_int (webserver_request.post ["bk"]);
+  int chapter = filter::strings::convert_to_int (webserver_request.post ["c"]);
   
   switch (action) {
     case Sync_Logic::bibles_get_total_checksum:
@@ -176,65 +173,65 @@ string sync_bibles (void * webserver_request)
       // checks which Bibles this user has access to,
       // calculate the checksum of all chapters in those Bibles,
       // and returns this checksum to the client.
-      string username = request->session_logic ()->currentUser ();
-      vector <string> bibles = access_bible::bibles (request, username);
-      string server_checksum = checksum_logic::get_bibles (request, bibles);
+      const std::string& username = webserver_request.session_logic ()->get_username ();
+      std::vector <std::string> bibles = access_bible::bibles (webserver_request, username);
+      std::string server_checksum = checksum_logic::get_bibles (bibles);
       return server_checksum;
     }
     case Sync_Logic::bibles_get_bibles:
     {
       // The server reads the credentials from the client's user,
       // and responds with a list of Bibles this user has access to.
-      string username = request->session_logic ()->currentUser ();
-      vector <string> bibles = access_bible::bibles (request, username);
-      string checksum = checksum_logic::get (bibles);
-      string s_bibles = filter::strings::implode (bibles, "\n");
+      const std::string& username = webserver_request.session_logic ()->get_username ();
+      std::vector <std::string> bibles = access_bible::bibles (webserver_request, username);
+      std::string checksum = checksum_logic::get (bibles);
+      std::string s_bibles = filter::strings::implode (bibles, "\n");
       return checksum + "\n" + s_bibles;
     }
     case Sync_Logic::bibles_get_bible_checksum:
     {
       // The server responds with the checksum for the whole Bible.
-      return checksum_logic::get_bible (request, bible);
+      return checksum_logic::get_bible (bible);
     }
     case Sync_Logic::bibles_get_books:
     {
       // The server responds with a checksum and then the list of books in the Bible.
-      vector <int> server_books = request->database_bibles()->getBooks (bible);
-      vector <string> v_server_books;
-      for (auto server_book : server_books) v_server_books.push_back (filter::strings::convert_to_string (server_book));
-      string s_server_books = filter::strings::implode (v_server_books, "\n");
-      string checksum = checksum_logic::get (v_server_books);
+      std::vector <int> server_books = database::bibles::get_books (bible);
+      std::vector <std::string> v_server_books;
+      for (auto server_book : server_books) v_server_books.push_back (std::to_string (server_book));
+      std::string s_server_books = filter::strings::implode (v_server_books, "\n");
+      std::string checksum = checksum_logic::get (v_server_books);
       return checksum + "\n" + s_server_books;
     }
     case Sync_Logic::bibles_get_book_checksum:
     {
       // The server responds with the checksum of the whole book.
-      return checksum_logic::get_book (request, bible, book);
+      return checksum_logic::get_book (bible, book);
     }
     case Sync_Logic::bibles_get_chapters:
     {
       // The server responds with the list of books in the Bible book.
-      vector <int> server_chapters = request->database_bibles()->getChapters (bible, book);
-      vector <string> v_server_chapters;
-      for (auto & server_chapter : server_chapters) v_server_chapters.push_back (filter::strings::convert_to_string (server_chapter));
-      string s_server_chapters = filter::strings::implode (v_server_chapters, "\n");
-      string checksum = checksum_logic::get (v_server_chapters);
+      std::vector <int> server_chapters = database::bibles::get_chapters (bible, book);
+      std::vector <std::string> v_server_chapters;
+      for (auto & server_chapter : server_chapters) v_server_chapters.push_back (std::to_string (server_chapter));
+      std::string s_server_chapters = filter::strings::implode (v_server_chapters, "\n");
+      std::string checksum = checksum_logic::get (v_server_chapters);
       return checksum + "\n" + s_server_chapters;
     }
     case Sync_Logic::bibles_get_chapter_checksum:
     {
       // The server responds with the checksum of the whole chapter.
-      return checksum_logic::get_chapter (request, bible, book, chapter);
+      return checksum_logic::get_chapter (bible, book, chapter);
     }
     case Sync_Logic::bibles_send_chapter:
     {
-      return sync_bibles_receive_chapter (request, bible, book, chapter);
+      return sync_bibles_receive_chapter (webserver_request, bible, book, chapter);
     }
     case Sync_Logic::bibles_get_chapter:
     {
       // The server responds with the USFM of the chapter, prefixed by a checksum.
-      string usfm = filter::strings::trim (request->database_bibles()->getChapter (bible, book, chapter));
-      string checksum = checksum_logic::get (usfm);
+      std::string usfm = filter::strings::trim (database::bibles::get_chapter (bible, book, chapter));
+      std::string checksum = checksum_logic::get (usfm);
       return checksum + "\n" + usfm;
     }
     default: {};
@@ -242,7 +239,7 @@ string sync_bibles (void * webserver_request)
   
   // Bad request.
   // Delay a while to obstruct a flood of bad requests.
-  this_thread::sleep_for (chrono::seconds (1));
-  request->response_code = 400;
-  return "";
+  std::this_thread::sleep_for (std::chrono::seconds (1));
+  webserver_request.response_code = 400;
+  return std::string();
 }
