@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -38,27 +38,25 @@
 #include <access/bible.h>
 #include <bb/logic.h>
 #include <notes/logic.h>
-using namespace std;
 
 
-string sync_notes_url ()
+std::string sync_notes_url ()
 {
   return "sync/notes";
 }
 
 
-string sync_notes (void * webserver_request)
+std::string sync_notes (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  Sync_Logic sync_logic = Sync_Logic (webserver_request);
+  Sync_Logic sync_logic (webserver_request);
   Database_Notes database_notes (webserver_request);
-  Notes_Logic notes_logic = Notes_Logic (webserver_request);
+  Notes_Logic notes_logic (webserver_request);
 
   
   if (!sync_logic.security_okay ()) {
     // When the Cloud enforces https, inform the client to upgrade.
-    request->response_code = 426;
-    return string();
+    webserver_request.response_code = 426;
+    return std::string();
   }
 
   
@@ -68,8 +66,8 @@ string sync_notes (void * webserver_request)
   if (!database_notes.checksums_healthy ()) available = false;
   if (!database_notes.available ()) available = false;
   if (!available) {
-    request->response_code = 503;
-    return string();
+    webserver_request.response_code = 503;
+    return std::string();
   }
 
 
@@ -78,57 +76,57 @@ string sync_notes (void * webserver_request)
 
   
   // What action does the client request from us?
-  int action = convert_to_int (request->post ["a"]);
+  int action = filter::strings::convert_to_int (webserver_request.post ["a"]);
 
   
   // Check on the credentials when the clients sends data to the server to be stored there.
   if ((action >= Sync_Logic::notes_put_create_initiate) && (action != Sync_Logic::notes_get_bulk)) {
-    if (!sync_logic.credentials_okay ()) return string();
+    if (!sync_logic.credentials_okay ()) return std::string();
   }
 
 
   // Check on username only, without password or level.
-  string user = hex2bin (request->post ["u"]);
+  std::string user = filter::strings::hex2bin (webserver_request.post ["u"]);
   if ((action == Sync_Logic::notes_get_total) || (action == Sync_Logic::notes_get_identifiers)) {
-    if (!request->database_users ()->usernameExists (user)) {
+    if (!webserver_request.database_users ()->usernameExists (user)) {
       Database_Logs::log ("A client passes a non-existing user " + user, Filter_Roles::manager ());
-      return string();
+      return std::string();
     }
   }
-  request->session_logic ()->set_username (user);
+  webserver_request.session_logic ()->set_username (user);
   
   
   // Note lower and upper limits.
-  int lowId = convert_to_int (request->post ["l"]);
-  int highId = convert_to_int (request->post ["h"]);
+  int lowId = filter::strings::convert_to_int (webserver_request.post ["l"]);
+  int highId = filter::strings::convert_to_int (webserver_request.post ["h"]);
 
   
-  int identifier = convert_to_int (request->post ["i"]);
-  string content = request->post ["c"];
+  int identifier = filter::strings::convert_to_int (webserver_request.post ["i"]);
+  std::string content = webserver_request.post ["c"];
   
   switch (action) {
     case Sync_Logic::notes_get_total:
     {
-      vector <string> bibles = access_bible::bibles (webserver_request, user);
-      vector <int> identifiers = database_notes.get_notes_in_range_for_bibles (lowId, highId, bibles, false);
+      std::vector <std::string> bibles = access_bible::bibles (webserver_request, user);
+      std::vector <int> identifiers = database_notes.get_notes_in_range_for_bibles (lowId, highId, bibles, false);
       // Checksum cache to speed things up in case of thousands of notes.
       // Else the server would run at 100% CPU usage for some time to get the total checksums of notes.
-      string checksum = Database_State::getNotesChecksum (lowId, highId);
+      std::string checksum = Database_State::getNotesChecksum (lowId, highId);
       if (checksum.empty ()) {
         checksum = database_notes.get_multiple_checksum (identifiers);
         Database_State::putNotesChecksum (lowId, highId, checksum);
       }
-      string response = convert_to_string (identifiers.size ()) + "\n" + checksum;
+      std::string response = std::to_string (identifiers.size ()) + "\n" + checksum;
       return response;
     }
     case Sync_Logic::notes_get_identifiers:
     {
-      vector <string> bibles = access_bible::bibles (webserver_request, user);
-      vector <int> identifiers = database_notes.get_notes_in_range_for_bibles (lowId, highId, bibles, false);
-      string response;
+      std::vector <std::string> bibles = access_bible::bibles (webserver_request, user);
+      std::vector <int> identifiers = database_notes.get_notes_in_range_for_bibles (lowId, highId, bibles, false);
+      std::string response;
       for (auto id : identifiers) {
         if (!response.empty ()) response.append ("\n");
-        response.append (convert_to_string (id));
+        response.append (std::to_string (id));
         response.append ("\n");
         response.append (database_notes.get_checksum (id));
       }
@@ -142,7 +140,7 @@ string sync_notes (void * webserver_request)
       database_notes.update_search_fields (identifier);
       database_notes.update_checksum (identifier);
       // Return summary.
-      string summary = database_notes.get_summary (identifier);
+      std::string summary = database_notes.get_summary (identifier);
       return summary;
     }
     case Sync_Logic::notes_get_contents:
@@ -151,13 +149,13 @@ string sync_notes (void * webserver_request)
     }
     case Sync_Logic::notes_get_subscribers:
     {
-      vector <string> subscribers = database_notes.get_subscribers (identifier);
-      return filter_string_implode (subscribers, "\n");
+      std::vector <std::string> subscribers = database_notes.get_subscribers (identifier);
+      return filter::strings::implode (subscribers, "\n");
     }
     case Sync_Logic::notes_get_assignees:
     {
-      vector <string> assignees = database_notes.get_assignees (identifier);
-      return filter_string_implode (assignees, "\n");
+      std::vector <std::string> assignees = database_notes.get_assignees (identifier);
+      return filter::strings::implode (assignees, "\n");
     }
     case Sync_Logic::notes_get_status:
     {
@@ -170,7 +168,7 @@ string sync_notes (void * webserver_request)
     }
     case Sync_Logic::notes_get_severity:
     {
-      return convert_to_string (database_notes.get_raw_severity (identifier));
+      return std::to_string (database_notes.get_raw_severity (identifier));
     }
     case Sync_Logic::notes_get_bible:
     {
@@ -178,7 +176,7 @@ string sync_notes (void * webserver_request)
     }
     case Sync_Logic::notes_get_modified:
     {
-      return convert_to_string (database_notes.get_modified (identifier));
+      return std::to_string (database_notes.get_modified (identifier));
     }
     case Sync_Logic::notes_put_create_initiate:
     {
@@ -189,14 +187,14 @@ string sync_notes (void * webserver_request)
       // Update search field.
       database_notes.update_search_fields (identifier);
       // Done.
-      return string();
+      return std::string();
     }
     case Sync_Logic::notes_put_create_complete:
     {
       // Do notifications.
       notes_logic.handlerNewNote (identifier);
       // Done.
-      return string();
+      return std::string();
     }
     case Sync_Logic::notes_put_summary:
     {
@@ -207,7 +205,7 @@ string sync_notes (void * webserver_request)
       // Info.
       Database_Logs::log ("Client created or updated a note on the server: " + content, Filter_Roles::manager ());
       // Done.
-      return string();
+      return std::string();
     }
     case Sync_Logic::notes_put_contents:
     {
@@ -216,7 +214,7 @@ string sync_notes (void * webserver_request)
       // Update search field.
       database_notes.update_search_fields (identifier);
       // Done.
-      return string();
+      return std::string();
     }
     case Sync_Logic::notes_put_comment:
     {
@@ -229,7 +227,7 @@ string sync_notes (void * webserver_request)
       // Notifications.
       notes_logic.handlerAddComment (identifier);
       // Done.
-      return string();
+      return std::string();
     }
     case Sync_Logic::notes_put_subscribe:
     {
@@ -238,7 +236,7 @@ string sync_notes (void * webserver_request)
       // Info.
       Database_Logs::log ("Client subscribed to note on server: " + database_notes.get_summary (identifier), Filter_Roles::manager ());
       // Done.
-      return string();
+      return std::string();
     }
     case Sync_Logic::notes_put_unsubscribe:
     {
@@ -247,7 +245,7 @@ string sync_notes (void * webserver_request)
       // Info.
       Database_Logs::log ("Client unsubscribed from note on server: " + database_notes.get_summary (identifier), Filter_Roles::manager ());
       // Done.
-      return string();
+      return std::string();
     }
     case Sync_Logic::notes_put_assign:
     {
@@ -258,7 +256,7 @@ string sync_notes (void * webserver_request)
       // Notifications.
       notes_logic.handlerAssignNote (identifier, content);
       // Done.
-      return string();
+      return std::string();
     }
     case Sync_Logic::notes_put_unassign:
     {
@@ -267,7 +265,7 @@ string sync_notes (void * webserver_request)
       // Info.
       Database_Logs::log ("Client unassigned a user from the note on server: " + database_notes.get_summary (identifier), Filter_Roles::manager ());
       // Done.
-      return string();
+      return std::string();
     }
     case Sync_Logic::notes_put_status:
     {
@@ -276,7 +274,7 @@ string sync_notes (void * webserver_request)
       // Info.
       Database_Logs::log ("Client set the note status on server: " + database_notes.get_summary (identifier), Filter_Roles::manager ());
       // Done.
-      return string();
+      return std::string();
     }
     case Sync_Logic::notes_put_passages:
     {
@@ -284,23 +282,23 @@ string sync_notes (void * webserver_request)
       database_notes.set_raw_passage (identifier, content);
       database_notes.index_raw_passage (identifier, content);
       // Done.
-      return string();
+      return std::string();
     }
     case Sync_Logic::notes_put_severity:
     {
       // Set the severity for a note on the server.
-      notes_logic.setRawSeverity (identifier, convert_to_int (content));
+      notes_logic.setRawSeverity (identifier, filter::strings::convert_to_int (content));
       // Info
       Database_Logs::log ("Client set the severity for a note on server: " + database_notes.get_summary (identifier), Filter_Roles::manager ());
       // Done.
-      return string();
+      return std::string();
     }
     case Sync_Logic::notes_put_bible:
     {
       // Set the Bible for a note on the server.
       notes_logic.setBible (identifier, content);
       // Done.
-      return string();
+      return std::string();
     }
     case Sync_Logic::notes_put_mark_delete:
     {
@@ -311,7 +309,7 @@ string sync_notes (void * webserver_request)
       // Notifications.
       notes_logic.handlerMarkNoteForDeletion (identifier);
       // Done.
-      return string();
+      return std::string();
     }
     case Sync_Logic::notes_put_unmark_delete:
     {
@@ -320,7 +318,7 @@ string sync_notes (void * webserver_request)
       // Info.
       Database_Logs::log ("Client unmarked a note on server for deletion: " + database_notes.get_summary (identifier), Filter_Roles::manager ());
       // Done.
-      return string();
+      return std::string();
     }
     case Sync_Logic::notes_put_delete:
     {
@@ -331,18 +329,18 @@ string sync_notes (void * webserver_request)
       // Delete note on server.
       notes_logic.erase (identifier);
       // Done.
-      return string();
+      return std::string();
     }
     // This method of bulk download was implemented as of September 2016.
     // After a year or so, the logic for the replaced download methods can probably be removed from the Cloud.
     case Sync_Logic::notes_get_bulk:
     {
       // Get the note identifiers the client requests.
-      vector <string> notes = filter_string_explode (request->post ["b"], '\n');
-      vector <int> identifiers;
-      for (auto note : notes) identifiers.push_back (convert_to_int (note));
+      std::vector <std::string> notes = filter::strings::explode (webserver_request.post ["b"], '\n');
+      std::vector <int> identifiers;
+      for (auto note : notes) identifiers.push_back (filter::strings::convert_to_int (note));
       // Return the JSON that contains all the requested notes.
-      string json = database_notes.get_bulk (identifiers);
+      std::string json = database_notes.get_bulk (identifiers);
       return json;
     }
     default: {};
@@ -350,7 +348,7 @@ string sync_notes (void * webserver_request)
   
   // Bad request.
   // Delay a while to obstruct a flood of bad requests.
-  this_thread::sleep_for (chrono::seconds (1));
-  request->response_code = 400;
-  return string();
+  std::this_thread::sleep_for (std::chrono::seconds (1));
+  webserver_request.response_code = 400;
+  return std::string();
 }
