@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -25,40 +25,38 @@
 #include <database/users.h>
 #include <sync/logic.h>
 #include <user/logic.h>
-using namespace std;
 
 
-string sync_setup_url ()
+std::string sync_setup_url ()
 {
   return "sync/setup";
 }
 
 
-string sync_setup (void * webserver_request)
+std::string sync_setup (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  Sync_Logic sync_logic = Sync_Logic (webserver_request);
+  Sync_Logic sync_logic (webserver_request);
   
   if (!sync_logic.security_okay ()) {
     // When the Cloud enforces https, inform the client to upgrade.
-    request->response_code = 426;
-    return "";
+    webserver_request.response_code = 426;
+    return std::string();
   }
   
-  string page;
+  std::string page;
   
-  string username = request->query ["user"];
-  username = hex2bin (username);
-  string password = request->query ["pass"];
+  std::string username = webserver_request.query ["user"];
+  username = filter::strings::hex2bin (username);
+  std::string password = webserver_request.query ["pass"];
 
   // Check the credentials of the client.
-  if (request->database_users ()->usernameExists (username)) {
-    string md5 = request->database_users ()->get_md5 (username);
+  if (webserver_request.database_users ()->usernameExists (username)) {
+    std::string md5 = webserver_request.database_users ()->get_md5 (username);
     if (password == md5) {
       // Check brute force attack mitigation.
       if (user_logic_login_failure_check_okay ()) {
         // Return the level to the client.
-        return convert_to_string (request->database_users ()->get_level (username));
+        return std::to_string (webserver_request.database_users ()->get_level (username));
       }
     }
   }
