@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -47,16 +47,15 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <fonts/logic.h>
 #include <manage/index.h>
 #include <client/logic.h>
-using namespace std;
 
 
-string system_index_url ()
+std::string system_index_url ()
 {
   return "system/index";
 }
 
 
-bool system_index_acl ([[maybe_unused]] void * webserver_request)
+bool system_index_acl ([[maybe_unused]] Webserver_Request& webserver_request)
 {
 #ifdef HAVE_CLIENT
   // Client: Anyone can make system settings.
@@ -68,21 +67,18 @@ bool system_index_acl ([[maybe_unused]] void * webserver_request)
 }
 
 
-string system_index (void * webserver_request)
+std::string system_index (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  
-  
-  string page;
-  string success;
-  string error;
+  std::string page {};
+  std::string success {};
+  std::string error {};
 
   
   // User can set the system language.
   // This is to be done before displaying the header.
-  if (request->post.count ("languageselection")) {
-    string languageselection = request->post ["languageselection"];
-    Database_Config_General::setSiteLanguage (languageselection);
+  if (webserver_request.post.count ("languageselection")) {
+    std::string languageselection {webserver_request.post ["languageselection"]};
+    database::config::general::set_site_language (languageselection);
   }
 
   
@@ -96,38 +92,38 @@ string system_index (void * webserver_request)
 
 
   // Get values for setting checkboxes.
-  string checkbox = request->post ["checkbox"];
-  [[maybe_unused]] bool checked = filter::strings::convert_to_bool (request->post ["checked"]);
+  const std::string checkbox = webserver_request.post ["checkbox"];
+  [[maybe_unused]] const bool checked = filter::strings::convert_to_bool (webserver_request.post ["checked"]);
 
 
   // The available localizations.
-  map <string, string> localizations = locale_logic_localizations ();
+  std::map <std::string, std::string> localizations = locale_logic_localizations ();
 
 
   // Set the language on the page.
     // Create the option tags for interface language selection.
   // Also the current selected option.
-  string language_html;
-  for (auto element : localizations) {
+  std::string language_html {};
+  for (const auto& element : localizations) {
     language_html = Options_To_Select::add_selection (element.second, element.first, language_html);
   }
-  string current_user_preference = Database_Config_General::getSiteLanguage ();
-  string language = current_user_preference;
+  const std::string current_user_preference = database::config::general::get_site_language ();
+  const std::string language = current_user_preference;
   view.set_variable ("languageselectionoptags", Options_To_Select::mark_selected (language, language_html));
   view.set_variable ("languageselection", language);
 
   
   // Entry of time zone offset in hours.
-  if (request->post.count ("timezone")) {
-    string input = request->post ["timezone"];
-    input = filter::strings::replace ("UTC", string(), input);
+  if (webserver_request.post.count ("timezone")) {
+    std::string input = webserver_request.post ["timezone"];
+    input = filter::strings::replace ("UTC", std::string(), input);
     int input_timezone = filter::strings::convert_to_int (input);
     input_timezone = clip (input_timezone, MINIMUM_TIMEZONE, MAXIMUM_TIMEZONE);
-    Database_Config_General::setTimezone (input_timezone);
+    database::config::general::set_timezone (input_timezone);
   }
   // Set the time zone offset in the GUI.
-  int timezone_setting = Database_Config_General::getTimezone();
-  view.set_variable ("timezone", filter::strings::convert_to_string (timezone_setting));
+  const int timezone_setting = database::config::general::get_timezone();
+  view.set_variable ("timezone", std::to_string (timezone_setting));
   // Display the section to set the site's timezone only
   // in case the calling program has not yet set this zone in the library.
   // So for example the app for iOS can set the timezone from the device,
@@ -141,19 +137,18 @@ string system_index (void * webserver_request)
 #ifdef HAVE_CLOUD
   // Whether to include the author with every change in the RSS feed.
   if (checkbox == "rssauthor") {
-    Database_Config_General::setAuthorInRssFeed (checked);
-    return string();
+    database::config::general::set_uuthor_in_rss_feed (checked);
+    return std::string();
   }
-  view.set_variable ("rssauthor", filter::strings::get_checkbox_status (Database_Config_General::getAuthorInRssFeed ()));
+  view.set_variable ("rssauthor", filter::strings::get_checkbox_status (database::config::general::get_author_in_rss_feed ()));
   // The location of the RSS feed.
   view.set_variable ("rssfeed", rss_feed_url ());
   // The Bibles that send their changes to the RSS feed.
-  string rssbibles;
+  std::string rssbibles {};
   {
-    Database_Bibles database_bibles;
-    vector <string> bibles = database_bibles.getBibles ();
-    for (auto bible : bibles) {
-      if (Database_Config_Bible::getSendChangesToRSS (bible)) {
+    std::vector <std::string> bibles = database::bibles::get_bibles ();
+    for (const auto& bible : bibles) {
+      if (database::config::bible::get_send_changes_to_rss (bible)) {
         if (!rssbibles.empty ()) rssbibles.append (" ");
         rssbibles.append (bible);
       }
@@ -167,35 +162,35 @@ string system_index (void * webserver_request)
 
   
 #ifdef HAVE_CLIENT
-  bool producebibles = request->query.count ("producebibles");
-  bool producenotes = request->query.count ("producenotes");
-  bool produceresources = request->query.count ("produceresources");
+  const bool producebibles = webserver_request.query.count ("producebibles");
+  const bool producenotes = webserver_request.query.count ("producenotes");
+  const bool produceresources = webserver_request.query.count ("produceresources");
   if (producebibles || producenotes || produceresources) {
     Database_Jobs database_jobs;
-    int jobId = database_jobs.get_new_id ();
+    const int jobId = database_jobs.get_new_id ();
     database_jobs.set_level (jobId, Filter_Roles::member ());
-    string task;
-    if (producebibles) task = PRODUCEBIBLESTRANSFERFILE;
-    if (producenotes) task = PRODUCERENOTESTRANSFERFILE;
-    if (produceresources) task = PRODUCERESOURCESTRANSFERFILE;
-    tasks_logic_queue (task, { filter::strings::convert_to_string (jobId) });
-    redirect_browser (request, jobs_index_url () + "?id=" + filter::strings::convert_to_string (jobId));
-    return "";
+    std::string task {};
+    if (producebibles) task = task::produce_bibles_transferfile;
+    if (producenotes) task = task::produce_notes_transferfile;
+    if (produceresources) task = task::produce_resources_transferfile;
+    tasks_logic_queue (task, { std::to_string(jobId) });
+    redirect_browser (webserver_request, jobs_index_url () + "?id=" + std::to_string(jobId));
+    return std::string();
   }
 #endif
 
   
 #ifdef HAVE_CLIENT
-  string importbibles = "importbibles";
-  if (request->query.count (importbibles)) {
-    if (request->post.count ("upload")) {
-      string datafile = filter_url_tempfile () + request->post ["filename"];
-      string data = request->post ["data"];
+  const std::string importbibles = "importbibles";
+  if (webserver_request.query.count (importbibles)) {
+    if (webserver_request.post.count ("upload")) {
+      const std::string datafile = filter_url_tempfile () + webserver_request.post ["filename"];
+      const std::string data = webserver_request.post ["data"];
       if (!data.empty ()) {
         filter_url_file_put_contents (datafile, data);
         success = translate("Import has started.");
         view.set_variable ("journal", journal_logic_see_journal_for_progress ());
-        tasks_logic_queue (IMPORTBIBLESTRANSFERFILE, { datafile });
+        tasks_logic_queue (task::import_bibles_transferfile, { datafile });
       } else {
         error = translate ("Nothing was imported");
       }
@@ -210,16 +205,16 @@ string system_index (void * webserver_request)
 
   
 #ifdef HAVE_CLIENT
-  string importnotes = "importnotes";
-  if (request->query.count (importnotes)) {
-    if (request->post.count ("upload")) {
-      string datafile = filter_url_tempfile () + request->post ["filename"];
-      string data = request->post ["data"];
+  const std::string importnotes = "importnotes";
+  if (webserver_request.query.count (importnotes)) {
+    if (webserver_request.post.count ("upload")) {
+      const std::string datafile = filter_url_tempfile () + webserver_request.post ["filename"];
+      const std::string data = webserver_request.post ["data"];
       if (!data.empty ()) {
         filter_url_file_put_contents (datafile, data);
         success = translate("Import has started.");
         view.set_variable ("journal", journal_logic_see_journal_for_progress ());
-        tasks_logic_queue (IMPORTNOTESTRANSFERFILE, { datafile });
+        tasks_logic_queue (task::import_notes_transferfile, { datafile });
       } else {
         error = translate ("Nothing was imported");
       }
@@ -234,16 +229,16 @@ string system_index (void * webserver_request)
   
   
 #ifdef HAVE_CLIENT
-  string importresources = "importresources";
-  if (request->query.count (importresources)) {
-    if (request->post.count ("upload")) {
-      string datafile = filter_url_tempfile () + request->post ["filename"];
-      string data = request->post ["data"];
+  const std::string importresources = "importresources";
+  if (webserver_request.query.count (importresources)) {
+    if (webserver_request.post.count ("upload")) {
+      const std::string datafile = filter_url_tempfile () + webserver_request.post ["filename"];
+      const std::string data = webserver_request.post ["data"];
       if (!data.empty ()) {
         filter_url_file_put_contents (datafile, data);
         success = translate("Import has started.");
         view.set_variable ("journal", journal_logic_see_journal_for_progress ());
-        tasks_logic_queue (IMPORTRESOURCESTRANSFERFILE, { datafile });
+        tasks_logic_queue (task::import_resources_transferfile, { datafile });
       } else {
         error = translate ("Nothing was imported");
       }
@@ -258,30 +253,30 @@ string system_index (void * webserver_request)
 
   
   // Force re-index Bibles.
-  if (request->query ["reindex"] == "bibles") {
-    Database_Config_General::setIndexBibles (true);
-    tasks_logic_queue (REINDEXBIBLES, {"1"});
-    redirect_browser (request, journal_index_url ());
-    return "";
+  if (webserver_request.query ["reindex"] == "bibles") {
+    database::config::general::set_index_bibles (true);
+    tasks_logic_queue (task::reindex_bibles, {"1"});
+    redirect_browser (webserver_request, journal_index_url ());
+    return std::string();
   }
   
   
   // Re-index consultation notes.
-  if (request->query ["reindex"] == "notes") {
-    Database_Config_General::setIndexNotes (true);
-    tasks_logic_queue (REINDEXNOTES);
-    redirect_browser (request, journal_index_url ());
-    return "";
+  if (webserver_request.query ["reindex"] == "notes") {
+    database::config::general::setIndexNotes (true);
+    tasks_logic_queue (task::reindex_notes);
+    redirect_browser (webserver_request, journal_index_url ());
+    return std::string();
   }
 
   
   // Delete a font.
-  string deletefont = request->query ["deletefont"];
+  const std::string deletefont = webserver_request.query ["deletefont"];
   if (!deletefont.empty ()) {
-    string font = filter_url_basename_web (deletefont);
+    const std::string font = filter_url_basename_web (deletefont);
     bool font_in_use = false;
-    vector <string> bibles = request->database_bibles ()->getBibles ();
-    for (auto & bible : bibles) {
+    const std::vector <std::string> bibles = database::bibles::get_bibles ();
+    for (const auto& bible : bibles) {
       if (font == fonts::logic::get_text_font (bible)) font_in_use = true;
     }
     if (!font_in_use) {
@@ -294,22 +289,22 @@ string system_index (void * webserver_request)
   
   
   // Upload a font.
-  if (request->post.count ("uploadfont")) {
-    string filename = request->post ["filename"];
-    string path = filter_url_create_root_path ({"fonts", filename});
-    string fontdata = request->post ["fontdata"];
+  if (webserver_request.post.count ("uploadfont")) {
+    const std::string filename = webserver_request.post ["filename"];
+    const std::string path = filter_url_create_root_path ({"fonts", filename});
+    const std::string fontdata = webserver_request.post ["fontdata"];
     filter_url_file_put_contents (path, fontdata);
     success = translate("The font has been uploaded.");
   }
   
   
   // Assemble the font block html.
-  vector <string> fonts = fonts::logic::get_fonts ();
-  stringstream fontsblock;
-  for (auto & font : fonts) {
+  const std::vector <std::string> fonts = fonts::logic::get_fonts ();
+  std::stringstream fontsblock;
+  for (const auto& font : fonts) {
     fontsblock << "<p>";
 #ifndef HAVE_CLIENT
-    fontsblock << "<a href=" << quoted ("?deletefont=" + font) << " title=" << quoted(translate("Delete font")) << ">" << filter::strings::emoji_wastebasket () << "</a>";
+    fontsblock << "<a href=" << std::quoted ("?deletefont=" + font) << " title=" << std::quoted(translate("Delete font")) << ">" << filter::strings::emoji_wastebasket () << "</a>";
 #endif
     fontsblock << font;
     fontsblock << "</p>";
@@ -318,44 +313,54 @@ string system_index (void * webserver_request)
 
   
   // Handle the command to clear the web and resources caches.
-  if (request->query.count ("clearcache")) {
-    tasks_logic_queue (CLEARCACHES);
-    redirect_browser (request, journal_index_url ());
-    return "";
+  if (webserver_request.query.count ("clearcache")) {
+    tasks_logic_queue (task::clear_caches);
+    redirect_browser (webserver_request, journal_index_url ());
+    return std::string();
   }
   
   
   // Handle the setting whether to keep the resource caches for an extended period of time.
 #ifdef HAVE_CLOUD
   if (checkbox == "keepcache") {
-    Database_Config_General::setKeepResourcesCacheForLong (checked);
-    return "";
+    database::config::general::set_keep_resources_cache_for_long (checked);
+    return std::string();
   }
-  view.set_variable ("keepcache", filter::strings::get_checkbox_status (Database_Config_General::getKeepResourcesCacheForLong ()));
+  view.set_variable ("keepcache", filter::strings::get_checkbox_status (database::config::general::get_keep_resources_cache_for_long ()));
 #endif
 
 
   // Handle display the number of unsent emails and clearing them.
 #ifdef HAVE_CLOUD
   Database_Mail database_mail (webserver_request);
-  if (request->query.count ("clearemails")) {
-    vector <int> mails = database_mail.getAllMails ();
+  if (webserver_request.query.count ("clearemails")) {
+    const std::vector <int> mails = database_mail.getAllMails ();
     for (auto rowid : mails) {
       database_mail.erase (rowid);
     }
   }
-  vector <int> mails = database_mail.getAllMails ();
-  string mailcount = filter::strings::convert_to_string (mails.size());
+  const std::vector <int> mails = database_mail.getAllMails ();
+  const std::string mailcount = std::to_string (mails.size());
   view.set_variable ("emailscount", mailcount);
 #endif
 
   
+  // Handle the setting whether to keep available OSIS content in the SWORD resources.
+#ifdef HAVE_CLOUD
+  if (checkbox == "keeposis") {
+    database::config::general::set_keep_osis_content_in_sword_resources (checked);
+    return std::string();
+  }
+  view.set_variable ("keeposis", filter::strings::get_checkbox_status (database::config::general::get_keep_osis_content_in_sword_resources ()));
+#endif
+
+  
 #ifdef HAVE_CLOUD
   view.enable_zone ("cloud");
 #endif
 #ifdef HAVE_CLIENT
   view.enable_zone ("client");
-  view.set_variable ("cloudlink", client_logic_link_to_cloud (manage_index_url (), ""));
+  view.set_variable ("cloudlink", client_logic_link_to_cloud (manage_index_url (), std::string()));
 #endif
   
   
