@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <database/users.h>
 #include <database/styles.h>
 #include <database/bibles.h>
-#include <database/check.h>
 #include <database/ipc.h>
 
 class Webserver_Request
@@ -61,6 +60,9 @@ public:
   int content_length {0};
    // The raw POST data from the browser, item by item.
   std::map <std::string, std::string> post {};
+  // If the POSTed data contains multiple identical keys, store the extra keys here.
+  // Ideally the above container, "post" should be redesigned to be able to contain multiple identical keys.
+  std::map <std::string, std::vector<std::string>> post_multiple{};
    // Header as received from the browser.
   std::string if_none_match {};
    // Extra header to be sent back to the browser.
@@ -80,15 +82,11 @@ public:
   Database_Config_User * database_config_user ();
   Database_Users * database_users ();
   Database_Styles * database_styles ();
-  Database_Bibles * database_bibles ();
-  Database_Check * database_check ();
   Database_Ipc * database_ipc ();
 private:
   Session_Logic * session_logic_instance { nullptr };
   Database_Config_User * database_config_user_instance { nullptr };
   Database_Users * database_users_instance { nullptr };
   Database_Styles * database_styles_instance { nullptr };
-  Database_Bibles * database_bibles_instance { nullptr };
-  Database_Check * database_check_instance { nullptr };
   Database_Ipc * database_ipc_instance { nullptr };
 };
