@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -34,39 +34,38 @@
 #include <navigation/passage.h>
 
 
-string workspace_index_url ()
+std::string workspace_index_url ()
 {
   return "workspace/index";
 }
 
 
-bool workspace_index_acl (void * webserver_request)
+bool workspace_index_acl (Webserver_Request& webserver_request)
 {
   return Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ());
 }
 
 
-string workspace_index (void * webserver_request)
+std::string workspace_index (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  vector <string> workspaces = workspace_get_names (request);
+  const std::vector <std::string> workspaces = workspace_get_names (webserver_request);
 
   // Set the requested workspace as the active one.
-  if (request->query.count ("bench")) {
-    size_t bench = static_cast <size_t> (convert_to_int (request->query ["bench"]));
+  if (webserver_request.query.count ("bench")) {
+    const size_t bench = static_cast <size_t> (filter::strings::convert_to_int (webserver_request.query ["bench"]));
     if (bench < workspaces.size ()) {
-      string workspace = workspaces [bench];
-      request->database_config_user()->setActiveWorkspace (workspace);
+      const std::string workspace = workspaces [bench];
+      webserver_request.database_config_user()->setActiveWorkspace (workspace);
     }
   }
   
   
   // Check that the active workspace exists, else set the first available workspace as the active one.
   {
-    string workspace = request->database_config_user ()->getActiveWorkspace ();
+    const std::string workspace = webserver_request.database_config_user ()->getActiveWorkspace ();
     if (!in_array (workspace, workspaces)) {
       if (!workspaces.empty ()) {
-        request->database_config_user ()->setActiveWorkspace (workspaces [0]);
+        webserver_request.database_config_user ()->setActiveWorkspace (workspaces [0]);
       }
     }
   }
@@ -84,56 +83,58 @@ string workspace_index (void * webserver_request)
   
   // In case the workspace is opened from a consultation note email,
   // read the note, and set the active passage to the passage the note refers to.
-  int noteid = convert_to_int (request->query ["note"]);
-  if (noteid) {
+  const int note_id = filter::strings::convert_to_int (webserver_request.query ["note"]);
+  if (note_id) {
     Database_Notes database_notes (webserver_request);
-    vector <Passage> passages = database_notes.get_passages (noteid);
+    const std::vector <Passage> passages = database_notes.get_passages (note_id);
     if (!passages.empty ()) {
-      Ipc_Focus::set (webserver_request, passages[0].m_book, passages[0].m_chapter, convert_to_int (passages[0].m_verse));
-      Navigation_Passage::record_history (webserver_request, passages[0].m_book, passages[0].m_chapter, convert_to_int (passages[0].m_verse));
+      Ipc_Focus::set (webserver_request, passages[0].m_book, passages[0].m_chapter, filter::strings::convert_to_int (passages[0].m_verse));
+      Navigation_Passage::record_history (webserver_request, passages[0].m_book, passages[0].m_chapter, filter::strings::convert_to_int (passages[0].m_verse));
     }
   }
   
   
-  string page;
-  Assets_Header header = Assets_Header (translate("Workspace"), request);
-  header.setNavigator ();
-  header.setFadingMenu (menu_logic_workspace_category (webserver_request));
+  std::string page{};
+  Assets_Header header = Assets_Header (translate("Workspace"), webserver_request);
+  header.set_navigator ();
+  header.set_fading_menu (menu_logic_workspace_category (webserver_request));
   page = header.run ();
   Assets_View view;
 
   
-  map <int, string> urls = workspace_get_urls (request, true);
-  map <int, string> widths = workspace_get_widths (request);
+  std::map <int, std::string> urls = workspace_get_urls (webserver_request, true);
+  std::map <int, std::string> widths = workspace_get_widths (webserver_request);
   // The Bible editor number, starting from 1, going up.
-  map <int, int> editor_numbers = workspace_add_bible_editor_number (urls);
+  std::map <int, int> editor_numbers = workspace_add_bible_editor_number (urls);
   for (int key = 0; key < 15; key++) {
-    string url = urls [key];
-    string width = widths [key];
-    int editor_number = editor_numbers [key];
-    int row = static_cast<int> (round (key / 5)) + 1;
-    int column = key % 5 + 1;
-    string variable = "url" + convert_to_string (row) + convert_to_string (column);
+    const std::string url = urls [key];
+    const std::string width = widths [key];
+    const int editor_number = editor_numbers [key];
+    const int row = static_cast<int> (round (key / 5)) + 1;
+    const int column = key % 5 + 1;
+    std::string variable = "url" + std::to_string (row) + std::to_string (column);
     view.set_variable (variable, url);
-    variable = "width" + convert_to_string (row) + convert_to_string (column);
+    variable = "width" + std::to_string (row) + std::to_string (column);
     view.set_variable (variable, width);
-    if (convert_to_int (width) > 0) view.enable_zone (variable);
-    variable = "editorno" + convert_to_string (row) + convert_to_string (column);
-    view.set_variable (variable, convert_to_string (editor_number));
+    if (filter::strings::convert_to_int (width) > 0) 
+      view.enable_zone (variable);
+    variable = "editorno" + std::to_string (row) + std::to_string (column);
+    view.set_variable (variable, std::to_string (editor_number));
   }
   
   
-  map <int, string> heights = workspace_get_heights (request);
+  std::map <int, std::string> heights = workspace_get_heights (webserver_request);
   for (int key = 0; key < 3; key++) {
-    string height = heights [key];
-    int row = key + 1;
-    string variable = "height" + convert_to_string (row);
+    const std::string height = heights [key];
+    const int row = key + 1;
+    const std::string variable = "height" + std::to_string (row);
     view.set_variable (variable, height);
-    if (convert_to_int (height) > 0) view.enable_zone (variable);
+    if (filter::strings::convert_to_int (height) > 0) 
+      view.enable_zone (variable);
   }
   
   
-  string workspacewidth = workspace_get_entire_width (request);
+  std::string workspacewidth = workspace_get_entire_width (webserver_request);
   if (!workspacewidth.empty ()) {
     workspacewidth.insert (0, "width: ");
     workspacewidth.append (";");
@@ -143,7 +144,7 @@ string workspace_index (void * webserver_request)
   
   // The rendered template disables framekillers through the "sandbox" attribute on the iframe elements.
   page += view.render ("workspace", "index");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
 
